/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import entidades.ActaEntrega;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import java.util.ArrayList;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AControl implements Serializable {

    public AControl(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(ActaEntrega actaEntrega) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = actaEntrega.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                actaEntrega.setTratamientoId(tratamientoId);
            }
            em.persist(actaEntrega);
            if (tratamientoId != null) {
                ActaEntrega oldActaEntregaOfTratamientoId = tratamientoId.getActaEntrega();
                if (oldActaEntregaOfTratamientoId != null) {
                    oldActaEntregaOfTratamientoId.setTratamientoId(null);
                    oldActaEntregaOfTratamientoId = em.merge(oldActaEntregaOfTratamientoId);
                }
                tratamientoId.setActaEntrega(actaEntrega);
                tratamientoId = em.merge(tratamientoId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(ActaEntrega actaEntrega) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ActaEntrega persistentActaEntrega = em.find(ActaEntrega.class, actaEntrega.getId());
            Tratamiento tratamientoIdOld = persistentActaEntrega.getTratamientoId();
            Tratamiento tratamientoIdNew = actaEntrega.getTratamientoId();
            List<String> illegalOrphanMessages = null;
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain Tratamiento " + tratamientoIdOld + " since its actaEntrega field is not nullable.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                actaEntrega.setTratamientoId(tratamientoIdNew);
            }
            actaEntrega = em.merge(actaEntrega);
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                ActaEntrega oldActaEntregaOfTratamientoId = tratamientoIdNew.getActaEntrega();
                if (oldActaEntregaOfTratamientoId != null) {
                    oldActaEntregaOfTratamientoId.setTratamientoId(null);
                    oldActaEntregaOfTratamientoId = em.merge(oldActaEntregaOfTratamientoId);
                }
                tratamientoIdNew.setActaEntrega(actaEntrega);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = actaEntrega.getId();
                if (findActaEntrega(id) == null) {
                    throw new NonexistentEntityException("The actaEntrega with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ActaEntrega actaEntrega;
            try {
                actaEntrega = em.getReference(ActaEntrega.class, id);
                actaEntrega.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The actaEntrega with id " + id + " no longer exists.", enfe);
            }
         
            em.remove(actaEntrega);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<ActaEntrega> findActaEntregaEntities() {
        return findActaEntregaEntities(true, -1, -1);
    }

    public List<ActaEntrega> findActaEntregaEntities(int maxResults, int firstResult) {
        return findActaEntregaEntities(false, maxResults, firstResult);
    }

    private List<ActaEntrega> findActaEntregaEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(ActaEntrega.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public ActaEntrega findActaEntrega(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(ActaEntrega.class, id);
        } finally {
            em.close();
        }
    }

    public int getActaEntregaCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<ActaEntrega> rt = cq.from(ActaEntrega.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
