/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import entidades.AnalisisCefalometricoAdulto;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import entidades.ResultadoAdulto;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AnalisisCefalometricoAdultoJpaController implements Serializable {

    public AnalisisCefalometricoAdultoJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(AnalisisCefalometricoAdulto analisisCefalometricoAdulto) throws IllegalOrphanException {
        if (analisisCefalometricoAdulto.getResultadoAdultoCollection() == null) {
            analisisCefalometricoAdulto.setResultadoAdultoCollection(new ArrayList<ResultadoAdulto>());
        }
        List<String> illegalOrphanMessages = null;
        Tratamiento tratamientoIdOrphanCheck = analisisCefalometricoAdulto.getTratamientoId();
        if (tratamientoIdOrphanCheck != null) {
            AnalisisCefalometricoAdulto oldAnalisisCefalometricoAdultoOfTratamientoId = tratamientoIdOrphanCheck.getAnalisisCefalometricoAdulto();
            if (oldAnalisisCefalometricoAdultoOfTratamientoId != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The Tratamiento " + tratamientoIdOrphanCheck + " already has an item of type AnalisisCefalometricoAdulto whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
            }
        }
        if (illegalOrphanMessages != null) {
            throw new IllegalOrphanException(illegalOrphanMessages);
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = analisisCefalometricoAdulto.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                analisisCefalometricoAdulto.setTratamientoId(tratamientoId);
            }
            Collection<ResultadoAdulto> attachedResultadoAdultoCollection = new ArrayList<ResultadoAdulto>();
            for (ResultadoAdulto resultadoAdultoCollectionResultadoAdultoToAttach : analisisCefalometricoAdulto.getResultadoAdultoCollection()) {
                resultadoAdultoCollectionResultadoAdultoToAttach = em.getReference(resultadoAdultoCollectionResultadoAdultoToAttach.getClass(), resultadoAdultoCollectionResultadoAdultoToAttach.getId());
                attachedResultadoAdultoCollection.add(resultadoAdultoCollectionResultadoAdultoToAttach);
            }
            analisisCefalometricoAdulto.setResultadoAdultoCollection(attachedResultadoAdultoCollection);
            em.persist(analisisCefalometricoAdulto);
            if (tratamientoId != null) {
                tratamientoId.setAnalisisCefalometricoAdulto(analisisCefalometricoAdulto);
                tratamientoId = em.merge(tratamientoId);
            }
            for (ResultadoAdulto resultadoAdultoCollectionResultadoAdulto : analisisCefalometricoAdulto.getResultadoAdultoCollection()) {
                AnalisisCefalometricoAdulto oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionResultadoAdulto = resultadoAdultoCollectionResultadoAdulto.getAnalisisCefalometricoAdultoId();
                resultadoAdultoCollectionResultadoAdulto.setAnalisisCefalometricoAdultoId(analisisCefalometricoAdulto);
                resultadoAdultoCollectionResultadoAdulto = em.merge(resultadoAdultoCollectionResultadoAdulto);
                if (oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionResultadoAdulto != null) {
                    oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionResultadoAdulto.getResultadoAdultoCollection().remove(resultadoAdultoCollectionResultadoAdulto);
                    oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionResultadoAdulto = em.merge(oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionResultadoAdulto);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(AnalisisCefalometricoAdulto analisisCefalometricoAdulto) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisCefalometricoAdulto persistentAnalisisCefalometricoAdulto = em.find(AnalisisCefalometricoAdulto.class, analisisCefalometricoAdulto.getId());
            Tratamiento tratamientoIdOld = persistentAnalisisCefalometricoAdulto.getTratamientoId();
            Tratamiento tratamientoIdNew = analisisCefalometricoAdulto.getTratamientoId();
            Collection<ResultadoAdulto> resultadoAdultoCollectionOld = persistentAnalisisCefalometricoAdulto.getResultadoAdultoCollection();
            Collection<ResultadoAdulto> resultadoAdultoCollectionNew = analisisCefalometricoAdulto.getResultadoAdultoCollection();
            List<String> illegalOrphanMessages = null;
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                AnalisisCefalometricoAdulto oldAnalisisCefalometricoAdultoOfTratamientoId = tratamientoIdNew.getAnalisisCefalometricoAdulto();
                if (oldAnalisisCefalometricoAdultoOfTratamientoId != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The Tratamiento " + tratamientoIdNew + " already has an item of type AnalisisCefalometricoAdulto whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
                }
            }
            for (ResultadoAdulto resultadoAdultoCollectionOldResultadoAdulto : resultadoAdultoCollectionOld) {
                if (!resultadoAdultoCollectionNew.contains(resultadoAdultoCollectionOldResultadoAdulto)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain ResultadoAdulto " + resultadoAdultoCollectionOldResultadoAdulto + " since its analisisCefalometricoAdultoId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                analisisCefalometricoAdulto.setTratamientoId(tratamientoIdNew);
            }
            Collection<ResultadoAdulto> attachedResultadoAdultoCollectionNew = new ArrayList<ResultadoAdulto>();
            for (ResultadoAdulto resultadoAdultoCollectionNewResultadoAdultoToAttach : resultadoAdultoCollectionNew) {
                resultadoAdultoCollectionNewResultadoAdultoToAttach = em.getReference(resultadoAdultoCollectionNewResultadoAdultoToAttach.getClass(), resultadoAdultoCollectionNewResultadoAdultoToAttach.getId());
                attachedResultadoAdultoCollectionNew.add(resultadoAdultoCollectionNewResultadoAdultoToAttach);
            }
            resultadoAdultoCollectionNew = attachedResultadoAdultoCollectionNew;
            analisisCefalometricoAdulto.setResultadoAdultoCollection(resultadoAdultoCollectionNew);
            analisisCefalometricoAdulto = em.merge(analisisCefalometricoAdulto);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.setAnalisisCefalometricoAdulto(null);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.setAnalisisCefalometricoAdulto(analisisCefalometricoAdulto);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            for (ResultadoAdulto resultadoAdultoCollectionNewResultadoAdulto : resultadoAdultoCollectionNew) {
                if (!resultadoAdultoCollectionOld.contains(resultadoAdultoCollectionNewResultadoAdulto)) {
                    AnalisisCefalometricoAdulto oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionNewResultadoAdulto = resultadoAdultoCollectionNewResultadoAdulto.getAnalisisCefalometricoAdultoId();
                    resultadoAdultoCollectionNewResultadoAdulto.setAnalisisCefalometricoAdultoId(analisisCefalometricoAdulto);
                    resultadoAdultoCollectionNewResultadoAdulto = em.merge(resultadoAdultoCollectionNewResultadoAdulto);
                    if (oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionNewResultadoAdulto != null && !oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionNewResultadoAdulto.equals(analisisCefalometricoAdulto)) {
                        oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionNewResultadoAdulto.getResultadoAdultoCollection().remove(resultadoAdultoCollectionNewResultadoAdulto);
                        oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionNewResultadoAdulto = em.merge(oldAnalisisCefalometricoAdultoIdOfResultadoAdultoCollectionNewResultadoAdulto);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = analisisCefalometricoAdulto.getId();
                if (findAnalisisCefalometricoAdulto(id) == null) {
                    throw new NonexistentEntityException("The analisisCefalometricoAdulto with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisCefalometricoAdulto analisisCefalometricoAdulto;
            try {
                analisisCefalometricoAdulto = em.getReference(AnalisisCefalometricoAdulto.class, id);
                analisisCefalometricoAdulto.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The analisisCefalometricoAdulto with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<ResultadoAdulto> resultadoAdultoCollectionOrphanCheck = analisisCefalometricoAdulto.getResultadoAdultoCollection();
            for (ResultadoAdulto resultadoAdultoCollectionOrphanCheckResultadoAdulto : resultadoAdultoCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This AnalisisCefalometricoAdulto (" + analisisCefalometricoAdulto + ") cannot be destroyed since the ResultadoAdulto " + resultadoAdultoCollectionOrphanCheckResultadoAdulto + " in its resultadoAdultoCollection field has a non-nullable analisisCefalometricoAdultoId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Tratamiento tratamientoId = analisisCefalometricoAdulto.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.setAnalisisCefalometricoAdulto(null);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(analisisCefalometricoAdulto);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<AnalisisCefalometricoAdulto> findAnalisisCefalometricoAdultoEntities() {
        return findAnalisisCefalometricoAdultoEntities(true, -1, -1);
    }

    public List<AnalisisCefalometricoAdulto> findAnalisisCefalometricoAdultoEntities(int maxResults, int firstResult) {
        return findAnalisisCefalometricoAdultoEntities(false, maxResults, firstResult);
    }

    private List<AnalisisCefalometricoAdulto> findAnalisisCefalometricoAdultoEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(AnalisisCefalometricoAdulto.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public AnalisisCefalometricoAdulto findAnalisisCefalometricoAdulto(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(AnalisisCefalometricoAdulto.class, id);
        } finally {
            em.close();
        }
    }

    public int getAnalisisCefalometricoAdultoCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<AnalisisCefalometricoAdulto> rt = cq.from(AnalisisCefalometricoAdulto.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
