/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import entidades.AnalisisCefalometricoNinos;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import entidades.ResultadosNinos;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AnalisisCefalometricoNinosJpaController implements Serializable {

    public AnalisisCefalometricoNinosJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(AnalisisCefalometricoNinos analisisCefalometricoNinos) throws IllegalOrphanException {
        if (analisisCefalometricoNinos.getResultadosNinosCollection() == null) {
            analisisCefalometricoNinos.setResultadosNinosCollection(new ArrayList<ResultadosNinos>());
        }
        List<String> illegalOrphanMessages = null;
        Tratamiento tratamientoIdOrphanCheck = analisisCefalometricoNinos.getTratamientoId();
        if (tratamientoIdOrphanCheck != null) {
            AnalisisCefalometricoNinos oldAnalisisCefalometricoNinosOfTratamientoId = tratamientoIdOrphanCheck.getAnalisisCefalometricoNinos();
            if (oldAnalisisCefalometricoNinosOfTratamientoId != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The Tratamiento " + tratamientoIdOrphanCheck + " already has an item of type AnalisisCefalometricoNinos whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
            }
        }
        if (illegalOrphanMessages != null) {
            throw new IllegalOrphanException(illegalOrphanMessages);
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = analisisCefalometricoNinos.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                analisisCefalometricoNinos.setTratamientoId(tratamientoId);
            }
            Collection<ResultadosNinos> attachedResultadosNinosCollection = new ArrayList<ResultadosNinos>();
            for (ResultadosNinos resultadosNinosCollectionResultadosNinosToAttach : analisisCefalometricoNinos.getResultadosNinosCollection()) {
                resultadosNinosCollectionResultadosNinosToAttach = em.getReference(resultadosNinosCollectionResultadosNinosToAttach.getClass(), resultadosNinosCollectionResultadosNinosToAttach.getId());
                attachedResultadosNinosCollection.add(resultadosNinosCollectionResultadosNinosToAttach);
            }
            analisisCefalometricoNinos.setResultadosNinosCollection(attachedResultadosNinosCollection);
            em.persist(analisisCefalometricoNinos);
            if (tratamientoId != null) {
                tratamientoId.setAnalisisCefalometricoNinos(analisisCefalometricoNinos);
                tratamientoId = em.merge(tratamientoId);
            }
            for (ResultadosNinos resultadosNinosCollectionResultadosNinos : analisisCefalometricoNinos.getResultadosNinosCollection()) {
                AnalisisCefalometricoNinos oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionResultadosNinos = resultadosNinosCollectionResultadosNinos.getAnalisisCefalometricoNinosId();
                resultadosNinosCollectionResultadosNinos.setAnalisisCefalometricoNinosId(analisisCefalometricoNinos);
                resultadosNinosCollectionResultadosNinos = em.merge(resultadosNinosCollectionResultadosNinos);
                if (oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionResultadosNinos != null) {
                    oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionResultadosNinos.getResultadosNinosCollection().remove(resultadosNinosCollectionResultadosNinos);
                    oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionResultadosNinos = em.merge(oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionResultadosNinos);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(AnalisisCefalometricoNinos analisisCefalometricoNinos) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisCefalometricoNinos persistentAnalisisCefalometricoNinos = em.find(AnalisisCefalometricoNinos.class, analisisCefalometricoNinos.getId());
            Tratamiento tratamientoIdOld = persistentAnalisisCefalometricoNinos.getTratamientoId();
            Tratamiento tratamientoIdNew = analisisCefalometricoNinos.getTratamientoId();
            Collection<ResultadosNinos> resultadosNinosCollectionOld = persistentAnalisisCefalometricoNinos.getResultadosNinosCollection();
            Collection<ResultadosNinos> resultadosNinosCollectionNew = analisisCefalometricoNinos.getResultadosNinosCollection();
            List<String> illegalOrphanMessages = null;
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain Tratamiento " + tratamientoIdOld + " since its analisisCefalometricoNinos field is not nullable.");
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                AnalisisCefalometricoNinos oldAnalisisCefalometricoNinosOfTratamientoId = tratamientoIdNew.getAnalisisCefalometricoNinos();
                if (oldAnalisisCefalometricoNinosOfTratamientoId != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The Tratamiento " + tratamientoIdNew + " already has an item of type AnalisisCefalometricoNinos whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
                }
            }
            for (ResultadosNinos resultadosNinosCollectionOldResultadosNinos : resultadosNinosCollectionOld) {
                if (!resultadosNinosCollectionNew.contains(resultadosNinosCollectionOldResultadosNinos)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain ResultadosNinos " + resultadosNinosCollectionOldResultadosNinos + " since its analisisCefalometricoNinosId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                analisisCefalometricoNinos.setTratamientoId(tratamientoIdNew);
            }
            Collection<ResultadosNinos> attachedResultadosNinosCollectionNew = new ArrayList<ResultadosNinos>();
            for (ResultadosNinos resultadosNinosCollectionNewResultadosNinosToAttach : resultadosNinosCollectionNew) {
                resultadosNinosCollectionNewResultadosNinosToAttach = em.getReference(resultadosNinosCollectionNewResultadosNinosToAttach.getClass(), resultadosNinosCollectionNewResultadosNinosToAttach.getId());
                attachedResultadosNinosCollectionNew.add(resultadosNinosCollectionNewResultadosNinosToAttach);
            }
            resultadosNinosCollectionNew = attachedResultadosNinosCollectionNew;
            analisisCefalometricoNinos.setResultadosNinosCollection(resultadosNinosCollectionNew);
            analisisCefalometricoNinos = em.merge(analisisCefalometricoNinos);
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.setAnalisisCefalometricoNinos(analisisCefalometricoNinos);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            for (ResultadosNinos resultadosNinosCollectionNewResultadosNinos : resultadosNinosCollectionNew) {
                if (!resultadosNinosCollectionOld.contains(resultadosNinosCollectionNewResultadosNinos)) {
                    AnalisisCefalometricoNinos oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionNewResultadosNinos = resultadosNinosCollectionNewResultadosNinos.getAnalisisCefalometricoNinosId();
                    resultadosNinosCollectionNewResultadosNinos.setAnalisisCefalometricoNinosId(analisisCefalometricoNinos);
                    resultadosNinosCollectionNewResultadosNinos = em.merge(resultadosNinosCollectionNewResultadosNinos);
                    if (oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionNewResultadosNinos != null && !oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionNewResultadosNinos.equals(analisisCefalometricoNinos)) {
                        oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionNewResultadosNinos.getResultadosNinosCollection().remove(resultadosNinosCollectionNewResultadosNinos);
                        oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionNewResultadosNinos = em.merge(oldAnalisisCefalometricoNinosIdOfResultadosNinosCollectionNewResultadosNinos);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = analisisCefalometricoNinos.getId();
                if (findAnalisisCefalometricoNinos(id) == null) {
                    throw new NonexistentEntityException("The analisisCefalometricoNinos with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisCefalometricoNinos analisisCefalometricoNinos;
            try {
                analisisCefalometricoNinos = em.getReference(AnalisisCefalometricoNinos.class, id);
                analisisCefalometricoNinos.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The analisisCefalometricoNinos with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Tratamiento tratamientoIdOrphanCheck = analisisCefalometricoNinos.getTratamientoId();
            if (tratamientoIdOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This AnalisisCefalometricoNinos (" + analisisCefalometricoNinos + ") cannot be destroyed since the Tratamiento " + tratamientoIdOrphanCheck + " in its tratamientoId field has a non-nullable analisisCefalometricoNinos field.");
            }
            Collection<ResultadosNinos> resultadosNinosCollectionOrphanCheck = analisisCefalometricoNinos.getResultadosNinosCollection();
            for (ResultadosNinos resultadosNinosCollectionOrphanCheckResultadosNinos : resultadosNinosCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This AnalisisCefalometricoNinos (" + analisisCefalometricoNinos + ") cannot be destroyed since the ResultadosNinos " + resultadosNinosCollectionOrphanCheckResultadosNinos + " in its resultadosNinosCollection field has a non-nullable analisisCefalometricoNinosId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            em.remove(analisisCefalometricoNinos);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<AnalisisCefalometricoNinos> findAnalisisCefalometricoNinosEntities() {
        return findAnalisisCefalometricoNinosEntities(true, -1, -1);
    }

    public List<AnalisisCefalometricoNinos> findAnalisisCefalometricoNinosEntities(int maxResults, int firstResult) {
        return findAnalisisCefalometricoNinosEntities(false, maxResults, firstResult);
    }

    private List<AnalisisCefalometricoNinos> findAnalisisCefalometricoNinosEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(AnalisisCefalometricoNinos.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public AnalisisCefalometricoNinos findAnalisisCefalometricoNinos(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(AnalisisCefalometricoNinos.class, id);
        } finally {
            em.close();
        }
    }

    public int getAnalisisCefalometricoNinosCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<AnalisisCefalometricoNinos> rt = cq.from(AnalisisCefalometricoNinos.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
