/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import entidades.AnalisisDeEspacio;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import entidades.PlanTratamiento;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AnalisisDeEspacioJpaController implements Serializable {

    public AnalisisDeEspacioJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(AnalisisDeEspacio analisisDeEspacio) throws IllegalOrphanException {
        if (analisisDeEspacio.getPlanTratamientoCollection() == null) {
            analisisDeEspacio.setPlanTratamientoCollection(new ArrayList<PlanTratamiento>());
        }
        List<String> illegalOrphanMessages = null;
        Tratamiento tratamientoIdOrphanCheck = analisisDeEspacio.getTratamientoId();
        if (tratamientoIdOrphanCheck != null) {
            AnalisisDeEspacio oldAnalisisDeEspacioOfTratamientoId = tratamientoIdOrphanCheck.getAnalisisDeEspacio();
            if (oldAnalisisDeEspacioOfTratamientoId != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The Tratamiento " + tratamientoIdOrphanCheck + " already has an item of type AnalisisDeEspacio whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
            }
        }
        if (illegalOrphanMessages != null) {
            throw new IllegalOrphanException(illegalOrphanMessages);
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = analisisDeEspacio.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                analisisDeEspacio.setTratamientoId(tratamientoId);
            }
            Collection<PlanTratamiento> attachedPlanTratamientoCollection = new ArrayList<PlanTratamiento>();
            for (PlanTratamiento planTratamientoCollectionPlanTratamientoToAttach : analisisDeEspacio.getPlanTratamientoCollection()) {
                planTratamientoCollectionPlanTratamientoToAttach = em.getReference(planTratamientoCollectionPlanTratamientoToAttach.getClass(), planTratamientoCollectionPlanTratamientoToAttach.getId());
                attachedPlanTratamientoCollection.add(planTratamientoCollectionPlanTratamientoToAttach);
            }
            analisisDeEspacio.setPlanTratamientoCollection(attachedPlanTratamientoCollection);
            em.persist(analisisDeEspacio);
            if (tratamientoId != null) {
                tratamientoId.setAnalisisDeEspacio(analisisDeEspacio);
                tratamientoId = em.merge(tratamientoId);
            }
            for (PlanTratamiento planTratamientoCollectionPlanTratamiento : analisisDeEspacio.getPlanTratamientoCollection()) {
                AnalisisDeEspacio oldAnalisisDeEspacioIdOfPlanTratamientoCollectionPlanTratamiento = planTratamientoCollectionPlanTratamiento.getAnalisisDeEspacioId();
                planTratamientoCollectionPlanTratamiento.setAnalisisDeEspacioId(analisisDeEspacio);
                planTratamientoCollectionPlanTratamiento = em.merge(planTratamientoCollectionPlanTratamiento);
                if (oldAnalisisDeEspacioIdOfPlanTratamientoCollectionPlanTratamiento != null) {
                    oldAnalisisDeEspacioIdOfPlanTratamientoCollectionPlanTratamiento.getPlanTratamientoCollection().remove(planTratamientoCollectionPlanTratamiento);
                    oldAnalisisDeEspacioIdOfPlanTratamientoCollectionPlanTratamiento = em.merge(oldAnalisisDeEspacioIdOfPlanTratamientoCollectionPlanTratamiento);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(AnalisisDeEspacio analisisDeEspacio) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisDeEspacio persistentAnalisisDeEspacio = em.find(AnalisisDeEspacio.class, analisisDeEspacio.getId());
            Tratamiento tratamientoIdOld = persistentAnalisisDeEspacio.getTratamientoId();
            Tratamiento tratamientoIdNew = analisisDeEspacio.getTratamientoId();
            Collection<PlanTratamiento> planTratamientoCollectionOld = persistentAnalisisDeEspacio.getPlanTratamientoCollection();
            Collection<PlanTratamiento> planTratamientoCollectionNew = analisisDeEspacio.getPlanTratamientoCollection();
            List<String> illegalOrphanMessages = null;
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                AnalisisDeEspacio oldAnalisisDeEspacioOfTratamientoId = tratamientoIdNew.getAnalisisDeEspacio();
                if (oldAnalisisDeEspacioOfTratamientoId != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The Tratamiento " + tratamientoIdNew + " already has an item of type AnalisisDeEspacio whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
                }
            }
            for (PlanTratamiento planTratamientoCollectionOldPlanTratamiento : planTratamientoCollectionOld) {
                if (!planTratamientoCollectionNew.contains(planTratamientoCollectionOldPlanTratamiento)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain PlanTratamiento " + planTratamientoCollectionOldPlanTratamiento + " since its analisisDeEspacioId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                analisisDeEspacio.setTratamientoId(tratamientoIdNew);
            }
            Collection<PlanTratamiento> attachedPlanTratamientoCollectionNew = new ArrayList<PlanTratamiento>();
            for (PlanTratamiento planTratamientoCollectionNewPlanTratamientoToAttach : planTratamientoCollectionNew) {
                planTratamientoCollectionNewPlanTratamientoToAttach = em.getReference(planTratamientoCollectionNewPlanTratamientoToAttach.getClass(), planTratamientoCollectionNewPlanTratamientoToAttach.getId());
                attachedPlanTratamientoCollectionNew.add(planTratamientoCollectionNewPlanTratamientoToAttach);
            }
            planTratamientoCollectionNew = attachedPlanTratamientoCollectionNew;
            analisisDeEspacio.setPlanTratamientoCollection(planTratamientoCollectionNew);
            analisisDeEspacio = em.merge(analisisDeEspacio);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.setAnalisisDeEspacio(null);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.setAnalisisDeEspacio(analisisDeEspacio);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            for (PlanTratamiento planTratamientoCollectionNewPlanTratamiento : planTratamientoCollectionNew) {
                if (!planTratamientoCollectionOld.contains(planTratamientoCollectionNewPlanTratamiento)) {
                    AnalisisDeEspacio oldAnalisisDeEspacioIdOfPlanTratamientoCollectionNewPlanTratamiento = planTratamientoCollectionNewPlanTratamiento.getAnalisisDeEspacioId();
                    planTratamientoCollectionNewPlanTratamiento.setAnalisisDeEspacioId(analisisDeEspacio);
                    planTratamientoCollectionNewPlanTratamiento = em.merge(planTratamientoCollectionNewPlanTratamiento);
                    if (oldAnalisisDeEspacioIdOfPlanTratamientoCollectionNewPlanTratamiento != null && !oldAnalisisDeEspacioIdOfPlanTratamientoCollectionNewPlanTratamiento.equals(analisisDeEspacio)) {
                        oldAnalisisDeEspacioIdOfPlanTratamientoCollectionNewPlanTratamiento.getPlanTratamientoCollection().remove(planTratamientoCollectionNewPlanTratamiento);
                        oldAnalisisDeEspacioIdOfPlanTratamientoCollectionNewPlanTratamiento = em.merge(oldAnalisisDeEspacioIdOfPlanTratamientoCollectionNewPlanTratamiento);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = analisisDeEspacio.getId();
                if (findAnalisisDeEspacio(id) == null) {
                    throw new NonexistentEntityException("The analisisDeEspacio with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisDeEspacio analisisDeEspacio;
            try {
                analisisDeEspacio = em.getReference(AnalisisDeEspacio.class, id);
                analisisDeEspacio.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The analisisDeEspacio with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<PlanTratamiento> planTratamientoCollectionOrphanCheck = analisisDeEspacio.getPlanTratamientoCollection();
            for (PlanTratamiento planTratamientoCollectionOrphanCheckPlanTratamiento : planTratamientoCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This AnalisisDeEspacio (" + analisisDeEspacio + ") cannot be destroyed since the PlanTratamiento " + planTratamientoCollectionOrphanCheckPlanTratamiento + " in its planTratamientoCollection field has a non-nullable analisisDeEspacioId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Tratamiento tratamientoId = analisisDeEspacio.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.setAnalisisDeEspacio(null);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(analisisDeEspacio);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<AnalisisDeEspacio> findAnalisisDeEspacioEntities() {
        return findAnalisisDeEspacioEntities(true, -1, -1);
    }

    public List<AnalisisDeEspacio> findAnalisisDeEspacioEntities(int maxResults, int firstResult) {
        return findAnalisisDeEspacioEntities(false, maxResults, firstResult);
    }

    private List<AnalisisDeEspacio> findAnalisisDeEspacioEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(AnalisisDeEspacio.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public AnalisisDeEspacio findAnalisisDeEspacio(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(AnalisisDeEspacio.class, id);
        } finally {
            em.close();
        }
    }

    public int getAnalisisDeEspacioCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<AnalisisDeEspacio> rt = cq.from(AnalisisDeEspacio.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
