/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import entidades.historia.AnexosRadiografia;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.historia.HistoriaClinica;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AnexosRadiografiaJpaController implements Serializable {

    public AnexosRadiografiaJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(AnexosRadiografia anexosRadiografia) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            HistoriaClinica historiaId = anexosRadiografia.getHistoriaId();
            if (historiaId != null) {
                historiaId = em.getReference(historiaId.getClass(), historiaId.getId());
                anexosRadiografia.setHistoriaId(historiaId);
            }
            em.persist(anexosRadiografia);
            if (historiaId != null) {
                historiaId.getAnexosRadiografia().add(anexosRadiografia);
                historiaId = em.merge(historiaId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(AnexosRadiografia anexosRadiografia) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnexosRadiografia persistentAnexosRadiografia = em.find(AnexosRadiografia.class, anexosRadiografia.getId());
            HistoriaClinica historiaIdOld = persistentAnexosRadiografia.getHistoriaId();
            HistoriaClinica historiaIdNew = anexosRadiografia.getHistoriaId();
            if (historiaIdNew != null) {
                historiaIdNew = em.getReference(historiaIdNew.getClass(), historiaIdNew.getId());
                anexosRadiografia.setHistoriaId(historiaIdNew);
            }
            anexosRadiografia = em.merge(anexosRadiografia);
            if (historiaIdOld != null && !historiaIdOld.equals(historiaIdNew)) {
                historiaIdOld.getAnexosRadiografia().remove(anexosRadiografia);
                historiaIdOld = em.merge(historiaIdOld);
            }
            if (historiaIdNew != null && !historiaIdNew.equals(historiaIdOld)) {
                historiaIdNew.getAnexosRadiografia().add(anexosRadiografia);
                historiaIdNew = em.merge(historiaIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = anexosRadiografia.getId();
                if (findAnexosRadiografia(id) == null) {
                    throw new NonexistentEntityException("The anexosRadiografia with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnexosRadiografia anexosRadiografia;
            try {
                anexosRadiografia = em.getReference(AnexosRadiografia.class, id);
                anexosRadiografia.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The anexosRadiografia with id " + id + " no longer exists.", enfe);
            }
            HistoriaClinica historiaId = anexosRadiografia.getHistoriaId();
            if (historiaId != null) {
                historiaId.getAnexosRadiografia().remove(anexosRadiografia);
                historiaId = em.merge(historiaId);
            }
            em.remove(anexosRadiografia);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<AnexosRadiografia> findAnexosRadiografiaEntities() {
        return findAnexosRadiografiaEntities(true, -1, -1);
    }

    public List<AnexosRadiografia> findAnexosRadiografiaEntities(int maxResults, int firstResult) {
        return findAnexosRadiografiaEntities(false, maxResults, firstResult);
    }

    private List<AnexosRadiografia> findAnexosRadiografiaEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(AnexosRadiografia.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public AnexosRadiografia findAnexosRadiografia(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(AnexosRadiografia.class, id);
        } finally {
            em.close();
        }
    }

    public int getAnexosRadiografiaCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<AnexosRadiografia> rt = cq.from(AnexosRadiografia.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
