/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import controladores.exceptions.PreexistingEntityException;
import entidades.Area;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Personal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AreaJpaController implements Serializable {

    public AreaJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Area area) throws PreexistingEntityException, Exception {
        if (area.getMedicoCollection() == null) {
            area.setMedicoCollection(new ArrayList<Personal>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Collection<Personal> attachedMedicoCollection = new ArrayList<Personal>();
            for (Personal medicoCollectionPersonalToAttach : area.getMedicoCollection()) {
                medicoCollectionPersonalToAttach = em.getReference(medicoCollectionPersonalToAttach.getClass(), medicoCollectionPersonalToAttach.getId());
                attachedMedicoCollection.add(medicoCollectionPersonalToAttach);
            }
            area.setMedicoCollection(attachedMedicoCollection);
            em.persist(area);
            for (Personal medicoCollectionPersonal : area.getMedicoCollection()) {
                Area oldAreaIdOfMedicoCollectionPersonal = medicoCollectionPersonal.getAreaId();
                medicoCollectionPersonal.setAreaId(area);
                medicoCollectionPersonal = em.merge(medicoCollectionPersonal);
                if (oldAreaIdOfMedicoCollectionPersonal != null) {
                    oldAreaIdOfMedicoCollectionPersonal.getMedicoCollection().remove(medicoCollectionPersonal);
                    oldAreaIdOfMedicoCollectionPersonal = em.merge(oldAreaIdOfMedicoCollectionPersonal);
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            if (findArea(area.getId()) != null) {
                throw new PreexistingEntityException("Area " + area + " already exists.", ex);
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Area area) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Area persistentArea = em.find(Area.class, area.getId());
            Collection<Personal> medicoCollectionOld = persistentArea.getMedicoCollection();
            Collection<Personal> medicoCollectionNew = area.getMedicoCollection();
            List<String> illegalOrphanMessages = null;
            for (Personal medicoCollectionOldPersonal : medicoCollectionOld) {
                if (!medicoCollectionNew.contains(medicoCollectionOldPersonal)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Personal " + medicoCollectionOldPersonal + " since its areaId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Collection<Personal> attachedMedicoCollectionNew = new ArrayList<Personal>();
            for (Personal medicoCollectionNewPersonalToAttach : medicoCollectionNew) {
                medicoCollectionNewPersonalToAttach = em.getReference(medicoCollectionNewPersonalToAttach.getClass(), medicoCollectionNewPersonalToAttach.getId());
                attachedMedicoCollectionNew.add(medicoCollectionNewPersonalToAttach);
            }
            medicoCollectionNew = attachedMedicoCollectionNew;
            area.setMedicoCollection(medicoCollectionNew);
            area = em.merge(area);
            for (Personal medicoCollectionNewPersonal : medicoCollectionNew) {
                if (!medicoCollectionOld.contains(medicoCollectionNewPersonal)) {
                    Area oldAreaIdOfMedicoCollectionNewPersonal = medicoCollectionNewPersonal.getAreaId();
                    medicoCollectionNewPersonal.setAreaId(area);
                    medicoCollectionNewPersonal = em.merge(medicoCollectionNewPersonal);
                    if (oldAreaIdOfMedicoCollectionNewPersonal != null && !oldAreaIdOfMedicoCollectionNewPersonal.equals(area)) {
                        oldAreaIdOfMedicoCollectionNewPersonal.getMedicoCollection().remove(medicoCollectionNewPersonal);
                        oldAreaIdOfMedicoCollectionNewPersonal = em.merge(oldAreaIdOfMedicoCollectionNewPersonal);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = area.getId();
                if (findArea(id) == null) {
                    throw new NonexistentEntityException("The area with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Area area;
            try {
                area = em.getReference(Area.class, id);
                area.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The area with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<Personal> medicoCollectionOrphanCheck = area.getMedicoCollection();
            for (Personal medicoCollectionOrphanCheckPersonal : medicoCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Area (" + area + ") cannot be destroyed since the Personal " + medicoCollectionOrphanCheckPersonal + " in its medicoCollection field has a non-nullable areaId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            em.remove(area);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Area> findAreaEntities() {
        return findAreaEntities(true, -1, -1);
    }

    public List<Area> findAreaEntities(int maxResults, int firstResult) {
        return findAreaEntities(false, maxResults, firstResult);
    }

    private List<Area> findAreaEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Area.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Area findArea(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Area.class, id);
        } finally {
            em.close();
        }
    }

    public int getAreaCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Area> rt = cq.from(Area.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
