/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import entidades.AutorizacionAdulto;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import java.util.ArrayList;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AutorizacionAdultoJpaController implements Serializable {

    public AutorizacionAdultoJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(AutorizacionAdulto autorizacionAdulto) throws IllegalOrphanException {
        List<String> illegalOrphanMessages = null;
        Tratamiento tratamientoIdOrphanCheck = autorizacionAdulto.getTratamientoId();
        if (tratamientoIdOrphanCheck != null) {
            AutorizacionAdulto oldAutorizacionAdultoOfTratamientoId = tratamientoIdOrphanCheck.getAutorizacionAdulto();
            if (oldAutorizacionAdultoOfTratamientoId != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The Tratamiento " + tratamientoIdOrphanCheck + " already has an item of type AutorizacionAdulto whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
            }
        }
        if (illegalOrphanMessages != null) {
            throw new IllegalOrphanException(illegalOrphanMessages);
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = autorizacionAdulto.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                autorizacionAdulto.setTratamientoId(tratamientoId);
            }
            em.persist(autorizacionAdulto);
            if (tratamientoId != null) {
                tratamientoId.setAutorizacionAdulto(autorizacionAdulto);
                tratamientoId = em.merge(tratamientoId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(AutorizacionAdulto autorizacionAdulto) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AutorizacionAdulto persistentAutorizacionAdulto = em.find(AutorizacionAdulto.class, autorizacionAdulto.getId());
            Tratamiento tratamientoIdOld = persistentAutorizacionAdulto.getTratamientoId();
            Tratamiento tratamientoIdNew = autorizacionAdulto.getTratamientoId();
            List<String> illegalOrphanMessages = null;
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                AutorizacionAdulto oldAutorizacionAdultoOfTratamientoId = tratamientoIdNew.getAutorizacionAdulto();
                if (oldAutorizacionAdultoOfTratamientoId != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The Tratamiento " + tratamientoIdNew + " already has an item of type AutorizacionAdulto whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                autorizacionAdulto.setTratamientoId(tratamientoIdNew);
            }
            autorizacionAdulto = em.merge(autorizacionAdulto);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.setAutorizacionAdulto(null);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.setAutorizacionAdulto(autorizacionAdulto);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = autorizacionAdulto.getId();
                if (findAutorizacionAdulto(id) == null) {
                    throw new NonexistentEntityException("The autorizacionAdulto with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AutorizacionAdulto autorizacionAdulto;
            try {
                autorizacionAdulto = em.getReference(AutorizacionAdulto.class, id);
                autorizacionAdulto.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The autorizacionAdulto with id " + id + " no longer exists.", enfe);
            }
            Tratamiento tratamientoId = autorizacionAdulto.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.setAutorizacionAdulto(null);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(autorizacionAdulto);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<AutorizacionAdulto> findAutorizacionAdultoEntities() {
        return findAutorizacionAdultoEntities(true, -1, -1);
    }

    public List<AutorizacionAdulto> findAutorizacionAdultoEntities(int maxResults, int firstResult) {
        return findAutorizacionAdultoEntities(false, maxResults, firstResult);
    }

    private List<AutorizacionAdulto> findAutorizacionAdultoEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(AutorizacionAdulto.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public AutorizacionAdulto findAutorizacionAdulto(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(AutorizacionAdulto.class, id);
        } finally {
            em.close();
        }
    }

    public int getAutorizacionAdultoCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<AutorizacionAdulto> rt = cq.from(AutorizacionAdulto.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
