/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import entidades.Autorizacion;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import java.util.ArrayList;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class AutorizacionJpaController implements Serializable {

    public AutorizacionJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Autorizacion autorizacion) throws IllegalOrphanException {
        List<String> illegalOrphanMessages = null;
        Tratamiento tratamientoIdOrphanCheck = autorizacion.getTratamientoId();
        if (tratamientoIdOrphanCheck != null) {
            Autorizacion oldAutorizacionOfTratamientoId = tratamientoIdOrphanCheck.getAutorizacion();
            if (oldAutorizacionOfTratamientoId != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The Tratamiento " + tratamientoIdOrphanCheck + " already has an item of type Autorizacion whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
            }
        }
        if (illegalOrphanMessages != null) {
            throw new IllegalOrphanException(illegalOrphanMessages);
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = autorizacion.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                autorizacion.setTratamientoId(tratamientoId);
            }
            em.persist(autorizacion);
            if (tratamientoId != null) {
                tratamientoId.setAutorizacion(autorizacion);
                tratamientoId = em.merge(tratamientoId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Autorizacion autorizacion) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Autorizacion persistentAutorizacion = em.find(Autorizacion.class, autorizacion.getId());
            Tratamiento tratamientoIdOld = persistentAutorizacion.getTratamientoId();
            Tratamiento tratamientoIdNew = autorizacion.getTratamientoId();
            List<String> illegalOrphanMessages = null;
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                Autorizacion oldAutorizacionOfTratamientoId = tratamientoIdNew.getAutorizacion();
                if (oldAutorizacionOfTratamientoId != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The Tratamiento " + tratamientoIdNew + " already has an item of type Autorizacion whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                autorizacion.setTratamientoId(tratamientoIdNew);
            }
            autorizacion = em.merge(autorizacion);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.setAutorizacion(null);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.setAutorizacion(autorizacion);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = autorizacion.getId();
                if (findAutorizacion(id) == null) {
                    throw new NonexistentEntityException("The autorizacion with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Autorizacion autorizacion;
            try {
                autorizacion = em.getReference(Autorizacion.class, id);
                autorizacion.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The autorizacion with id " + id + " no longer exists.", enfe);
            }
            Tratamiento tratamientoId = autorizacion.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.setAutorizacion(null);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(autorizacion);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Autorizacion> findAutorizacionEntities() {
        return findAutorizacionEntities(true, -1, -1);
    }

    public List<Autorizacion> findAutorizacionEntities(int maxResults, int firstResult) {
        return findAutorizacionEntities(false, maxResults, firstResult);
    }

    private List<Autorizacion> findAutorizacionEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Autorizacion.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Autorizacion findAutorizacion(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Autorizacion.class, id);
        } finally {
            em.close();
        }
    }

    public int getAutorizacionCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Autorizacion> rt = cq.from(Autorizacion.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
