/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import entidades.Citas;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.EstadoCita;
import entidades.Paciente;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class CitasJpaController implements Serializable {

    public CitasJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Citas citas) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            EstadoCita estadoCitaId = citas.getEstadoCitaId();
            if (estadoCitaId != null) {
                estadoCitaId = em.getReference(estadoCitaId.getClass(), estadoCitaId.getId());
                citas.setEstadoCitaId(estadoCitaId);
            }
            Paciente pacienteId = citas.getPacienteId();
            if (pacienteId != null) {
                pacienteId = em.getReference(pacienteId.getClass(), pacienteId.getId());
                citas.setPacienteId(pacienteId);
            }
            em.persist(citas);
            if (estadoCitaId != null) {
                estadoCitaId.getCitasCollection().add(citas);
                estadoCitaId = em.merge(estadoCitaId);
            }
            if (pacienteId != null) {
                pacienteId.getCitasCollection().add(citas);
                pacienteId = em.merge(pacienteId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Citas citas) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Citas persistentCitas = em.find(Citas.class, citas.getId());
            EstadoCita estadoCitaIdOld = persistentCitas.getEstadoCitaId();
            EstadoCita estadoCitaIdNew = citas.getEstadoCitaId();
            Paciente pacienteIdOld = persistentCitas.getPacienteId();
            Paciente pacienteIdNew = citas.getPacienteId();
            if (estadoCitaIdNew != null) {
                estadoCitaIdNew = em.getReference(estadoCitaIdNew.getClass(), estadoCitaIdNew.getId());
                citas.setEstadoCitaId(estadoCitaIdNew);
            }
            if (pacienteIdNew != null) {
                pacienteIdNew = em.getReference(pacienteIdNew.getClass(), pacienteIdNew.getId());
                citas.setPacienteId(pacienteIdNew);
            }
            citas = em.merge(citas);
            if (estadoCitaIdOld != null && !estadoCitaIdOld.equals(estadoCitaIdNew)) {
                estadoCitaIdOld.getCitasCollection().remove(citas);
                estadoCitaIdOld = em.merge(estadoCitaIdOld);
            }
            if (estadoCitaIdNew != null && !estadoCitaIdNew.equals(estadoCitaIdOld)) {
                estadoCitaIdNew.getCitasCollection().add(citas);
                estadoCitaIdNew = em.merge(estadoCitaIdNew);
            }
            if (pacienteIdOld != null && !pacienteIdOld.equals(pacienteIdNew)) {
                pacienteIdOld.getCitasCollection().remove(citas);
                pacienteIdOld = em.merge(pacienteIdOld);
            }
            if (pacienteIdNew != null && !pacienteIdNew.equals(pacienteIdOld)) {
                pacienteIdNew.getCitasCollection().add(citas);
                pacienteIdNew = em.merge(pacienteIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = citas.getId();
                if (findCitas(id) == null) {
                    throw new NonexistentEntityException("The citas with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Citas citas;
            try {
                citas = em.getReference(Citas.class, id);
                citas.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The citas with id " + id + " no longer exists.", enfe);
            }
            EstadoCita estadoCitaId = citas.getEstadoCitaId();
            if (estadoCitaId != null) {
                estadoCitaId.getCitasCollection().remove(citas);
                estadoCitaId = em.merge(estadoCitaId);
            }
            Paciente pacienteId = citas.getPacienteId();
            if (pacienteId != null) {
                pacienteId.getCitasCollection().remove(citas);
                pacienteId = em.merge(pacienteId);
            }
            em.remove(citas);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Citas> findCitasEntities() {
        return findCitasEntities(true, -1, -1);
    }

    public List<Citas> findCitasEntities(int maxResults, int firstResult) {
        return findCitasEntities(false, maxResults, firstResult);
    }

    private List<Citas> findCitasEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Citas.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Citas findCitas(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Citas.class, id);
        } finally {
            em.close();
        }
    }

    public int getCitasCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Citas> rt = cq.from(Citas.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
