/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import controladores.exceptions.PreexistingEntityException;
import entidades.Depto;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Muni;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class DeptoJpaController implements Serializable {

    public DeptoJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Depto depto) throws PreexistingEntityException, Exception {
        if (depto.getMuniCollection() == null) {
            depto.setMuniCollection(new ArrayList<Muni>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Collection<Muni> attachedMuniCollection = new ArrayList<Muni>();
            for (Muni muniCollectionMuniToAttach : depto.getMuniCollection()) {
                muniCollectionMuniToAttach = em.getReference(muniCollectionMuniToAttach.getClass(), muniCollectionMuniToAttach.getId());
                attachedMuniCollection.add(muniCollectionMuniToAttach);
            }
            depto.setMuniCollection(attachedMuniCollection);
            em.persist(depto);
            for (Muni muniCollectionMuni : depto.getMuniCollection()) {
                Depto oldDeptoCodigoOfMuniCollectionMuni = muniCollectionMuni.getDeptoCodigo();
                muniCollectionMuni.setDeptoCodigo(depto);
                muniCollectionMuni = em.merge(muniCollectionMuni);
                if (oldDeptoCodigoOfMuniCollectionMuni != null) {
                    oldDeptoCodigoOfMuniCollectionMuni.getMuniCollection().remove(muniCollectionMuni);
                    oldDeptoCodigoOfMuniCollectionMuni = em.merge(oldDeptoCodigoOfMuniCollectionMuni);
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            if (findDepto(depto.getCodigo()) != null) {
                throw new PreexistingEntityException("Depto " + depto + " already exists.", ex);
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Depto depto) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Depto persistentDepto = em.find(Depto.class, depto.getCodigo());
            Collection<Muni> muniCollectionOld = persistentDepto.getMuniCollection();
            Collection<Muni> muniCollectionNew = depto.getMuniCollection();
            List<String> illegalOrphanMessages = null;
            for (Muni muniCollectionOldMuni : muniCollectionOld) {
                if (!muniCollectionNew.contains(muniCollectionOldMuni)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Muni " + muniCollectionOldMuni + " since its deptoCodigo field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Collection<Muni> attachedMuniCollectionNew = new ArrayList<Muni>();
            for (Muni muniCollectionNewMuniToAttach : muniCollectionNew) {
                muniCollectionNewMuniToAttach = em.getReference(muniCollectionNewMuniToAttach.getClass(), muniCollectionNewMuniToAttach.getId());
                attachedMuniCollectionNew.add(muniCollectionNewMuniToAttach);
            }
            muniCollectionNew = attachedMuniCollectionNew;
            depto.setMuniCollection(muniCollectionNew);
            depto = em.merge(depto);
            for (Muni muniCollectionNewMuni : muniCollectionNew) {
                if (!muniCollectionOld.contains(muniCollectionNewMuni)) {
                    Depto oldDeptoCodigoOfMuniCollectionNewMuni = muniCollectionNewMuni.getDeptoCodigo();
                    muniCollectionNewMuni.setDeptoCodigo(depto);
                    muniCollectionNewMuni = em.merge(muniCollectionNewMuni);
                    if (oldDeptoCodigoOfMuniCollectionNewMuni != null && !oldDeptoCodigoOfMuniCollectionNewMuni.equals(depto)) {
                        oldDeptoCodigoOfMuniCollectionNewMuni.getMuniCollection().remove(muniCollectionNewMuni);
                        oldDeptoCodigoOfMuniCollectionNewMuni = em.merge(oldDeptoCodigoOfMuniCollectionNewMuni);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = depto.getCodigo();
                if (findDepto(id) == null) {
                    throw new NonexistentEntityException("The depto with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Depto depto;
            try {
                depto = em.getReference(Depto.class, id);
                depto.getCodigo();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The depto with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<Muni> muniCollectionOrphanCheck = depto.getMuniCollection();
            for (Muni muniCollectionOrphanCheckMuni : muniCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Depto (" + depto + ") cannot be destroyed since the Muni " + muniCollectionOrphanCheckMuni + " in its muniCollection field has a non-nullable deptoCodigo field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            em.remove(depto);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Depto> findDeptoEntities() {
        return findDeptoEntities(true, -1, -1);
    }

    public List<Depto> findDeptoEntities(int maxResults, int firstResult) {
        return findDeptoEntities(false, maxResults, firstResult);
    }

    private List<Depto> findDeptoEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Depto.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Depto findDepto(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Depto.class, id);
        } finally {
            em.close();
        }
    }

    public int getDeptoCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Depto> rt = cq.from(Depto.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
