/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import controladores.exceptions.PreexistingEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Citas;
import entidades.EstadoCita;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class EstadoCitaJpaController implements Serializable {

    public EstadoCitaJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(EstadoCita estadoCita) throws PreexistingEntityException, Exception {
        if (estadoCita.getCitasCollection() == null) {
            estadoCita.setCitasCollection(new ArrayList<Citas>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Collection<Citas> attachedCitasCollection = new ArrayList<Citas>();
            for (Citas citasCollectionCitasToAttach : estadoCita.getCitasCollection()) {
                citasCollectionCitasToAttach = em.getReference(citasCollectionCitasToAttach.getClass(), citasCollectionCitasToAttach.getId());
                attachedCitasCollection.add(citasCollectionCitasToAttach);
            }
            estadoCita.setCitasCollection(attachedCitasCollection);
            em.persist(estadoCita);
            for (Citas citasCollectionCitas : estadoCita.getCitasCollection()) {
                EstadoCita oldEstadoCitaIdOfCitasCollectionCitas = citasCollectionCitas.getEstadoCitaId();
                citasCollectionCitas.setEstadoCitaId(estadoCita);
                citasCollectionCitas = em.merge(citasCollectionCitas);
                if (oldEstadoCitaIdOfCitasCollectionCitas != null) {
                    oldEstadoCitaIdOfCitasCollectionCitas.getCitasCollection().remove(citasCollectionCitas);
                    oldEstadoCitaIdOfCitasCollectionCitas = em.merge(oldEstadoCitaIdOfCitasCollectionCitas);
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            if (findEstadoCita(estadoCita.getId()) != null) {
                throw new PreexistingEntityException("EstadoCita " + estadoCita + " already exists.", ex);
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(EstadoCita estadoCita) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            EstadoCita persistentEstadoCita = em.find(EstadoCita.class, estadoCita.getId());
            Collection<Citas> citasCollectionOld = persistentEstadoCita.getCitasCollection();
            Collection<Citas> citasCollectionNew = estadoCita.getCitasCollection();
            List<String> illegalOrphanMessages = null;
            for (Citas citasCollectionOldCitas : citasCollectionOld) {
                if (!citasCollectionNew.contains(citasCollectionOldCitas)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Citas " + citasCollectionOldCitas + " since its estadoCitaId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Collection<Citas> attachedCitasCollectionNew = new ArrayList<Citas>();
            for (Citas citasCollectionNewCitasToAttach : citasCollectionNew) {
                citasCollectionNewCitasToAttach = em.getReference(citasCollectionNewCitasToAttach.getClass(), citasCollectionNewCitasToAttach.getId());
                attachedCitasCollectionNew.add(citasCollectionNewCitasToAttach);
            }
            citasCollectionNew = attachedCitasCollectionNew;
            estadoCita.setCitasCollection(citasCollectionNew);
            estadoCita = em.merge(estadoCita);
            for (Citas citasCollectionNewCitas : citasCollectionNew) {
                if (!citasCollectionOld.contains(citasCollectionNewCitas)) {
                    EstadoCita oldEstadoCitaIdOfCitasCollectionNewCitas = citasCollectionNewCitas.getEstadoCitaId();
                    citasCollectionNewCitas.setEstadoCitaId(estadoCita);
                    citasCollectionNewCitas = em.merge(citasCollectionNewCitas);
                    if (oldEstadoCitaIdOfCitasCollectionNewCitas != null && !oldEstadoCitaIdOfCitasCollectionNewCitas.equals(estadoCita)) {
                        oldEstadoCitaIdOfCitasCollectionNewCitas.getCitasCollection().remove(citasCollectionNewCitas);
                        oldEstadoCitaIdOfCitasCollectionNewCitas = em.merge(oldEstadoCitaIdOfCitasCollectionNewCitas);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = estadoCita.getId();
                if (findEstadoCita(id) == null) {
                    throw new NonexistentEntityException("The estadoCita with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            EstadoCita estadoCita;
            try {
                estadoCita = em.getReference(EstadoCita.class, id);
                estadoCita.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The estadoCita with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<Citas> citasCollectionOrphanCheck = estadoCita.getCitasCollection();
            for (Citas citasCollectionOrphanCheckCitas : citasCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This EstadoCita (" + estadoCita + ") cannot be destroyed since the Citas " + citasCollectionOrphanCheckCitas + " in its citasCollection field has a non-nullable estadoCitaId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            em.remove(estadoCita);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<EstadoCita> findEstadoCitaEntities() {
        return findEstadoCitaEntities(true, -1, -1);
    }

    public List<EstadoCita> findEstadoCitaEntities(int maxResults, int firstResult) {
        return findEstadoCitaEntities(false, maxResults, firstResult);
    }

    private List<EstadoCita> findEstadoCitaEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(EstadoCita.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public EstadoCita findEstadoCita(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(EstadoCita.class, id);
        } finally {
            em.close();
        }
    }

    public int getEstadoCitaCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<EstadoCita> rt = cq.from(EstadoCita.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
