/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import entidades.Evolucion;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import entidades.Personal;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class EvolucionJpaController implements Serializable {

    public EvolucionJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Evolucion evolucion) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = evolucion.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                evolucion.setTratamientoId(tratamientoId);
            }
            Personal personalId = evolucion.getPersonalId();
            if (personalId != null) {
                personalId = em.getReference(personalId.getClass(), personalId.getId());
                evolucion.setPersonalId(personalId);
            }
            em.persist(evolucion);
            if (tratamientoId != null) {
                tratamientoId.getEvolucion().add(evolucion);
                tratamientoId = em.merge(tratamientoId);
            }
            if (personalId != null) {
                personalId.getEvolucionCollection().add(evolucion);
                personalId = em.merge(personalId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Evolucion evolucion) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Evolucion persistentEvolucion = em.find(Evolucion.class, evolucion.getId());
            Tratamiento tratamientoIdOld = persistentEvolucion.getTratamientoId();
            Tratamiento tratamientoIdNew = evolucion.getTratamientoId();
            Personal personalIdOld = persistentEvolucion.getPersonalId();
            Personal personalIdNew = evolucion.getPersonalId();
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                evolucion.setTratamientoId(tratamientoIdNew);
            }
            if (personalIdNew != null) {
                personalIdNew = em.getReference(personalIdNew.getClass(), personalIdNew.getId());
                evolucion.setPersonalId(personalIdNew);
            }
            evolucion = em.merge(evolucion);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.getEvolucion().remove(evolucion);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.getEvolucion().add(evolucion);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            if (personalIdOld != null && !personalIdOld.equals(personalIdNew)) {
                personalIdOld.getEvolucionCollection().remove(evolucion);
                personalIdOld = em.merge(personalIdOld);
            }
            if (personalIdNew != null && !personalIdNew.equals(personalIdOld)) {
                personalIdNew.getEvolucionCollection().add(evolucion);
                personalIdNew = em.merge(personalIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = evolucion.getId();
                if (findEvolucion(id) == null) {
                    throw new NonexistentEntityException("The evolucion with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Evolucion evolucion;
            try {
                evolucion = em.getReference(Evolucion.class, id);
                evolucion.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The evolucion with id " + id + " no longer exists.", enfe);
            }
            Tratamiento tratamientoId = evolucion.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.getEvolucion().remove(evolucion);
                tratamientoId = em.merge(tratamientoId);
            }
            Personal personalId = evolucion.getPersonalId();
            if (personalId != null) {
                personalId.getEvolucionCollection().remove(evolucion);
                personalId = em.merge(personalId);
            }
            em.remove(evolucion);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Evolucion> findEvolucionEntities() {
        return findEvolucionEntities(true, -1, -1);
    }

    public List<Evolucion> findEvolucionEntities(int maxResults, int firstResult) {
        return findEvolucionEntities(false, maxResults, firstResult);
    }

    private List<Evolucion> findEvolucionEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Evolucion.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Evolucion findEvolucion(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Evolucion.class, id);
        } finally {
            em.close();
        }
    }

    public int getEvolucionCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Evolucion> rt = cq.from(Evolucion.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
