/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import entidades.historia.AnexosRadiografia;
import entidades.historia.HistoriaClinica;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class HistoriaClinicaJpaController implements Serializable {

    public HistoriaClinicaJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(HistoriaClinica historiaClinica) {
        if (historiaClinica.getAnexosRadiografia() == null) {
            historiaClinica.setAnexosRadiografia(new ArrayList<AnexosRadiografia>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = historiaClinica.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                historiaClinica.setTratamientoId(tratamientoId);
            }
            Collection<AnexosRadiografia> attachedAnexosRadiografia = new ArrayList<AnexosRadiografia>();
            for (AnexosRadiografia anexosRadiografiaAnexosRadiografiaToAttach : historiaClinica.getAnexosRadiografia()) {
                anexosRadiografiaAnexosRadiografiaToAttach = em.getReference(anexosRadiografiaAnexosRadiografiaToAttach.getClass(), anexosRadiografiaAnexosRadiografiaToAttach.getId());
                attachedAnexosRadiografia.add(anexosRadiografiaAnexosRadiografiaToAttach);
            }
            historiaClinica.setAnexosRadiografia(attachedAnexosRadiografia);
            em.persist(historiaClinica);
            if (tratamientoId != null) {
                tratamientoId.getHistoriaClinicaCollection().add(historiaClinica);
                tratamientoId = em.merge(tratamientoId);
            }
            for (AnexosRadiografia anexosRadiografiaAnexosRadiografia : historiaClinica.getAnexosRadiografia()) {
                HistoriaClinica oldHistoriaIdOfAnexosRadiografiaAnexosRadiografia = anexosRadiografiaAnexosRadiografia.getHistoriaId();
                anexosRadiografiaAnexosRadiografia.setHistoriaId(historiaClinica);
                anexosRadiografiaAnexosRadiografia = em.merge(anexosRadiografiaAnexosRadiografia);
                if (oldHistoriaIdOfAnexosRadiografiaAnexosRadiografia != null) {
                    oldHistoriaIdOfAnexosRadiografiaAnexosRadiografia.getAnexosRadiografia().remove(anexosRadiografiaAnexosRadiografia);
                    oldHistoriaIdOfAnexosRadiografiaAnexosRadiografia = em.merge(oldHistoriaIdOfAnexosRadiografiaAnexosRadiografia);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(HistoriaClinica historiaClinica) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            HistoriaClinica persistentHistoriaClinica = em.find(HistoriaClinica.class, historiaClinica.getId());
            Tratamiento tratamientoIdOld = persistentHistoriaClinica.getTratamientoId();
            Tratamiento tratamientoIdNew = historiaClinica.getTratamientoId();
            Collection<AnexosRadiografia> anexosRadiografiaOld = persistentHistoriaClinica.getAnexosRadiografia();
            Collection<AnexosRadiografia> anexosRadiografiaNew = historiaClinica.getAnexosRadiografia();
            List<String> illegalOrphanMessages = null;
            for (AnexosRadiografia anexosRadiografiaOldAnexosRadiografia : anexosRadiografiaOld) {
                if (!anexosRadiografiaNew.contains(anexosRadiografiaOldAnexosRadiografia)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain AnexosRadiografia " + anexosRadiografiaOldAnexosRadiografia + " since its historiaId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                historiaClinica.setTratamientoId(tratamientoIdNew);
            }
            Collection<AnexosRadiografia> attachedAnexosRadiografiaNew = new ArrayList<AnexosRadiografia>();
            for (AnexosRadiografia anexosRadiografiaNewAnexosRadiografiaToAttach : anexosRadiografiaNew) {
                anexosRadiografiaNewAnexosRadiografiaToAttach = em.getReference(anexosRadiografiaNewAnexosRadiografiaToAttach.getClass(), anexosRadiografiaNewAnexosRadiografiaToAttach.getId());
                attachedAnexosRadiografiaNew.add(anexosRadiografiaNewAnexosRadiografiaToAttach);
            }
            anexosRadiografiaNew = attachedAnexosRadiografiaNew;
            historiaClinica.setAnexosRadiografia(anexosRadiografiaNew);
            historiaClinica = em.merge(historiaClinica);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.getHistoriaClinicaCollection().remove(historiaClinica);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.getHistoriaClinicaCollection().add(historiaClinica);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            for (AnexosRadiografia anexosRadiografiaNewAnexosRadiografia : anexosRadiografiaNew) {
                if (!anexosRadiografiaOld.contains(anexosRadiografiaNewAnexosRadiografia)) {
                    HistoriaClinica oldHistoriaIdOfAnexosRadiografiaNewAnexosRadiografia = anexosRadiografiaNewAnexosRadiografia.getHistoriaId();
                    anexosRadiografiaNewAnexosRadiografia.setHistoriaId(historiaClinica);
                    anexosRadiografiaNewAnexosRadiografia = em.merge(anexosRadiografiaNewAnexosRadiografia);
                    if (oldHistoriaIdOfAnexosRadiografiaNewAnexosRadiografia != null && !oldHistoriaIdOfAnexosRadiografiaNewAnexosRadiografia.equals(historiaClinica)) {
                        oldHistoriaIdOfAnexosRadiografiaNewAnexosRadiografia.getAnexosRadiografia().remove(anexosRadiografiaNewAnexosRadiografia);
                        oldHistoriaIdOfAnexosRadiografiaNewAnexosRadiografia = em.merge(oldHistoriaIdOfAnexosRadiografiaNewAnexosRadiografia);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = historiaClinica.getId();
                if (findHistoriaClinica(id) == null) {
                    throw new NonexistentEntityException("The historiaClinica with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            HistoriaClinica historiaClinica;
            try {
                historiaClinica = em.getReference(HistoriaClinica.class, id);
                historiaClinica.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The historiaClinica with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<AnexosRadiografia> anexosRadiografiaOrphanCheck = historiaClinica.getAnexosRadiografia();
            for (AnexosRadiografia anexosRadiografiaOrphanCheckAnexosRadiografia : anexosRadiografiaOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This HistoriaClinica (" + historiaClinica + ") cannot be destroyed since the AnexosRadiografia " + anexosRadiografiaOrphanCheckAnexosRadiografia + " in its anexosRadiografia field has a non-nullable historiaId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Tratamiento tratamientoId = historiaClinica.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.getHistoriaClinicaCollection().remove(historiaClinica);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(historiaClinica);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<HistoriaClinica> findHistoriaClinicaEntities() {
        return findHistoriaClinicaEntities(true, -1, -1);
    }

    public List<HistoriaClinica> findHistoriaClinicaEntities(int maxResults, int firstResult) {
        return findHistoriaClinicaEntities(false, maxResults, firstResult);
    }

    private List<HistoriaClinica> findHistoriaClinicaEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(HistoriaClinica.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public HistoriaClinica findHistoriaClinica(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(HistoriaClinica.class, id);
        } finally {
            em.close();
        }
    }

    public int getHistoriaClinicaCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<HistoriaClinica> rt = cq.from(HistoriaClinica.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
