/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Depto;
import entidades.Muni;
import entidades.Paciente;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class MuniJpaController implements Serializable {

    public MuniJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Muni muni) {
        if (muni.getPacienteCollection() == null) {
            muni.setPacienteCollection(new ArrayList<Paciente>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Depto deptoCodigo = muni.getDeptoCodigo();
            if (deptoCodigo != null) {
                deptoCodigo = em.getReference(deptoCodigo.getClass(), deptoCodigo.getCodigo());
                muni.setDeptoCodigo(deptoCodigo);
            }
            Collection<Paciente> attachedPacienteCollection = new ArrayList<Paciente>();
            for (Paciente pacienteCollectionPacienteToAttach : muni.getPacienteCollection()) {
                pacienteCollectionPacienteToAttach = em.getReference(pacienteCollectionPacienteToAttach.getClass(), pacienteCollectionPacienteToAttach.getId());
                attachedPacienteCollection.add(pacienteCollectionPacienteToAttach);
            }
            muni.setPacienteCollection(attachedPacienteCollection);
            em.persist(muni);
            if (deptoCodigo != null) {
                deptoCodigo.getMuniCollection().add(muni);
                deptoCodigo = em.merge(deptoCodigo);
            }
            for (Paciente pacienteCollectionPaciente : muni.getPacienteCollection()) {
                Muni oldMuniIdOfPacienteCollectionPaciente = pacienteCollectionPaciente.getMuniId();
                pacienteCollectionPaciente.setMuniId(muni);
                pacienteCollectionPaciente = em.merge(pacienteCollectionPaciente);
                if (oldMuniIdOfPacienteCollectionPaciente != null) {
                    oldMuniIdOfPacienteCollectionPaciente.getPacienteCollection().remove(pacienteCollectionPaciente);
                    oldMuniIdOfPacienteCollectionPaciente = em.merge(oldMuniIdOfPacienteCollectionPaciente);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Muni muni) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Muni persistentMuni = em.find(Muni.class, muni.getId());
            Depto deptoCodigoOld = persistentMuni.getDeptoCodigo();
            Depto deptoCodigoNew = muni.getDeptoCodigo();
            Collection<Paciente> pacienteCollectionOld = persistentMuni.getPacienteCollection();
            Collection<Paciente> pacienteCollectionNew = muni.getPacienteCollection();
            List<String> illegalOrphanMessages = null;
            for (Paciente pacienteCollectionOldPaciente : pacienteCollectionOld) {
                if (!pacienteCollectionNew.contains(pacienteCollectionOldPaciente)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Paciente " + pacienteCollectionOldPaciente + " since its muniId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (deptoCodigoNew != null) {
                deptoCodigoNew = em.getReference(deptoCodigoNew.getClass(), deptoCodigoNew.getCodigo());
                muni.setDeptoCodigo(deptoCodigoNew);
            }
            Collection<Paciente> attachedPacienteCollectionNew = new ArrayList<Paciente>();
            for (Paciente pacienteCollectionNewPacienteToAttach : pacienteCollectionNew) {
                pacienteCollectionNewPacienteToAttach = em.getReference(pacienteCollectionNewPacienteToAttach.getClass(), pacienteCollectionNewPacienteToAttach.getId());
                attachedPacienteCollectionNew.add(pacienteCollectionNewPacienteToAttach);
            }
            pacienteCollectionNew = attachedPacienteCollectionNew;
            muni.setPacienteCollection(pacienteCollectionNew);
            muni = em.merge(muni);
            if (deptoCodigoOld != null && !deptoCodigoOld.equals(deptoCodigoNew)) {
                deptoCodigoOld.getMuniCollection().remove(muni);
                deptoCodigoOld = em.merge(deptoCodigoOld);
            }
            if (deptoCodigoNew != null && !deptoCodigoNew.equals(deptoCodigoOld)) {
                deptoCodigoNew.getMuniCollection().add(muni);
                deptoCodigoNew = em.merge(deptoCodigoNew);
            }
            for (Paciente pacienteCollectionNewPaciente : pacienteCollectionNew) {
                if (!pacienteCollectionOld.contains(pacienteCollectionNewPaciente)) {
                    Muni oldMuniIdOfPacienteCollectionNewPaciente = pacienteCollectionNewPaciente.getMuniId();
                    pacienteCollectionNewPaciente.setMuniId(muni);
                    pacienteCollectionNewPaciente = em.merge(pacienteCollectionNewPaciente);
                    if (oldMuniIdOfPacienteCollectionNewPaciente != null && !oldMuniIdOfPacienteCollectionNewPaciente.equals(muni)) {
                        oldMuniIdOfPacienteCollectionNewPaciente.getPacienteCollection().remove(pacienteCollectionNewPaciente);
                        oldMuniIdOfPacienteCollectionNewPaciente = em.merge(oldMuniIdOfPacienteCollectionNewPaciente);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = muni.getId();
                if (findMuni(id) == null) {
                    throw new NonexistentEntityException("The muni with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Muni muni;
            try {
                muni = em.getReference(Muni.class, id);
                muni.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The muni with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<Paciente> pacienteCollectionOrphanCheck = muni.getPacienteCollection();
            for (Paciente pacienteCollectionOrphanCheckPaciente : pacienteCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Muni (" + muni + ") cannot be destroyed since the Paciente " + pacienteCollectionOrphanCheckPaciente + " in its pacienteCollection field has a non-nullable muniId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Depto deptoCodigo = muni.getDeptoCodigo();
            if (deptoCodigo != null) {
                deptoCodigo.getMuniCollection().remove(muni);
                deptoCodigo = em.merge(deptoCodigo);
            }
            em.remove(muni);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Muni> findMuniEntities() {
        return findMuniEntities(true, -1, -1);
    }

    public List<Muni> findMuniEntities(int maxResults, int firstResult) {
        return findMuniEntities(false, maxResults, firstResult);
    }

    private List<Muni> findMuniEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Muni.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Muni findMuni(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Muni.class, id);
        } finally {
            em.close();
        }
    }

    public int getMuniCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Muni> rt = cq.from(Muni.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
