/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import entidades.Ortopedia3;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import java.util.ArrayList;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class Ortopedia3JpaController implements Serializable {

    public Ortopedia3JpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Ortopedia3 ortopedia3) throws IllegalOrphanException {
        List<String> illegalOrphanMessages = null;
        Tratamiento tratamientoIdOrphanCheck = ortopedia3.getTratamientoId();
        if (tratamientoIdOrphanCheck != null) {
            Ortopedia3 oldOrtopedia3OfTratamientoId = tratamientoIdOrphanCheck.getOrtopedia3();
            if (oldOrtopedia3OfTratamientoId != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The Tratamiento " + tratamientoIdOrphanCheck + " already has an item of type Ortopedia3 whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
            }
        }
        if (illegalOrphanMessages != null) {
            throw new IllegalOrphanException(illegalOrphanMessages);
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = ortopedia3.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                ortopedia3.setTratamientoId(tratamientoId);
            }
            em.persist(ortopedia3);
            if (tratamientoId != null) {
                tratamientoId.setOrtopedia3(ortopedia3);
                tratamientoId = em.merge(tratamientoId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Ortopedia3 ortopedia3) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Ortopedia3 persistentOrtopedia3 = em.find(Ortopedia3.class, ortopedia3.getId());
            Tratamiento tratamientoIdOld = persistentOrtopedia3.getTratamientoId();
            Tratamiento tratamientoIdNew = ortopedia3.getTratamientoId();
            List<String> illegalOrphanMessages = null;
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                Ortopedia3 oldOrtopedia3OfTratamientoId = tratamientoIdNew.getOrtopedia3();
                if (oldOrtopedia3OfTratamientoId != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The Tratamiento " + tratamientoIdNew + " already has an item of type Ortopedia3 whose tratamientoId column cannot be null. Please make another selection for the tratamientoId field.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                ortopedia3.setTratamientoId(tratamientoIdNew);
            }
            ortopedia3 = em.merge(ortopedia3);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.setOrtopedia3(null);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.setOrtopedia3(ortopedia3);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = ortopedia3.getId();
                if (findOrtopedia3(id) == null) {
                    throw new NonexistentEntityException("The ortopedia3 with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Ortopedia3 ortopedia3;
            try {
                ortopedia3 = em.getReference(Ortopedia3.class, id);
                ortopedia3.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The ortopedia3 with id " + id + " no longer exists.", enfe);
            }
            Tratamiento tratamientoId = ortopedia3.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.setOrtopedia3(null);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(ortopedia3);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Ortopedia3> findOrtopedia3Entities() {
        return findOrtopedia3Entities(true, -1, -1);
    }

    public List<Ortopedia3> findOrtopedia3Entities(int maxResults, int firstResult) {
        return findOrtopedia3Entities(false, maxResults, firstResult);
    }

    private List<Ortopedia3> findOrtopedia3Entities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Ortopedia3.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Ortopedia3 findOrtopedia3(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Ortopedia3.class, id);
        } finally {
            em.close();
        }
    }

    public int getOrtopedia3Count() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Ortopedia3> rt = cq.from(Ortopedia3.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
