/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Muni;
import entidades.Tratamiento;
import java.util.ArrayList;
import java.util.Collection;
import entidades.Citas;
import entidades.Paciente;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class PacienteJpaController implements Serializable {

    public PacienteJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Paciente paciente) {
        if (paciente.getTratamientoCollection() == null) {
            paciente.setTratamientoCollection(new ArrayList<Tratamiento>());
        }
        if (paciente.getCitasCollection() == null) {
            paciente.setCitasCollection(new ArrayList<Citas>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Muni muniId = paciente.getMuniId();
            if (muniId != null) {
                muniId = em.getReference(muniId.getClass(), muniId.getId());
                paciente.setMuniId(muniId);
            }
            Collection<Tratamiento> attachedTratamientoCollection = new ArrayList<Tratamiento>();
            for (Tratamiento tratamientoCollectionTratamientoToAttach : paciente.getTratamientoCollection()) {
                tratamientoCollectionTratamientoToAttach = em.getReference(tratamientoCollectionTratamientoToAttach.getClass(), tratamientoCollectionTratamientoToAttach.getId());
                attachedTratamientoCollection.add(tratamientoCollectionTratamientoToAttach);
            }
            paciente.setTratamientoCollection(attachedTratamientoCollection);
            Collection<Citas> attachedCitasCollection = new ArrayList<Citas>();
            for (Citas citasCollectionCitasToAttach : paciente.getCitasCollection()) {
                citasCollectionCitasToAttach = em.getReference(citasCollectionCitasToAttach.getClass(), citasCollectionCitasToAttach.getId());
                attachedCitasCollection.add(citasCollectionCitasToAttach);
            }
            paciente.setCitasCollection(attachedCitasCollection);
            em.persist(paciente);
            if (muniId != null) {
                muniId.getPacienteCollection().add(paciente);
                muniId = em.merge(muniId);
            }
            for (Tratamiento tratamientoCollectionTratamiento : paciente.getTratamientoCollection()) {
                Paciente oldPacienteIdOfTratamientoCollectionTratamiento = tratamientoCollectionTratamiento.getPacienteId();
                tratamientoCollectionTratamiento.setPacienteId(paciente);
                tratamientoCollectionTratamiento = em.merge(tratamientoCollectionTratamiento);
                if (oldPacienteIdOfTratamientoCollectionTratamiento != null) {
                    oldPacienteIdOfTratamientoCollectionTratamiento.getTratamientoCollection().remove(tratamientoCollectionTratamiento);
                    oldPacienteIdOfTratamientoCollectionTratamiento = em.merge(oldPacienteIdOfTratamientoCollectionTratamiento);
                }
            }
            for (Citas citasCollectionCitas : paciente.getCitasCollection()) {
                Paciente oldPacienteIdOfCitasCollectionCitas = citasCollectionCitas.getPacienteId();
                citasCollectionCitas.setPacienteId(paciente);
                citasCollectionCitas = em.merge(citasCollectionCitas);
                if (oldPacienteIdOfCitasCollectionCitas != null) {
                    oldPacienteIdOfCitasCollectionCitas.getCitasCollection().remove(citasCollectionCitas);
                    oldPacienteIdOfCitasCollectionCitas = em.merge(oldPacienteIdOfCitasCollectionCitas);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Paciente paciente) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Paciente persistentPaciente = em.find(Paciente.class, paciente.getId());
            Muni muniIdOld = persistentPaciente.getMuniId();
            Muni muniIdNew = paciente.getMuniId();
            Collection<Tratamiento> tratamientoCollectionOld = persistentPaciente.getTratamientoCollection();
            Collection<Tratamiento> tratamientoCollectionNew = paciente.getTratamientoCollection();
            Collection<Citas> citasCollectionOld = persistentPaciente.getCitasCollection();
            Collection<Citas> citasCollectionNew = paciente.getCitasCollection();
            List<String> illegalOrphanMessages = null;
            for (Tratamiento tratamientoCollectionOldTratamiento : tratamientoCollectionOld) {
                if (!tratamientoCollectionNew.contains(tratamientoCollectionOldTratamiento)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Tratamiento " + tratamientoCollectionOldTratamiento + " since its pacienteId field is not nullable.");
                }
            }
            for (Citas citasCollectionOldCitas : citasCollectionOld) {
                if (!citasCollectionNew.contains(citasCollectionOldCitas)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Citas " + citasCollectionOldCitas + " since its pacienteId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (muniIdNew != null) {
                muniIdNew = em.getReference(muniIdNew.getClass(), muniIdNew.getId());
                paciente.setMuniId(muniIdNew);
            }
            Collection<Tratamiento> attachedTratamientoCollectionNew = new ArrayList<Tratamiento>();
            for (Tratamiento tratamientoCollectionNewTratamientoToAttach : tratamientoCollectionNew) {
                tratamientoCollectionNewTratamientoToAttach = em.getReference(tratamientoCollectionNewTratamientoToAttach.getClass(), tratamientoCollectionNewTratamientoToAttach.getId());
                attachedTratamientoCollectionNew.add(tratamientoCollectionNewTratamientoToAttach);
            }
            tratamientoCollectionNew = attachedTratamientoCollectionNew;
            paciente.setTratamientoCollection(tratamientoCollectionNew);
            Collection<Citas> attachedCitasCollectionNew = new ArrayList<Citas>();
            for (Citas citasCollectionNewCitasToAttach : citasCollectionNew) {
                citasCollectionNewCitasToAttach = em.getReference(citasCollectionNewCitasToAttach.getClass(), citasCollectionNewCitasToAttach.getId());
                attachedCitasCollectionNew.add(citasCollectionNewCitasToAttach);
            }
            citasCollectionNew = attachedCitasCollectionNew;
            paciente.setCitasCollection(citasCollectionNew);
            paciente = em.merge(paciente);
            if (muniIdOld != null && !muniIdOld.equals(muniIdNew)) {
                muniIdOld.getPacienteCollection().remove(paciente);
                muniIdOld = em.merge(muniIdOld);
            }
            if (muniIdNew != null && !muniIdNew.equals(muniIdOld)) {
                muniIdNew.getPacienteCollection().add(paciente);
                muniIdNew = em.merge(muniIdNew);
            }
            for (Tratamiento tratamientoCollectionNewTratamiento : tratamientoCollectionNew) {
                if (!tratamientoCollectionOld.contains(tratamientoCollectionNewTratamiento)) {
                    Paciente oldPacienteIdOfTratamientoCollectionNewTratamiento = tratamientoCollectionNewTratamiento.getPacienteId();
                    tratamientoCollectionNewTratamiento.setPacienteId(paciente);
                    tratamientoCollectionNewTratamiento = em.merge(tratamientoCollectionNewTratamiento);
                    if (oldPacienteIdOfTratamientoCollectionNewTratamiento != null && !oldPacienteIdOfTratamientoCollectionNewTratamiento.equals(paciente)) {
                        oldPacienteIdOfTratamientoCollectionNewTratamiento.getTratamientoCollection().remove(tratamientoCollectionNewTratamiento);
                        oldPacienteIdOfTratamientoCollectionNewTratamiento = em.merge(oldPacienteIdOfTratamientoCollectionNewTratamiento);
                    }
                }
            }
            for (Citas citasCollectionNewCitas : citasCollectionNew) {
                if (!citasCollectionOld.contains(citasCollectionNewCitas)) {
                    Paciente oldPacienteIdOfCitasCollectionNewCitas = citasCollectionNewCitas.getPacienteId();
                    citasCollectionNewCitas.setPacienteId(paciente);
                    citasCollectionNewCitas = em.merge(citasCollectionNewCitas);
                    if (oldPacienteIdOfCitasCollectionNewCitas != null && !oldPacienteIdOfCitasCollectionNewCitas.equals(paciente)) {
                        oldPacienteIdOfCitasCollectionNewCitas.getCitasCollection().remove(citasCollectionNewCitas);
                        oldPacienteIdOfCitasCollectionNewCitas = em.merge(oldPacienteIdOfCitasCollectionNewCitas);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = paciente.getId();
                if (findPaciente(id) == null) {
                    throw new NonexistentEntityException("The paciente with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Paciente paciente;
            try {
                paciente = em.getReference(Paciente.class, id);
                paciente.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The paciente with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Collection<Tratamiento> tratamientoCollectionOrphanCheck = paciente.getTratamientoCollection();
            for (Tratamiento tratamientoCollectionOrphanCheckTratamiento : tratamientoCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Paciente (" + paciente + ") cannot be destroyed since the Tratamiento " + tratamientoCollectionOrphanCheckTratamiento + " in its tratamientoCollection field has a non-nullable pacienteId field.");
            }
            Collection<Citas> citasCollectionOrphanCheck = paciente.getCitasCollection();
            for (Citas citasCollectionOrphanCheckCitas : citasCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Paciente (" + paciente + ") cannot be destroyed since the Citas " + citasCollectionOrphanCheckCitas + " in its citasCollection field has a non-nullable pacienteId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Muni muniId = paciente.getMuniId();
            if (muniId != null) {
                muniId.getPacienteCollection().remove(paciente);
                muniId = em.merge(muniId);
            }
            em.remove(paciente);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Paciente> findPacienteEntities() {
        return findPacienteEntities(true, -1, -1);
    }

    public List<Paciente> findPacienteEntities(int maxResults, int firstResult) {
        return findPacienteEntities(false, maxResults, firstResult);
    }

    private List<Paciente> findPacienteEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Paciente.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Paciente findPaciente(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Paciente.class, id);
        } finally {
            em.close();
        }
    }

    public int getPacienteCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Paciente> rt = cq.from(Paciente.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
