/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Area;
import entidades.Permiso;
import entidades.Tratamiento;
import java.util.ArrayList;
import java.util.Collection;
import entidades.Evolucion;
import entidades.Personal;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class PersonalJpaController implements Serializable {

    public PersonalJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Personal personal) {
        if (personal.getTratamientoCollection() == null) {
            personal.setTratamientoCollection(new ArrayList<Tratamiento>());
        }
        if (personal.getEvolucionCollection() == null) {
            personal.setEvolucionCollection(new ArrayList<Evolucion>());
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Area areaId = personal.getAreaId();
            if (areaId != null) {
                areaId = em.getReference(areaId.getClass(), areaId.getId());
                personal.setAreaId(areaId);
            }
            Permiso permiso = personal.getPermiso();
            if (permiso != null) {
                permiso = em.getReference(permiso.getClass(), permiso.getId());
                personal.setPermiso(permiso);
            }
            Collection<Tratamiento> attachedTratamientoCollection = new ArrayList<Tratamiento>();
            for (Tratamiento tratamientoCollectionTratamientoToAttach : personal.getTratamientoCollection()) {
                tratamientoCollectionTratamientoToAttach = em.getReference(tratamientoCollectionTratamientoToAttach.getClass(), tratamientoCollectionTratamientoToAttach.getId());
                attachedTratamientoCollection.add(tratamientoCollectionTratamientoToAttach);
            }
            personal.setTratamientoCollection(attachedTratamientoCollection);
            Collection<Evolucion> attachedEvolucionCollection = new ArrayList<Evolucion>();
            for (Evolucion evolucionCollectionEvolucionToAttach : personal.getEvolucionCollection()) {
                evolucionCollectionEvolucionToAttach = em.getReference(evolucionCollectionEvolucionToAttach.getClass(), evolucionCollectionEvolucionToAttach.getId());
                attachedEvolucionCollection.add(evolucionCollectionEvolucionToAttach);
            }
            personal.setEvolucionCollection(attachedEvolucionCollection);
            em.persist(personal);
            if (areaId != null) {
                areaId.getMedicoCollection().add(personal);
                areaId = em.merge(areaId);
            }
            if (permiso != null) {
                Personal oldPersonalIdOfPermiso = permiso.getPersonalId();
                if (oldPersonalIdOfPermiso != null) {
                    oldPersonalIdOfPermiso.setPermiso(null);
                    oldPersonalIdOfPermiso = em.merge(oldPersonalIdOfPermiso);
                }
                permiso.setPersonalId(personal);
                permiso = em.merge(permiso);
            }
            for (Tratamiento tratamientoCollectionTratamiento : personal.getTratamientoCollection()) {
                Personal oldPersonalIdOfTratamientoCollectionTratamiento = tratamientoCollectionTratamiento.getPersonalId();
                tratamientoCollectionTratamiento.setPersonalId(personal);
                tratamientoCollectionTratamiento = em.merge(tratamientoCollectionTratamiento);
                if (oldPersonalIdOfTratamientoCollectionTratamiento != null) {
                    oldPersonalIdOfTratamientoCollectionTratamiento.getTratamientoCollection().remove(tratamientoCollectionTratamiento);
                    oldPersonalIdOfTratamientoCollectionTratamiento = em.merge(oldPersonalIdOfTratamientoCollectionTratamiento);
                }
            }
            for (Evolucion evolucionCollectionEvolucion : personal.getEvolucionCollection()) {
                Personal oldPersonalIdOfEvolucionCollectionEvolucion = evolucionCollectionEvolucion.getPersonalId();
                evolucionCollectionEvolucion.setPersonalId(personal);
                evolucionCollectionEvolucion = em.merge(evolucionCollectionEvolucion);
                if (oldPersonalIdOfEvolucionCollectionEvolucion != null) {
                    oldPersonalIdOfEvolucionCollectionEvolucion.getEvolucionCollection().remove(evolucionCollectionEvolucion);
                    oldPersonalIdOfEvolucionCollectionEvolucion = em.merge(oldPersonalIdOfEvolucionCollectionEvolucion);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Personal personal) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Personal persistentPersonal = em.find(Personal.class, personal.getId());
            Area areaIdOld = persistentPersonal.getAreaId();
            Area areaIdNew = personal.getAreaId();
            Permiso permisoOld = persistentPersonal.getPermiso();
            Permiso permisoNew = personal.getPermiso();
            Collection<Tratamiento> tratamientoCollectionOld = persistentPersonal.getTratamientoCollection();
            Collection<Tratamiento> tratamientoCollectionNew = personal.getTratamientoCollection();
            Collection<Evolucion> evolucionCollectionOld = persistentPersonal.getEvolucionCollection();
            Collection<Evolucion> evolucionCollectionNew = personal.getEvolucionCollection();
            List<String> illegalOrphanMessages = null;
            if (permisoOld != null && !permisoOld.equals(permisoNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain Permiso " + permisoOld + " since its personalId field is not nullable.");
            }
            for (Tratamiento tratamientoCollectionOldTratamiento : tratamientoCollectionOld) {
                if (!tratamientoCollectionNew.contains(tratamientoCollectionOldTratamiento)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Tratamiento " + tratamientoCollectionOldTratamiento + " since its personalId field is not nullable.");
                }
            }
            for (Evolucion evolucionCollectionOldEvolucion : evolucionCollectionOld) {
                if (!evolucionCollectionNew.contains(evolucionCollectionOldEvolucion)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Evolucion " + evolucionCollectionOldEvolucion + " since its personalId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (areaIdNew != null) {
                areaIdNew = em.getReference(areaIdNew.getClass(), areaIdNew.getId());
                personal.setAreaId(areaIdNew);
            }
            if (permisoNew != null) {
                permisoNew = em.getReference(permisoNew.getClass(), permisoNew.getId());
                personal.setPermiso(permisoNew);
            }
            Collection<Tratamiento> attachedTratamientoCollectionNew = new ArrayList<Tratamiento>();
            for (Tratamiento tratamientoCollectionNewTratamientoToAttach : tratamientoCollectionNew) {
                tratamientoCollectionNewTratamientoToAttach = em.getReference(tratamientoCollectionNewTratamientoToAttach.getClass(), tratamientoCollectionNewTratamientoToAttach.getId());
                attachedTratamientoCollectionNew.add(tratamientoCollectionNewTratamientoToAttach);
            }
            tratamientoCollectionNew = attachedTratamientoCollectionNew;
            personal.setTratamientoCollection(tratamientoCollectionNew);
            Collection<Evolucion> attachedEvolucionCollectionNew = new ArrayList<Evolucion>();
            for (Evolucion evolucionCollectionNewEvolucionToAttach : evolucionCollectionNew) {
                evolucionCollectionNewEvolucionToAttach = em.getReference(evolucionCollectionNewEvolucionToAttach.getClass(), evolucionCollectionNewEvolucionToAttach.getId());
                attachedEvolucionCollectionNew.add(evolucionCollectionNewEvolucionToAttach);
            }
            evolucionCollectionNew = attachedEvolucionCollectionNew;
            personal.setEvolucionCollection(evolucionCollectionNew);
            personal = em.merge(personal);
            if (areaIdOld != null && !areaIdOld.equals(areaIdNew)) {
                areaIdOld.getMedicoCollection().remove(personal);
                areaIdOld = em.merge(areaIdOld);
            }
            if (areaIdNew != null && !areaIdNew.equals(areaIdOld)) {
                areaIdNew.getMedicoCollection().add(personal);
                areaIdNew = em.merge(areaIdNew);
            }
            if (permisoNew != null && !permisoNew.equals(permisoOld)) {
                Personal oldPersonalIdOfPermiso = permisoNew.getPersonalId();
                if (oldPersonalIdOfPermiso != null) {
                    oldPersonalIdOfPermiso.setPermiso(null);
                    oldPersonalIdOfPermiso = em.merge(oldPersonalIdOfPermiso);
                }
                permisoNew.setPersonalId(personal);
                permisoNew = em.merge(permisoNew);
            }
            for (Tratamiento tratamientoCollectionNewTratamiento : tratamientoCollectionNew) {
                if (!tratamientoCollectionOld.contains(tratamientoCollectionNewTratamiento)) {
                    Personal oldPersonalIdOfTratamientoCollectionNewTratamiento = tratamientoCollectionNewTratamiento.getPersonalId();
                    tratamientoCollectionNewTratamiento.setPersonalId(personal);
                    tratamientoCollectionNewTratamiento = em.merge(tratamientoCollectionNewTratamiento);
                    if (oldPersonalIdOfTratamientoCollectionNewTratamiento != null && !oldPersonalIdOfTratamientoCollectionNewTratamiento.equals(personal)) {
                        oldPersonalIdOfTratamientoCollectionNewTratamiento.getTratamientoCollection().remove(tratamientoCollectionNewTratamiento);
                        oldPersonalIdOfTratamientoCollectionNewTratamiento = em.merge(oldPersonalIdOfTratamientoCollectionNewTratamiento);
                    }
                }
            }
            for (Evolucion evolucionCollectionNewEvolucion : evolucionCollectionNew) {
                if (!evolucionCollectionOld.contains(evolucionCollectionNewEvolucion)) {
                    Personal oldPersonalIdOfEvolucionCollectionNewEvolucion = evolucionCollectionNewEvolucion.getPersonalId();
                    evolucionCollectionNewEvolucion.setPersonalId(personal);
                    evolucionCollectionNewEvolucion = em.merge(evolucionCollectionNewEvolucion);
                    if (oldPersonalIdOfEvolucionCollectionNewEvolucion != null && !oldPersonalIdOfEvolucionCollectionNewEvolucion.equals(personal)) {
                        oldPersonalIdOfEvolucionCollectionNewEvolucion.getEvolucionCollection().remove(evolucionCollectionNewEvolucion);
                        oldPersonalIdOfEvolucionCollectionNewEvolucion = em.merge(oldPersonalIdOfEvolucionCollectionNewEvolucion);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = personal.getId();
                if (findPersonal(id) == null) {
                    throw new NonexistentEntityException("The personal with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Personal personal;
            try {
                personal = em.getReference(Personal.class, id);
                personal.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The personal with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            Permiso permisoOrphanCheck = personal.getPermiso();
            if (permisoOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Personal (" + personal + ") cannot be destroyed since the Permiso " + permisoOrphanCheck + " in its permiso field has a non-nullable personalId field.");
            }
            Collection<Tratamiento> tratamientoCollectionOrphanCheck = personal.getTratamientoCollection();
            for (Tratamiento tratamientoCollectionOrphanCheckTratamiento : tratamientoCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Personal (" + personal + ") cannot be destroyed since the Tratamiento " + tratamientoCollectionOrphanCheckTratamiento + " in its tratamientoCollection field has a non-nullable personalId field.");
            }
            Collection<Evolucion> evolucionCollectionOrphanCheck = personal.getEvolucionCollection();
            for (Evolucion evolucionCollectionOrphanCheckEvolucion : evolucionCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Personal (" + personal + ") cannot be destroyed since the Evolucion " + evolucionCollectionOrphanCheckEvolucion + " in its evolucionCollection field has a non-nullable personalId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Area areaId = personal.getAreaId();
            if (areaId != null) {
                areaId.getMedicoCollection().remove(personal);
                areaId = em.merge(areaId);
            }
            em.remove(personal);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Personal> findPersonalEntities() {
        return findPersonalEntities(true, -1, -1);
    }

    public List<Personal> findPersonalEntities(int maxResults, int firstResult) {
        return findPersonalEntities(false, maxResults, firstResult);
    }

    private List<Personal> findPersonalEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Personal.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Personal findPersonal(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Personal.class, id);
        } finally {
            em.close();
        }
    }

    public int getPersonalCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Personal> rt = cq.from(Personal.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
