/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.AnalisisDeEspacio;
import entidades.PlanTratamiento;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class PlanTratamientoJpaController implements Serializable {

    public PlanTratamientoJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(PlanTratamiento planTratamiento) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisDeEspacio analisisDeEspacioId = planTratamiento.getAnalisisDeEspacioId();
            if (analisisDeEspacioId != null) {
                analisisDeEspacioId = em.getReference(analisisDeEspacioId.getClass(), analisisDeEspacioId.getId());
                planTratamiento.setAnalisisDeEspacioId(analisisDeEspacioId);
            }
            em.persist(planTratamiento);
            if (analisisDeEspacioId != null) {
                analisisDeEspacioId.getPlanTratamientoCollection().add(planTratamiento);
                analisisDeEspacioId = em.merge(analisisDeEspacioId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(PlanTratamiento planTratamiento) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            PlanTratamiento persistentPlanTratamiento = em.find(PlanTratamiento.class, planTratamiento.getId());
            AnalisisDeEspacio analisisDeEspacioIdOld = persistentPlanTratamiento.getAnalisisDeEspacioId();
            AnalisisDeEspacio analisisDeEspacioIdNew = planTratamiento.getAnalisisDeEspacioId();
            if (analisisDeEspacioIdNew != null) {
                analisisDeEspacioIdNew = em.getReference(analisisDeEspacioIdNew.getClass(), analisisDeEspacioIdNew.getId());
                planTratamiento.setAnalisisDeEspacioId(analisisDeEspacioIdNew);
            }
            planTratamiento = em.merge(planTratamiento);
            if (analisisDeEspacioIdOld != null && !analisisDeEspacioIdOld.equals(analisisDeEspacioIdNew)) {
                analisisDeEspacioIdOld.getPlanTratamientoCollection().remove(planTratamiento);
                analisisDeEspacioIdOld = em.merge(analisisDeEspacioIdOld);
            }
            if (analisisDeEspacioIdNew != null && !analisisDeEspacioIdNew.equals(analisisDeEspacioIdOld)) {
                analisisDeEspacioIdNew.getPlanTratamientoCollection().add(planTratamiento);
                analisisDeEspacioIdNew = em.merge(analisisDeEspacioIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = planTratamiento.getId();
                if (findPlanTratamiento(id) == null) {
                    throw new NonexistentEntityException("The planTratamiento with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            PlanTratamiento planTratamiento;
            try {
                planTratamiento = em.getReference(PlanTratamiento.class, id);
                planTratamiento.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The planTratamiento with id " + id + " no longer exists.", enfe);
            }
            AnalisisDeEspacio analisisDeEspacioId = planTratamiento.getAnalisisDeEspacioId();
            if (analisisDeEspacioId != null) {
                analisisDeEspacioId.getPlanTratamientoCollection().remove(planTratamiento);
                analisisDeEspacioId = em.merge(analisisDeEspacioId);
            }
            em.remove(planTratamiento);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<PlanTratamiento> findPlanTratamientoEntities() {
        return findPlanTratamientoEntities(true, -1, -1);
    }

    public List<PlanTratamiento> findPlanTratamientoEntities(int maxResults, int firstResult) {
        return findPlanTratamientoEntities(false, maxResults, firstResult);
    }

    private List<PlanTratamiento> findPlanTratamientoEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(PlanTratamiento.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public PlanTratamiento findPlanTratamiento(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(PlanTratamiento.class, id);
        } finally {
            em.close();
        }
    }

    public int getPlanTratamientoCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<PlanTratamiento> rt = cq.from(PlanTratamiento.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
