/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import entidades.ReciboCaja;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class ReciboCajaJpaController implements Serializable {

    public ReciboCajaJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(ReciboCaja reciboCaja) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = reciboCaja.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                reciboCaja.setTratamientoId(tratamientoId);
            }
            em.persist(reciboCaja);
            if (tratamientoId != null) {
                tratamientoId.getReciboCajaCollection().add(reciboCaja);
                tratamientoId = em.merge(tratamientoId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(ReciboCaja reciboCaja) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ReciboCaja persistentReciboCaja = em.find(ReciboCaja.class, reciboCaja.getId());
            Tratamiento tratamientoIdOld = persistentReciboCaja.getTratamientoId();
            Tratamiento tratamientoIdNew = reciboCaja.getTratamientoId();
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                reciboCaja.setTratamientoId(tratamientoIdNew);
            }
            reciboCaja = em.merge(reciboCaja);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.getReciboCajaCollection().remove(reciboCaja);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.getReciboCajaCollection().add(reciboCaja);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = reciboCaja.getId();
                if (findReciboCaja(id) == null) {
                    throw new NonexistentEntityException("The reciboCaja with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ReciboCaja reciboCaja;
            try {
                reciboCaja = em.getReference(ReciboCaja.class, id);
                reciboCaja.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The reciboCaja with id " + id + " no longer exists.", enfe);
            }
            Tratamiento tratamientoId = reciboCaja.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.getReciboCajaCollection().remove(reciboCaja);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(reciboCaja);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<ReciboCaja> findReciboCajaEntities() {
        return findReciboCajaEntities(true, -1, -1);
    }

    public List<ReciboCaja> findReciboCajaEntities(int maxResults, int firstResult) {
        return findReciboCajaEntities(false, maxResults, firstResult);
    }

    private List<ReciboCaja> findReciboCajaEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(ReciboCaja.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public ReciboCaja findReciboCaja(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(ReciboCaja.class, id);
        } finally {
            em.close();
        }
    }

    public int getReciboCajaCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<ReciboCaja> rt = cq.from(ReciboCaja.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
