/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import entidades.Remision;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Tratamiento;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class RemisionJpaController implements Serializable {

    public RemisionJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Remision remision) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamientoId = remision.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId = em.getReference(tratamientoId.getClass(), tratamientoId.getId());
                remision.setTratamientoId(tratamientoId);
            }
            em.persist(remision);
            if (tratamientoId != null) {
                tratamientoId.getRemisionCollection().add(remision);
                tratamientoId = em.merge(tratamientoId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Remision remision) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Remision persistentRemision = em.find(Remision.class, remision.getId());
            Tratamiento tratamientoIdOld = persistentRemision.getTratamientoId();
            Tratamiento tratamientoIdNew = remision.getTratamientoId();
            if (tratamientoIdNew != null) {
                tratamientoIdNew = em.getReference(tratamientoIdNew.getClass(), tratamientoIdNew.getId());
                remision.setTratamientoId(tratamientoIdNew);
            }
            remision = em.merge(remision);
            if (tratamientoIdOld != null && !tratamientoIdOld.equals(tratamientoIdNew)) {
                tratamientoIdOld.getRemisionCollection().remove(remision);
                tratamientoIdOld = em.merge(tratamientoIdOld);
            }
            if (tratamientoIdNew != null && !tratamientoIdNew.equals(tratamientoIdOld)) {
                tratamientoIdNew.getRemisionCollection().add(remision);
                tratamientoIdNew = em.merge(tratamientoIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = remision.getId();
                if (findRemision(id) == null) {
                    throw new NonexistentEntityException("The remision with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Remision remision;
            try {
                remision = em.getReference(Remision.class, id);
                remision.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The remision with id " + id + " no longer exists.", enfe);
            }
            Tratamiento tratamientoId = remision.getTratamientoId();
            if (tratamientoId != null) {
                tratamientoId.getRemisionCollection().remove(remision);
                tratamientoId = em.merge(tratamientoId);
            }
            em.remove(remision);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Remision> findRemisionEntities() {
        return findRemisionEntities(true, -1, -1);
    }

    public List<Remision> findRemisionEntities(int maxResults, int firstResult) {
        return findRemisionEntities(false, maxResults, firstResult);
    }

    private List<Remision> findRemisionEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Remision.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Remision findRemision(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Remision.class, id);
        } finally {
            em.close();
        }
    }

    public int getRemisionCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Remision> rt = cq.from(Remision.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
