/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.AnalisisCefalometricoAdulto;
import entidades.ResultadoAdulto;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class ResultadoAdultoJpaController implements Serializable {

    public ResultadoAdultoJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(ResultadoAdulto resultadoAdulto) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisCefalometricoAdulto analisisCefalometricoAdultoId = resultadoAdulto.getAnalisisCefalometricoAdultoId();
            if (analisisCefalometricoAdultoId != null) {
                analisisCefalometricoAdultoId = em.getReference(analisisCefalometricoAdultoId.getClass(), analisisCefalometricoAdultoId.getId());
                resultadoAdulto.setAnalisisCefalometricoAdultoId(analisisCefalometricoAdultoId);
            }
            em.persist(resultadoAdulto);
            if (analisisCefalometricoAdultoId != null) {
                analisisCefalometricoAdultoId.getResultadoAdultoCollection().add(resultadoAdulto);
                analisisCefalometricoAdultoId = em.merge(analisisCefalometricoAdultoId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(ResultadoAdulto resultadoAdulto) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ResultadoAdulto persistentResultadoAdulto = em.find(ResultadoAdulto.class, resultadoAdulto.getId());
            AnalisisCefalometricoAdulto analisisCefalometricoAdultoIdOld = persistentResultadoAdulto.getAnalisisCefalometricoAdultoId();
            AnalisisCefalometricoAdulto analisisCefalometricoAdultoIdNew = resultadoAdulto.getAnalisisCefalometricoAdultoId();
            if (analisisCefalometricoAdultoIdNew != null) {
                analisisCefalometricoAdultoIdNew = em.getReference(analisisCefalometricoAdultoIdNew.getClass(), analisisCefalometricoAdultoIdNew.getId());
                resultadoAdulto.setAnalisisCefalometricoAdultoId(analisisCefalometricoAdultoIdNew);
            }
            resultadoAdulto = em.merge(resultadoAdulto);
            if (analisisCefalometricoAdultoIdOld != null && !analisisCefalometricoAdultoIdOld.equals(analisisCefalometricoAdultoIdNew)) {
                analisisCefalometricoAdultoIdOld.getResultadoAdultoCollection().remove(resultadoAdulto);
                analisisCefalometricoAdultoIdOld = em.merge(analisisCefalometricoAdultoIdOld);
            }
            if (analisisCefalometricoAdultoIdNew != null && !analisisCefalometricoAdultoIdNew.equals(analisisCefalometricoAdultoIdOld)) {
                analisisCefalometricoAdultoIdNew.getResultadoAdultoCollection().add(resultadoAdulto);
                analisisCefalometricoAdultoIdNew = em.merge(analisisCefalometricoAdultoIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = resultadoAdulto.getId();
                if (findResultadoAdulto(id) == null) {
                    throw new NonexistentEntityException("The resultadoAdulto with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ResultadoAdulto resultadoAdulto;
            try {
                resultadoAdulto = em.getReference(ResultadoAdulto.class, id);
                resultadoAdulto.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The resultadoAdulto with id " + id + " no longer exists.", enfe);
            }
            AnalisisCefalometricoAdulto analisisCefalometricoAdultoId = resultadoAdulto.getAnalisisCefalometricoAdultoId();
            if (analisisCefalometricoAdultoId != null) {
                analisisCefalometricoAdultoId.getResultadoAdultoCollection().remove(resultadoAdulto);
                analisisCefalometricoAdultoId = em.merge(analisisCefalometricoAdultoId);
            }
            em.remove(resultadoAdulto);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<ResultadoAdulto> findResultadoAdultoEntities() {
        return findResultadoAdultoEntities(true, -1, -1);
    }

    public List<ResultadoAdulto> findResultadoAdultoEntities(int maxResults, int firstResult) {
        return findResultadoAdultoEntities(false, maxResults, firstResult);
    }

    private List<ResultadoAdulto> findResultadoAdultoEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(ResultadoAdulto.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public ResultadoAdulto findResultadoAdulto(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(ResultadoAdulto.class, id);
        } finally {
            em.close();
        }
    }

    public int getResultadoAdultoCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<ResultadoAdulto> rt = cq.from(ResultadoAdulto.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
