/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.AnalisisCefalometricoNinos;
import entidades.ResultadosNinos;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class ResultadosNinosJpaController implements Serializable {

    public ResultadosNinosJpaController(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(ResultadosNinos resultadosNinos) {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            AnalisisCefalometricoNinos analisisCefalometricoNinosId = resultadosNinos.getAnalisisCefalometricoNinosId();
            if (analisisCefalometricoNinosId != null) {
                analisisCefalometricoNinosId = em.getReference(analisisCefalometricoNinosId.getClass(), analisisCefalometricoNinosId.getId());
                resultadosNinos.setAnalisisCefalometricoNinosId(analisisCefalometricoNinosId);
            }
            em.persist(resultadosNinos);
            if (analisisCefalometricoNinosId != null) {
                analisisCefalometricoNinosId.getResultadosNinosCollection().add(resultadosNinos);
                analisisCefalometricoNinosId = em.merge(analisisCefalometricoNinosId);
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(ResultadosNinos resultadosNinos) throws NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ResultadosNinos persistentResultadosNinos = em.find(ResultadosNinos.class, resultadosNinos.getId());
            AnalisisCefalometricoNinos analisisCefalometricoNinosIdOld = persistentResultadosNinos.getAnalisisCefalometricoNinosId();
            AnalisisCefalometricoNinos analisisCefalometricoNinosIdNew = resultadosNinos.getAnalisisCefalometricoNinosId();
            if (analisisCefalometricoNinosIdNew != null) {
                analisisCefalometricoNinosIdNew = em.getReference(analisisCefalometricoNinosIdNew.getClass(), analisisCefalometricoNinosIdNew.getId());
                resultadosNinos.setAnalisisCefalometricoNinosId(analisisCefalometricoNinosIdNew);
            }
            resultadosNinos = em.merge(resultadosNinos);
            if (analisisCefalometricoNinosIdOld != null && !analisisCefalometricoNinosIdOld.equals(analisisCefalometricoNinosIdNew)) {
                analisisCefalometricoNinosIdOld.getResultadosNinosCollection().remove(resultadosNinos);
                analisisCefalometricoNinosIdOld = em.merge(analisisCefalometricoNinosIdOld);
            }
            if (analisisCefalometricoNinosIdNew != null && !analisisCefalometricoNinosIdNew.equals(analisisCefalometricoNinosIdOld)) {
                analisisCefalometricoNinosIdNew.getResultadosNinosCollection().add(resultadosNinos);
                analisisCefalometricoNinosIdNew = em.merge(analisisCefalometricoNinosIdNew);
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = resultadosNinos.getId();
                if (findResultadosNinos(id) == null) {
                    throw new NonexistentEntityException("The resultadosNinos with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            ResultadosNinos resultadosNinos;
            try {
                resultadosNinos = em.getReference(ResultadosNinos.class, id);
                resultadosNinos.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The resultadosNinos with id " + id + " no longer exists.", enfe);
            }
            AnalisisCefalometricoNinos analisisCefalometricoNinosId = resultadosNinos.getAnalisisCefalometricoNinosId();
            if (analisisCefalometricoNinosId != null) {
                analisisCefalometricoNinosId.getResultadosNinosCollection().remove(resultadosNinos);
                analisisCefalometricoNinosId = em.merge(analisisCefalometricoNinosId);
            }
            em.remove(resultadosNinos);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<ResultadosNinos> findResultadosNinosEntities() {
        return findResultadosNinosEntities(true, -1, -1);
    }

    public List<ResultadosNinos> findResultadosNinosEntities(int maxResults, int firstResult) {
        return findResultadosNinosEntities(false, maxResults, firstResult);
    }

    private List<ResultadosNinos> findResultadosNinosEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(ResultadosNinos.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public ResultadosNinos findResultadosNinos(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(ResultadosNinos.class, id);
        } finally {
            em.close();
        }
    }

    public int getResultadosNinosCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<ResultadosNinos> rt = cq.from(ResultadosNinos.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
