/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package controladores;

import controladores.exceptions.IllegalOrphanException;
import controladores.exceptions.NonexistentEntityException;
import java.io.Serializable;
import javax.persistence.Query;
import javax.persistence.EntityNotFoundException;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;
import entidades.Paciente;
import entidades.Personal;
import entidades.AutorizacionAdulto;
import entidades.AnalisisCefalometricoAdulto;
import entidades.AnalisisDeEspacio;
import entidades.AnalisisCefalometricoNinos;
import entidades.Autorizacion;
import entidades.Ortopedia;
import entidades.ActaEntrega;
import entidades.Ortopedia2;
import entidades.Ortopedia3;
import entidades.Remision;
import java.util.ArrayList;
import java.util.Collection;
import entidades.historia.HistoriaClinica;
import entidades.Evolucion;
import entidades.ReciboCaja;
import entidades.Tratamiento;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 *
 * @author ander
 */
public class TControl implements Serializable {

    public TControl(EntityManagerFactory emf) {
        this.emf = emf;
    }
    private EntityManagerFactory emf = null;

    public EntityManager getEntityManager() {
        return emf.createEntityManager();
    }

    public void create(Tratamiento tratamiento) throws IllegalOrphanException {
        if (tratamiento.getRemisionCollection() == null) {
            tratamiento.setRemisionCollection(new ArrayList<Remision>());
        }
        if (tratamiento.getHistoriaClinicaCollection() == null) {
            tratamiento.setHistoriaClinicaCollection(new ArrayList<HistoriaClinica>());
        }
        if (tratamiento.getEvolucion() == null) {
            tratamiento.setEvolucion(new ArrayList<Evolucion>());
        }
        if (tratamiento.getReciboCajaCollection() == null) {
            tratamiento.setReciboCajaCollection(new ArrayList<ReciboCaja>());
        }
        List<String> illegalOrphanMessages = null;
        AnalisisCefalometricoNinos analisisCefalometricoNinosOrphanCheck = tratamiento.getAnalisisCefalometricoNinos();
        if (analisisCefalometricoNinosOrphanCheck != null) {
            Tratamiento oldTratamientoIdOfAnalisisCefalometricoNinos = analisisCefalometricoNinosOrphanCheck.getTratamientoId();
            if (oldTratamientoIdOfAnalisisCefalometricoNinos != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The AnalisisCefalometricoNinos " + analisisCefalometricoNinosOrphanCheck + " already has an item of type Tratamiento whose analisisCefalometricoNinos column cannot be null. Please make another selection for the analisisCefalometricoNinos field.");
            }
        }
        ActaEntrega actaEntregaOrphanCheck = tratamiento.getActaEntrega();
        if (actaEntregaOrphanCheck != null) {
            Tratamiento oldTratamientoIdOfActaEntrega = actaEntregaOrphanCheck.getTratamientoId();
            if (oldTratamientoIdOfActaEntrega != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("The ActaEntrega " + actaEntregaOrphanCheck + " already has an item of type Tratamiento whose actaEntrega column cannot be null. Please make another selection for the actaEntrega field.");
            }
        }
        if (illegalOrphanMessages != null) {
            throw new IllegalOrphanException(illegalOrphanMessages);
        }
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Paciente pacienteId = tratamiento.getPacienteId();
            if (pacienteId != null) {
                pacienteId = em.getReference(pacienteId.getClass(), pacienteId.getId());
                tratamiento.setPacienteId(pacienteId);
            }
            Personal personalId = tratamiento.getPersonalId();
            if (personalId != null) {
                personalId = em.getReference(personalId.getClass(), personalId.getId());
                tratamiento.setPersonalId(personalId);
            }
            AutorizacionAdulto autorizacionAdulto = tratamiento.getAutorizacionAdulto();
            if (autorizacionAdulto != null) {
                autorizacionAdulto = em.getReference(autorizacionAdulto.getClass(), autorizacionAdulto.getId());
                tratamiento.setAutorizacionAdulto(autorizacionAdulto);
            }
            AnalisisCefalometricoAdulto analisisCefalometricoAdulto = tratamiento.getAnalisisCefalometricoAdulto();
            if (analisisCefalometricoAdulto != null) {
                analisisCefalometricoAdulto = em.getReference(analisisCefalometricoAdulto.getClass(), analisisCefalometricoAdulto.getId());
                tratamiento.setAnalisisCefalometricoAdulto(analisisCefalometricoAdulto);
            }
            AnalisisDeEspacio analisisDeEspacio = tratamiento.getAnalisisDeEspacio();
            if (analisisDeEspacio != null) {
                analisisDeEspacio = em.getReference(analisisDeEspacio.getClass(), analisisDeEspacio.getId());
                tratamiento.setAnalisisDeEspacio(analisisDeEspacio);
            }
            AnalisisCefalometricoNinos analisisCefalometricoNinos = tratamiento.getAnalisisCefalometricoNinos();
            if (analisisCefalometricoNinos != null) {
                analisisCefalometricoNinos = em.getReference(analisisCefalometricoNinos.getClass(), analisisCefalometricoNinos.getId());
                tratamiento.setAnalisisCefalometricoNinos(analisisCefalometricoNinos);
            }
            Autorizacion autorizacion = tratamiento.getAutorizacion();
            if (autorizacion != null) {
                autorizacion = em.getReference(autorizacion.getClass(), autorizacion.getId());
                tratamiento.setAutorizacion(autorizacion);
            }
            Ortopedia ortopedia = tratamiento.getOrtopedia();
            if (ortopedia != null) {
                ortopedia = em.getReference(ortopedia.getClass(), ortopedia.getId());
                tratamiento.setOrtopedia(ortopedia);
            }
            ActaEntrega actaEntrega = tratamiento.getActaEntrega();
            if (actaEntrega != null) {
                actaEntrega = em.getReference(actaEntrega.getClass(), actaEntrega.getId());
                tratamiento.setActaEntrega(actaEntrega);
            }
            Ortopedia2 ortopedia2 = tratamiento.getOrtopedia2();
            if (ortopedia2 != null) {
                ortopedia2 = em.getReference(ortopedia2.getClass(), ortopedia2.getId());
                tratamiento.setOrtopedia2(ortopedia2);
            }
            Ortopedia3 ortopedia3 = tratamiento.getOrtopedia3();
            if (ortopedia3 != null) {
                ortopedia3 = em.getReference(ortopedia3.getClass(), ortopedia3.getId());
                tratamiento.setOrtopedia3(ortopedia3);
            }
            Collection<Remision> attachedRemisionCollection = new ArrayList<Remision>();
            for (Remision remisionCollectionRemisionToAttach : tratamiento.getRemisionCollection()) {
                remisionCollectionRemisionToAttach = em.getReference(remisionCollectionRemisionToAttach.getClass(), remisionCollectionRemisionToAttach.getId());
                attachedRemisionCollection.add(remisionCollectionRemisionToAttach);
            }
            tratamiento.setRemisionCollection(attachedRemisionCollection);
            Collection<HistoriaClinica> attachedHistoriaClinicaCollection = new ArrayList<HistoriaClinica>();
            for (HistoriaClinica historiaClinicaCollectionHistoriaClinicaToAttach : tratamiento.getHistoriaClinicaCollection()) {
                historiaClinicaCollectionHistoriaClinicaToAttach = em.getReference(historiaClinicaCollectionHistoriaClinicaToAttach.getClass(), historiaClinicaCollectionHistoriaClinicaToAttach.getId());
                attachedHistoriaClinicaCollection.add(historiaClinicaCollectionHistoriaClinicaToAttach);
            }
            tratamiento.setHistoriaClinicaCollection(attachedHistoriaClinicaCollection);
            Collection<Evolucion> attachedEvolucion = new ArrayList<Evolucion>();
            for (Evolucion evolucionEvolucionToAttach : tratamiento.getEvolucion()) {
                evolucionEvolucionToAttach = em.getReference(evolucionEvolucionToAttach.getClass(), evolucionEvolucionToAttach.getId());
                attachedEvolucion.add(evolucionEvolucionToAttach);
            }
            tratamiento.setEvolucion(attachedEvolucion);
            Collection<ReciboCaja> attachedReciboCajaCollection = new ArrayList<ReciboCaja>();
            for (ReciboCaja reciboCajaCollectionReciboCajaToAttach : tratamiento.getReciboCajaCollection()) {
                reciboCajaCollectionReciboCajaToAttach = em.getReference(reciboCajaCollectionReciboCajaToAttach.getClass(), reciboCajaCollectionReciboCajaToAttach.getId());
                attachedReciboCajaCollection.add(reciboCajaCollectionReciboCajaToAttach);
            }
            tratamiento.setReciboCajaCollection(attachedReciboCajaCollection);
            em.persist(tratamiento);
            if (pacienteId != null) {
                pacienteId.getTratamientoCollection().add(tratamiento);
                pacienteId = em.merge(pacienteId);
            }
            if (personalId != null) {
                personalId.getTratamientoCollection().add(tratamiento);
                personalId = em.merge(personalId);
            }
            if (autorizacionAdulto != null) {
                Tratamiento oldTratamientoIdOfAutorizacionAdulto = autorizacionAdulto.getTratamientoId();
                if (oldTratamientoIdOfAutorizacionAdulto != null) {
                    oldTratamientoIdOfAutorizacionAdulto.setAutorizacionAdulto(null);
                    oldTratamientoIdOfAutorizacionAdulto = em.merge(oldTratamientoIdOfAutorizacionAdulto);
                }
                autorizacionAdulto.setTratamientoId(tratamiento);
                autorizacionAdulto = em.merge(autorizacionAdulto);
            }
            if (analisisCefalometricoAdulto != null) {
                Tratamiento oldTratamientoIdOfAnalisisCefalometricoAdulto = analisisCefalometricoAdulto.getTratamientoId();
                if (oldTratamientoIdOfAnalisisCefalometricoAdulto != null) {
                    oldTratamientoIdOfAnalisisCefalometricoAdulto.setAnalisisCefalometricoAdulto(null);
                    oldTratamientoIdOfAnalisisCefalometricoAdulto = em.merge(oldTratamientoIdOfAnalisisCefalometricoAdulto);
                }
                analisisCefalometricoAdulto.setTratamientoId(tratamiento);
                analisisCefalometricoAdulto = em.merge(analisisCefalometricoAdulto);
            }
            if (analisisDeEspacio != null) {
                Tratamiento oldTratamientoIdOfAnalisisDeEspacio = analisisDeEspacio.getTratamientoId();
                if (oldTratamientoIdOfAnalisisDeEspacio != null) {
                    oldTratamientoIdOfAnalisisDeEspacio.setAnalisisDeEspacio(null);
                    oldTratamientoIdOfAnalisisDeEspacio = em.merge(oldTratamientoIdOfAnalisisDeEspacio);
                }
                analisisDeEspacio.setTratamientoId(tratamiento);
                analisisDeEspacio = em.merge(analisisDeEspacio);
            }
            if (analisisCefalometricoNinos != null) {
                analisisCefalometricoNinos.setTratamientoId(tratamiento);
                analisisCefalometricoNinos = em.merge(analisisCefalometricoNinos);
            }
            if (autorizacion != null) {
                Tratamiento oldTratamientoIdOfAutorizacion = autorizacion.getTratamientoId();
                if (oldTratamientoIdOfAutorizacion != null) {
                    oldTratamientoIdOfAutorizacion.setAutorizacion(null);
                    oldTratamientoIdOfAutorizacion = em.merge(oldTratamientoIdOfAutorizacion);
                }
                autorizacion.setTratamientoId(tratamiento);
                autorizacion = em.merge(autorizacion);
            }
            if (ortopedia != null) {
                Tratamiento oldTratamientoIdOfOrtopedia = ortopedia.getTratamientoId();
                if (oldTratamientoIdOfOrtopedia != null) {
                    oldTratamientoIdOfOrtopedia.setOrtopedia(null);
                    oldTratamientoIdOfOrtopedia = em.merge(oldTratamientoIdOfOrtopedia);
                }
                ortopedia.setTratamientoId(tratamiento);
                ortopedia = em.merge(ortopedia);
            }
            if (actaEntrega != null) {
                actaEntrega.setTratamientoId(tratamiento);
                actaEntrega = em.merge(actaEntrega);
            }
            if (ortopedia2 != null) {
                Tratamiento oldTratamientoIdOfOrtopedia2 = ortopedia2.getTratamientoId();
                if (oldTratamientoIdOfOrtopedia2 != null) {
                    oldTratamientoIdOfOrtopedia2.setOrtopedia2(null);
                    oldTratamientoIdOfOrtopedia2 = em.merge(oldTratamientoIdOfOrtopedia2);
                }
                ortopedia2.setTratamientoId(tratamiento);
                ortopedia2 = em.merge(ortopedia2);
            }
            if (ortopedia3 != null) {
                Tratamiento oldTratamientoIdOfOrtopedia3 = ortopedia3.getTratamientoId();
                if (oldTratamientoIdOfOrtopedia3 != null) {
                    oldTratamientoIdOfOrtopedia3.setOrtopedia3(null);
                    oldTratamientoIdOfOrtopedia3 = em.merge(oldTratamientoIdOfOrtopedia3);
                }
                ortopedia3.setTratamientoId(tratamiento);
                ortopedia3 = em.merge(ortopedia3);
            }
            for (Remision remisionCollectionRemision : tratamiento.getRemisionCollection()) {
                Tratamiento oldTratamientoIdOfRemisionCollectionRemision = remisionCollectionRemision.getTratamientoId();
                remisionCollectionRemision.setTratamientoId(tratamiento);
                remisionCollectionRemision = em.merge(remisionCollectionRemision);
                if (oldTratamientoIdOfRemisionCollectionRemision != null) {
                    oldTratamientoIdOfRemisionCollectionRemision.getRemisionCollection().remove(remisionCollectionRemision);
                    oldTratamientoIdOfRemisionCollectionRemision = em.merge(oldTratamientoIdOfRemisionCollectionRemision);
                }
            }
            for (HistoriaClinica historiaClinicaCollectionHistoriaClinica : tratamiento.getHistoriaClinicaCollection()) {
                Tratamiento oldTratamientoIdOfHistoriaClinicaCollectionHistoriaClinica = historiaClinicaCollectionHistoriaClinica.getTratamientoId();
                historiaClinicaCollectionHistoriaClinica.setTratamientoId(tratamiento);
                historiaClinicaCollectionHistoriaClinica = em.merge(historiaClinicaCollectionHistoriaClinica);
                if (oldTratamientoIdOfHistoriaClinicaCollectionHistoriaClinica != null) {
                    oldTratamientoIdOfHistoriaClinicaCollectionHistoriaClinica.getHistoriaClinicaCollection().remove(historiaClinicaCollectionHistoriaClinica);
                    oldTratamientoIdOfHistoriaClinicaCollectionHistoriaClinica = em.merge(oldTratamientoIdOfHistoriaClinicaCollectionHistoriaClinica);
                }
            }
            for (Evolucion evolucionEvolucion : tratamiento.getEvolucion()) {
                Tratamiento oldTratamientoIdOfEvolucionEvolucion = evolucionEvolucion.getTratamientoId();
                evolucionEvolucion.setTratamientoId(tratamiento);
                evolucionEvolucion = em.merge(evolucionEvolucion);
                if (oldTratamientoIdOfEvolucionEvolucion != null) {
                    oldTratamientoIdOfEvolucionEvolucion.getEvolucion().remove(evolucionEvolucion);
                    oldTratamientoIdOfEvolucionEvolucion = em.merge(oldTratamientoIdOfEvolucionEvolucion);
                }
            }
            for (ReciboCaja reciboCajaCollectionReciboCaja : tratamiento.getReciboCajaCollection()) {
                Tratamiento oldTratamientoIdOfReciboCajaCollectionReciboCaja = reciboCajaCollectionReciboCaja.getTratamientoId();
                reciboCajaCollectionReciboCaja.setTratamientoId(tratamiento);
                reciboCajaCollectionReciboCaja = em.merge(reciboCajaCollectionReciboCaja);
                if (oldTratamientoIdOfReciboCajaCollectionReciboCaja != null) {
                    oldTratamientoIdOfReciboCajaCollectionReciboCaja.getReciboCajaCollection().remove(reciboCajaCollectionReciboCaja);
                    oldTratamientoIdOfReciboCajaCollectionReciboCaja = em.merge(oldTratamientoIdOfReciboCajaCollectionReciboCaja);
                }
            }
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void edit(Tratamiento tratamiento) throws IllegalOrphanException, NonexistentEntityException, Exception {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento persistentTratamiento = em.find(Tratamiento.class, tratamiento.getId());
            Paciente pacienteIdOld = persistentTratamiento.getPacienteId();
            Paciente pacienteIdNew = tratamiento.getPacienteId();
            Personal personalIdOld = persistentTratamiento.getPersonalId();
            Personal personalIdNew = tratamiento.getPersonalId();
            AutorizacionAdulto autorizacionAdultoOld = persistentTratamiento.getAutorizacionAdulto();
            AutorizacionAdulto autorizacionAdultoNew = tratamiento.getAutorizacionAdulto();
            AnalisisCefalometricoAdulto analisisCefalometricoAdultoOld = persistentTratamiento.getAnalisisCefalometricoAdulto();
            AnalisisCefalometricoAdulto analisisCefalometricoAdultoNew = tratamiento.getAnalisisCefalometricoAdulto();
            AnalisisDeEspacio analisisDeEspacioOld = persistentTratamiento.getAnalisisDeEspacio();
            AnalisisDeEspacio analisisDeEspacioNew = tratamiento.getAnalisisDeEspacio();
            AnalisisCefalometricoNinos analisisCefalometricoNinosOld = persistentTratamiento.getAnalisisCefalometricoNinos();
            AnalisisCefalometricoNinos analisisCefalometricoNinosNew = tratamiento.getAnalisisCefalometricoNinos();
            Autorizacion autorizacionOld = persistentTratamiento.getAutorizacion();
            Autorizacion autorizacionNew = tratamiento.getAutorizacion();
            Ortopedia ortopediaOld = persistentTratamiento.getOrtopedia();
            Ortopedia ortopediaNew = tratamiento.getOrtopedia();
            ActaEntrega actaEntregaOld = persistentTratamiento.getActaEntrega();
            ActaEntrega actaEntregaNew = tratamiento.getActaEntrega();
            Ortopedia2 ortopedia2Old = persistentTratamiento.getOrtopedia2();
            Ortopedia2 ortopedia2New = tratamiento.getOrtopedia2();
            Ortopedia3 ortopedia3Old = persistentTratamiento.getOrtopedia3();
            Ortopedia3 ortopedia3New = tratamiento.getOrtopedia3();
            Collection<Remision> remisionCollectionOld = persistentTratamiento.getRemisionCollection();
            Collection<Remision> remisionCollectionNew = tratamiento.getRemisionCollection();
            Collection<HistoriaClinica> historiaClinicaCollectionOld = persistentTratamiento.getHistoriaClinicaCollection();
            Collection<HistoriaClinica> historiaClinicaCollectionNew = tratamiento.getHistoriaClinicaCollection();
            Collection<Evolucion> evolucionOld = persistentTratamiento.getEvolucion();
            Collection<Evolucion> evolucionNew = tratamiento.getEvolucion();
            Collection<ReciboCaja> reciboCajaCollectionOld = persistentTratamiento.getReciboCajaCollection();
            Collection<ReciboCaja> reciboCajaCollectionNew = tratamiento.getReciboCajaCollection();
            List<String> illegalOrphanMessages = null;
            if (autorizacionAdultoOld != null && !autorizacionAdultoOld.equals(autorizacionAdultoNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain AutorizacionAdulto " + autorizacionAdultoOld + " since its tratamientoId field is not nullable.");
            }
            if (analisisCefalometricoAdultoOld != null && !analisisCefalometricoAdultoOld.equals(analisisCefalometricoAdultoNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain AnalisisCefalometricoAdulto " + analisisCefalometricoAdultoOld + " since its tratamientoId field is not nullable.");
            }
            if (analisisDeEspacioOld != null && !analisisDeEspacioOld.equals(analisisDeEspacioNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain AnalisisDeEspacio " + analisisDeEspacioOld + " since its tratamientoId field is not nullable.");
            }
            if (analisisCefalometricoNinosOld != null && !analisisCefalometricoNinosOld.equals(analisisCefalometricoNinosNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain AnalisisCefalometricoNinos " + analisisCefalometricoNinosOld + " since its tratamientoId field is not nullable.");
            }
            if (analisisCefalometricoNinosNew != null && !analisisCefalometricoNinosNew.equals(analisisCefalometricoNinosOld)) {
                Tratamiento oldTratamientoIdOfAnalisisCefalometricoNinos = analisisCefalometricoNinosNew.getTratamientoId();
                if (oldTratamientoIdOfAnalisisCefalometricoNinos != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The AnalisisCefalometricoNinos " + analisisCefalometricoNinosNew + " already has an item of type Tratamiento whose analisisCefalometricoNinos column cannot be null. Please make another selection for the analisisCefalometricoNinos field.");
                }
            }
            if (autorizacionOld != null && !autorizacionOld.equals(autorizacionNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain Autorizacion " + autorizacionOld + " since its tratamientoId field is not nullable.");
            }
            if (ortopediaOld != null && !ortopediaOld.equals(ortopediaNew)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain Ortopedia " + ortopediaOld + " since its tratamientoId field is not nullable.");
            }
            if (actaEntregaNew != null && !actaEntregaNew.equals(actaEntregaOld)) {
                Tratamiento oldTratamientoIdOfActaEntrega = actaEntregaNew.getTratamientoId();
                if (oldTratamientoIdOfActaEntrega != null) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("The ActaEntrega " + actaEntregaNew + " already has an item of type Tratamiento whose actaEntrega column cannot be null. Please make another selection for the actaEntrega field.");
                }
            }
            if (ortopedia2Old != null && !ortopedia2Old.equals(ortopedia2New)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain Ortopedia2 " + ortopedia2Old + " since its tratamientoId field is not nullable.");
            }
            if (ortopedia3Old != null && !ortopedia3Old.equals(ortopedia3New)) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("You must retain Ortopedia3 " + ortopedia3Old + " since its tratamientoId field is not nullable.");
            }
            for (Remision remisionCollectionOldRemision : remisionCollectionOld) {
                if (!remisionCollectionNew.contains(remisionCollectionOldRemision)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Remision " + remisionCollectionOldRemision + " since its tratamientoId field is not nullable.");
                }
            }
            for (HistoriaClinica historiaClinicaCollectionOldHistoriaClinica : historiaClinicaCollectionOld) {
                if (!historiaClinicaCollectionNew.contains(historiaClinicaCollectionOldHistoriaClinica)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain HistoriaClinica " + historiaClinicaCollectionOldHistoriaClinica + " since its tratamientoId field is not nullable.");
                }
            }
            for (Evolucion evolucionOldEvolucion : evolucionOld) {
                if (!evolucionNew.contains(evolucionOldEvolucion)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain Evolucion " + evolucionOldEvolucion + " since its tratamientoId field is not nullable.");
                }
            }
            for (ReciboCaja reciboCajaCollectionOldReciboCaja : reciboCajaCollectionOld) {
                if (!reciboCajaCollectionNew.contains(reciboCajaCollectionOldReciboCaja)) {
                    if (illegalOrphanMessages == null) {
                        illegalOrphanMessages = new ArrayList<String>();
                    }
                    illegalOrphanMessages.add("You must retain ReciboCaja " + reciboCajaCollectionOldReciboCaja + " since its tratamientoId field is not nullable.");
                }
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            if (pacienteIdNew != null) {
                pacienteIdNew = em.getReference(pacienteIdNew.getClass(), pacienteIdNew.getId());
                tratamiento.setPacienteId(pacienteIdNew);
            }
            if (personalIdNew != null) {
                personalIdNew = em.getReference(personalIdNew.getClass(), personalIdNew.getId());
                tratamiento.setPersonalId(personalIdNew);
            }
            if (autorizacionAdultoNew != null) {
                autorizacionAdultoNew = em.getReference(autorizacionAdultoNew.getClass(), autorizacionAdultoNew.getId());
                tratamiento.setAutorizacionAdulto(autorizacionAdultoNew);
            }
            if (analisisCefalometricoAdultoNew != null) {
                analisisCefalometricoAdultoNew = em.getReference(analisisCefalometricoAdultoNew.getClass(), analisisCefalometricoAdultoNew.getId());
                tratamiento.setAnalisisCefalometricoAdulto(analisisCefalometricoAdultoNew);
            }
            if (analisisDeEspacioNew != null) {
                analisisDeEspacioNew = em.getReference(analisisDeEspacioNew.getClass(), analisisDeEspacioNew.getId());
                tratamiento.setAnalisisDeEspacio(analisisDeEspacioNew);
            }
            if (analisisCefalometricoNinosNew != null) {
                analisisCefalometricoNinosNew = em.getReference(analisisCefalometricoNinosNew.getClass(), analisisCefalometricoNinosNew.getId());
                tratamiento.setAnalisisCefalometricoNinos(analisisCefalometricoNinosNew);
            }
            if (autorizacionNew != null) {
                autorizacionNew = em.getReference(autorizacionNew.getClass(), autorizacionNew.getId());
                tratamiento.setAutorizacion(autorizacionNew);
            }
            if (ortopediaNew != null) {
                ortopediaNew = em.getReference(ortopediaNew.getClass(), ortopediaNew.getId());
                tratamiento.setOrtopedia(ortopediaNew);
            }
            if (actaEntregaNew != null) {
                actaEntregaNew = em.getReference(actaEntregaNew.getClass(), actaEntregaNew.getId());
                tratamiento.setActaEntrega(actaEntregaNew);
            }
            if (ortopedia2New != null) {
                ortopedia2New = em.getReference(ortopedia2New.getClass(), ortopedia2New.getId());
                tratamiento.setOrtopedia2(ortopedia2New);
            }
            if (ortopedia3New != null) {
                ortopedia3New = em.getReference(ortopedia3New.getClass(), ortopedia3New.getId());
                tratamiento.setOrtopedia3(ortopedia3New);
            }
            Collection<Remision> attachedRemisionCollectionNew = new ArrayList<Remision>();
            for (Remision remisionCollectionNewRemisionToAttach : remisionCollectionNew) {
                remisionCollectionNewRemisionToAttach = em.getReference(remisionCollectionNewRemisionToAttach.getClass(), remisionCollectionNewRemisionToAttach.getId());
                attachedRemisionCollectionNew.add(remisionCollectionNewRemisionToAttach);
            }
            remisionCollectionNew = attachedRemisionCollectionNew;
            tratamiento.setRemisionCollection(remisionCollectionNew);
            Collection<HistoriaClinica> attachedHistoriaClinicaCollectionNew = new ArrayList<HistoriaClinica>();
            for (HistoriaClinica historiaClinicaCollectionNewHistoriaClinicaToAttach : historiaClinicaCollectionNew) {
                historiaClinicaCollectionNewHistoriaClinicaToAttach = em.getReference(historiaClinicaCollectionNewHistoriaClinicaToAttach.getClass(), historiaClinicaCollectionNewHistoriaClinicaToAttach.getId());
                attachedHistoriaClinicaCollectionNew.add(historiaClinicaCollectionNewHistoriaClinicaToAttach);
            }
            historiaClinicaCollectionNew = attachedHistoriaClinicaCollectionNew;
            tratamiento.setHistoriaClinicaCollection(historiaClinicaCollectionNew);
            Collection<Evolucion> attachedEvolucionNew = new ArrayList<Evolucion>();
            for (Evolucion evolucionNewEvolucionToAttach : evolucionNew) {
                evolucionNewEvolucionToAttach = em.getReference(evolucionNewEvolucionToAttach.getClass(), evolucionNewEvolucionToAttach.getId());
                attachedEvolucionNew.add(evolucionNewEvolucionToAttach);
            }
            evolucionNew = attachedEvolucionNew;
            tratamiento.setEvolucion(evolucionNew);
            Collection<ReciboCaja> attachedReciboCajaCollectionNew = new ArrayList<ReciboCaja>();
            for (ReciboCaja reciboCajaCollectionNewReciboCajaToAttach : reciboCajaCollectionNew) {
                reciboCajaCollectionNewReciboCajaToAttach = em.getReference(reciboCajaCollectionNewReciboCajaToAttach.getClass(), reciboCajaCollectionNewReciboCajaToAttach.getId());
                attachedReciboCajaCollectionNew.add(reciboCajaCollectionNewReciboCajaToAttach);
            }
            reciboCajaCollectionNew = attachedReciboCajaCollectionNew;
            tratamiento.setReciboCajaCollection(reciboCajaCollectionNew);
            tratamiento = em.merge(tratamiento);
            if (pacienteIdOld != null && !pacienteIdOld.equals(pacienteIdNew)) {
                pacienteIdOld.getTratamientoCollection().remove(tratamiento);
                pacienteIdOld = em.merge(pacienteIdOld);
            }
            if (pacienteIdNew != null && !pacienteIdNew.equals(pacienteIdOld)) {
                pacienteIdNew.getTratamientoCollection().add(tratamiento);
                pacienteIdNew = em.merge(pacienteIdNew);
            }
            if (personalIdOld != null && !personalIdOld.equals(personalIdNew)) {
                personalIdOld.getTratamientoCollection().remove(tratamiento);
                personalIdOld = em.merge(personalIdOld);
            }
            if (personalIdNew != null && !personalIdNew.equals(personalIdOld)) {
                personalIdNew.getTratamientoCollection().add(tratamiento);
                personalIdNew = em.merge(personalIdNew);
            }
            if (autorizacionAdultoNew != null && !autorizacionAdultoNew.equals(autorizacionAdultoOld)) {
                Tratamiento oldTratamientoIdOfAutorizacionAdulto = autorizacionAdultoNew.getTratamientoId();
                if (oldTratamientoIdOfAutorizacionAdulto != null) {
                    oldTratamientoIdOfAutorizacionAdulto.setAutorizacionAdulto(null);
                    oldTratamientoIdOfAutorizacionAdulto = em.merge(oldTratamientoIdOfAutorizacionAdulto);
                }
                autorizacionAdultoNew.setTratamientoId(tratamiento);
                autorizacionAdultoNew = em.merge(autorizacionAdultoNew);
            }
            if (analisisCefalometricoAdultoNew != null && !analisisCefalometricoAdultoNew.equals(analisisCefalometricoAdultoOld)) {
                Tratamiento oldTratamientoIdOfAnalisisCefalometricoAdulto = analisisCefalometricoAdultoNew.getTratamientoId();
                if (oldTratamientoIdOfAnalisisCefalometricoAdulto != null) {
                    oldTratamientoIdOfAnalisisCefalometricoAdulto.setAnalisisCefalometricoAdulto(null);
                    oldTratamientoIdOfAnalisisCefalometricoAdulto = em.merge(oldTratamientoIdOfAnalisisCefalometricoAdulto);
                }
                analisisCefalometricoAdultoNew.setTratamientoId(tratamiento);
                analisisCefalometricoAdultoNew = em.merge(analisisCefalometricoAdultoNew);
            }
            if (analisisDeEspacioNew != null && !analisisDeEspacioNew.equals(analisisDeEspacioOld)) {
                Tratamiento oldTratamientoIdOfAnalisisDeEspacio = analisisDeEspacioNew.getTratamientoId();
                if (oldTratamientoIdOfAnalisisDeEspacio != null) {
                    oldTratamientoIdOfAnalisisDeEspacio.setAnalisisDeEspacio(null);
                    oldTratamientoIdOfAnalisisDeEspacio = em.merge(oldTratamientoIdOfAnalisisDeEspacio);
                }
                analisisDeEspacioNew.setTratamientoId(tratamiento);
                analisisDeEspacioNew = em.merge(analisisDeEspacioNew);
            }
            if (analisisCefalometricoNinosNew != null && !analisisCefalometricoNinosNew.equals(analisisCefalometricoNinosOld)) {
                analisisCefalometricoNinosNew.setTratamientoId(tratamiento);
                analisisCefalometricoNinosNew = em.merge(analisisCefalometricoNinosNew);
            }
            if (autorizacionNew != null && !autorizacionNew.equals(autorizacionOld)) {
                Tratamiento oldTratamientoIdOfAutorizacion = autorizacionNew.getTratamientoId();
                if (oldTratamientoIdOfAutorizacion != null) {
                    oldTratamientoIdOfAutorizacion.setAutorizacion(null);
                    oldTratamientoIdOfAutorizacion = em.merge(oldTratamientoIdOfAutorizacion);
                }
                autorizacionNew.setTratamientoId(tratamiento);
                autorizacionNew = em.merge(autorizacionNew);
            }
            if (ortopediaNew != null && !ortopediaNew.equals(ortopediaOld)) {
                Tratamiento oldTratamientoIdOfOrtopedia = ortopediaNew.getTratamientoId();
                if (oldTratamientoIdOfOrtopedia != null) {
                    oldTratamientoIdOfOrtopedia.setOrtopedia(null);
                    oldTratamientoIdOfOrtopedia = em.merge(oldTratamientoIdOfOrtopedia);
                }
                ortopediaNew.setTratamientoId(tratamiento);
                ortopediaNew = em.merge(ortopediaNew);
            }
            if (actaEntregaOld != null && !actaEntregaOld.equals(actaEntregaNew)) {
                actaEntregaOld.setTratamientoId(null);
                actaEntregaOld = em.merge(actaEntregaOld);
            }
            if (actaEntregaNew != null && !actaEntregaNew.equals(actaEntregaOld)) {
                actaEntregaNew.setTratamientoId(tratamiento);
                actaEntregaNew = em.merge(actaEntregaNew);
            }
            if (ortopedia2New != null && !ortopedia2New.equals(ortopedia2Old)) {
                Tratamiento oldTratamientoIdOfOrtopedia2 = ortopedia2New.getTratamientoId();
                if (oldTratamientoIdOfOrtopedia2 != null) {
                    oldTratamientoIdOfOrtopedia2.setOrtopedia2(null);
                    oldTratamientoIdOfOrtopedia2 = em.merge(oldTratamientoIdOfOrtopedia2);
                }
                ortopedia2New.setTratamientoId(tratamiento);
                ortopedia2New = em.merge(ortopedia2New);
            }
            if (ortopedia3New != null && !ortopedia3New.equals(ortopedia3Old)) {
                Tratamiento oldTratamientoIdOfOrtopedia3 = ortopedia3New.getTratamientoId();
                if (oldTratamientoIdOfOrtopedia3 != null) {
                    oldTratamientoIdOfOrtopedia3.setOrtopedia3(null);
                    oldTratamientoIdOfOrtopedia3 = em.merge(oldTratamientoIdOfOrtopedia3);
                }
                ortopedia3New.setTratamientoId(tratamiento);
                ortopedia3New = em.merge(ortopedia3New);
            }
            for (Remision remisionCollectionNewRemision : remisionCollectionNew) {
                if (!remisionCollectionOld.contains(remisionCollectionNewRemision)) {
                    Tratamiento oldTratamientoIdOfRemisionCollectionNewRemision = remisionCollectionNewRemision.getTratamientoId();
                    remisionCollectionNewRemision.setTratamientoId(tratamiento);
                    remisionCollectionNewRemision = em.merge(remisionCollectionNewRemision);
                    if (oldTratamientoIdOfRemisionCollectionNewRemision != null && !oldTratamientoIdOfRemisionCollectionNewRemision.equals(tratamiento)) {
                        oldTratamientoIdOfRemisionCollectionNewRemision.getRemisionCollection().remove(remisionCollectionNewRemision);
                        oldTratamientoIdOfRemisionCollectionNewRemision = em.merge(oldTratamientoIdOfRemisionCollectionNewRemision);
                    }
                }
            }
            for (HistoriaClinica historiaClinicaCollectionNewHistoriaClinica : historiaClinicaCollectionNew) {
                if (!historiaClinicaCollectionOld.contains(historiaClinicaCollectionNewHistoriaClinica)) {
                    Tratamiento oldTratamientoIdOfHistoriaClinicaCollectionNewHistoriaClinica = historiaClinicaCollectionNewHistoriaClinica.getTratamientoId();
                    historiaClinicaCollectionNewHistoriaClinica.setTratamientoId(tratamiento);
                    historiaClinicaCollectionNewHistoriaClinica = em.merge(historiaClinicaCollectionNewHistoriaClinica);
                    if (oldTratamientoIdOfHistoriaClinicaCollectionNewHistoriaClinica != null && !oldTratamientoIdOfHistoriaClinicaCollectionNewHistoriaClinica.equals(tratamiento)) {
                        oldTratamientoIdOfHistoriaClinicaCollectionNewHistoriaClinica.getHistoriaClinicaCollection().remove(historiaClinicaCollectionNewHistoriaClinica);
                        oldTratamientoIdOfHistoriaClinicaCollectionNewHistoriaClinica = em.merge(oldTratamientoIdOfHistoriaClinicaCollectionNewHistoriaClinica);
                    }
                }
            }
            for (Evolucion evolucionNewEvolucion : evolucionNew) {
                if (!evolucionOld.contains(evolucionNewEvolucion)) {
                    Tratamiento oldTratamientoIdOfEvolucionNewEvolucion = evolucionNewEvolucion.getTratamientoId();
                    evolucionNewEvolucion.setTratamientoId(tratamiento);
                    evolucionNewEvolucion = em.merge(evolucionNewEvolucion);
                    if (oldTratamientoIdOfEvolucionNewEvolucion != null && !oldTratamientoIdOfEvolucionNewEvolucion.equals(tratamiento)) {
                        oldTratamientoIdOfEvolucionNewEvolucion.getEvolucion().remove(evolucionNewEvolucion);
                        oldTratamientoIdOfEvolucionNewEvolucion = em.merge(oldTratamientoIdOfEvolucionNewEvolucion);
                    }
                }
            }
            for (ReciboCaja reciboCajaCollectionNewReciboCaja : reciboCajaCollectionNew) {
                if (!reciboCajaCollectionOld.contains(reciboCajaCollectionNewReciboCaja)) {
                    Tratamiento oldTratamientoIdOfReciboCajaCollectionNewReciboCaja = reciboCajaCollectionNewReciboCaja.getTratamientoId();
                    reciboCajaCollectionNewReciboCaja.setTratamientoId(tratamiento);
                    reciboCajaCollectionNewReciboCaja = em.merge(reciboCajaCollectionNewReciboCaja);
                    if (oldTratamientoIdOfReciboCajaCollectionNewReciboCaja != null && !oldTratamientoIdOfReciboCajaCollectionNewReciboCaja.equals(tratamiento)) {
                        oldTratamientoIdOfReciboCajaCollectionNewReciboCaja.getReciboCajaCollection().remove(reciboCajaCollectionNewReciboCaja);
                        oldTratamientoIdOfReciboCajaCollectionNewReciboCaja = em.merge(oldTratamientoIdOfReciboCajaCollectionNewReciboCaja);
                    }
                }
            }
            em.getTransaction().commit();
        } catch (Exception ex) {
            String msg = ex.getLocalizedMessage();
            if (msg == null || msg.length() == 0) {
                Integer id = tratamiento.getId();
                if (findTratamiento(id) == null) {
                    throw new NonexistentEntityException("The tratamiento with id " + id + " no longer exists.");
                }
            }
            throw ex;
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public void destroy(Integer id) throws IllegalOrphanException, NonexistentEntityException {
        EntityManager em = null;
        try {
            em = getEntityManager();
            em.getTransaction().begin();
            Tratamiento tratamiento;
            try {
                tratamiento = em.getReference(Tratamiento.class, id);
                tratamiento.getId();
            } catch (EntityNotFoundException enfe) {
                throw new NonexistentEntityException("The tratamiento with id " + id + " no longer exists.", enfe);
            }
            List<String> illegalOrphanMessages = null;
            AutorizacionAdulto autorizacionAdultoOrphanCheck = tratamiento.getAutorizacionAdulto();
            if (autorizacionAdultoOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the AutorizacionAdulto " + autorizacionAdultoOrphanCheck + " in its autorizacionAdulto field has a non-nullable tratamientoId field.");
            }
            AnalisisCefalometricoAdulto analisisCefalometricoAdultoOrphanCheck = tratamiento.getAnalisisCefalometricoAdulto();
            if (analisisCefalometricoAdultoOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the AnalisisCefalometricoAdulto " + analisisCefalometricoAdultoOrphanCheck + " in its analisisCefalometricoAdulto field has a non-nullable tratamientoId field.");
            }
            AnalisisDeEspacio analisisDeEspacioOrphanCheck = tratamiento.getAnalisisDeEspacio();
            if (analisisDeEspacioOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the AnalisisDeEspacio " + analisisDeEspacioOrphanCheck + " in its analisisDeEspacio field has a non-nullable tratamientoId field.");
            }
            AnalisisCefalometricoNinos analisisCefalometricoNinosOrphanCheck = tratamiento.getAnalisisCefalometricoNinos();
            if (analisisCefalometricoNinosOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the AnalisisCefalometricoNinos " + analisisCefalometricoNinosOrphanCheck + " in its analisisCefalometricoNinos field has a non-nullable tratamientoId field.");
            }
            Autorizacion autorizacionOrphanCheck = tratamiento.getAutorizacion();
            if (autorizacionOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the Autorizacion " + autorizacionOrphanCheck + " in its autorizacion field has a non-nullable tratamientoId field.");
            }
            Ortopedia ortopediaOrphanCheck = tratamiento.getOrtopedia();
            if (ortopediaOrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the Ortopedia " + ortopediaOrphanCheck + " in its ortopedia field has a non-nullable tratamientoId field.");
            }
            Ortopedia2 ortopedia2OrphanCheck = tratamiento.getOrtopedia2();
            if (ortopedia2OrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the Ortopedia2 " + ortopedia2OrphanCheck + " in its ortopedia2 field has a non-nullable tratamientoId field.");
            }
            Ortopedia3 ortopedia3OrphanCheck = tratamiento.getOrtopedia3();
            if (ortopedia3OrphanCheck != null) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the Ortopedia3 " + ortopedia3OrphanCheck + " in its ortopedia3 field has a non-nullable tratamientoId field.");
            }
            Collection<Remision> remisionCollectionOrphanCheck = tratamiento.getRemisionCollection();
            for (Remision remisionCollectionOrphanCheckRemision : remisionCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the Remision " + remisionCollectionOrphanCheckRemision + " in its remisionCollection field has a non-nullable tratamientoId field.");
            }
            Collection<HistoriaClinica> historiaClinicaCollectionOrphanCheck = tratamiento.getHistoriaClinicaCollection();
            for (HistoriaClinica historiaClinicaCollectionOrphanCheckHistoriaClinica : historiaClinicaCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the HistoriaClinica " + historiaClinicaCollectionOrphanCheckHistoriaClinica + " in its historiaClinicaCollection field has a non-nullable tratamientoId field.");
            }
            Collection<Evolucion> evolucionOrphanCheck = tratamiento.getEvolucion();
            for (Evolucion evolucionOrphanCheckEvolucion : evolucionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the Evolucion " + evolucionOrphanCheckEvolucion + " in its evolucion field has a non-nullable tratamientoId field.");
            }
            Collection<ReciboCaja> reciboCajaCollectionOrphanCheck = tratamiento.getReciboCajaCollection();
            for (ReciboCaja reciboCajaCollectionOrphanCheckReciboCaja : reciboCajaCollectionOrphanCheck) {
                if (illegalOrphanMessages == null) {
                    illegalOrphanMessages = new ArrayList<String>();
                }
                illegalOrphanMessages.add("This Tratamiento (" + tratamiento + ") cannot be destroyed since the ReciboCaja " + reciboCajaCollectionOrphanCheckReciboCaja + " in its reciboCajaCollection field has a non-nullable tratamientoId field.");
            }
            if (illegalOrphanMessages != null) {
                throw new IllegalOrphanException(illegalOrphanMessages);
            }
            Paciente pacienteId = tratamiento.getPacienteId();
            if (pacienteId != null) {
                pacienteId.getTratamientoCollection().remove(tratamiento);
                pacienteId = em.merge(pacienteId);
            }
            Personal personalId = tratamiento.getPersonalId();
            if (personalId != null) {
                personalId.getTratamientoCollection().remove(tratamiento);
                personalId = em.merge(personalId);
            }
            ActaEntrega actaEntrega = tratamiento.getActaEntrega();
            if (actaEntrega != null) {
                actaEntrega.setTratamientoId(null);
                actaEntrega = em.merge(actaEntrega);
            }
            em.remove(tratamiento);
            em.getTransaction().commit();
        } finally {
            if (em != null) {
                em.close();
            }
        }
    }

    public List<Tratamiento> findTratamientoEntities() {
        return findTratamientoEntities(true, -1, -1);
    }

    public List<Tratamiento> findTratamientoEntities(int maxResults, int firstResult) {
        return findTratamientoEntities(false, maxResults, firstResult);
    }

    private List<Tratamiento> findTratamientoEntities(boolean all, int maxResults, int firstResult) {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            cq.select(cq.from(Tratamiento.class));
            Query q = em.createQuery(cq);
            if (!all) {
                q.setMaxResults(maxResults);
                q.setFirstResult(firstResult);
            }
            return q.getResultList();
        } finally {
            em.close();
        }
    }

    public Tratamiento findTratamiento(Integer id) {
        EntityManager em = getEntityManager();
        try {
            return em.find(Tratamiento.class, id);
        } finally {
            em.close();
        }
    }

    public int getTratamientoCount() {
        EntityManager em = getEntityManager();
        try {
            CriteriaQuery cq = em.getCriteriaBuilder().createQuery();
            Root<Tratamiento> rt = cq.from(Tratamiento.class);
            cq.select(em.getCriteriaBuilder().count(rt));
            Query q = em.createQuery(cq);
            return ((Long) q.getSingleResult()).intValue();
        } finally {
            em.close();
        }
    }
    
}
