/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "acta_entrega")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "ActaEntrega.findAll", query = "SELECT a FROM ActaEntrega a"),
    @NamedQuery(name = "ActaEntrega.findById", query = "SELECT a FROM ActaEntrega a WHERE a.id = :id"),
    @NamedQuery(name = "ActaEntrega.findByYo", query = "SELECT a FROM ActaEntrega a WHERE a.yo = :yo"),
    @NamedQuery(name = "ActaEntrega.findByIdentificadoCon", query = "SELECT a FROM ActaEntrega a WHERE a.identificadoCon = :identificadoCon"),
    @NamedQuery(name = "ActaEntrega.findByNumero", query = "SELECT a FROM ActaEntrega a WHERE a.numero = :numero"),
    @NamedQuery(name = "ActaEntrega.findByRegistros", query = "SELECT a FROM ActaEntrega a WHERE a.registros = :registros"),
    @NamedQuery(name = "ActaEntrega.findByPaciente", query = "SELECT a FROM ActaEntrega a WHERE a.paciente = :paciente"),
    @NamedQuery(name = "ActaEntrega.findByFechaFirma", query = "SELECT a FROM ActaEntrega a WHERE a.fechaFirma = :fechaFirma"),
    @NamedQuery(name = "ActaEntrega.findByNombre", query = "SELECT a FROM ActaEntrega a WHERE a.nombre = :nombre"),
    @NamedQuery(name = "ActaEntrega.findByDocNumero", query = "SELECT a FROM ActaEntrega a WHERE a.docNumero = :docNumero"),
    @NamedQuery(name = "ActaEntrega.findByPopayan", query = "SELECT a FROM ActaEntrega a WHERE a.popayan = :popayan")})
public class ActaEntrega implements Serializable {
    public static final String PROP_HUELLA = "PROP_HUELLA";
    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "yo")
    private String yo;
    @Basic(optional = false)
    @Column(name = "identificado_con")
    private String identificadoCon;
    @Basic(optional = false)
    @Column(name = "numero")
    private String numero;
    @Basic(optional = false)
    @Column(name = "registros")
    private String registros;
    @Basic(optional = false)
    @Column(name = "paciente")
    private String paciente;
    @Basic(optional = false)
    @Column(name = "fecha_firma")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fechaFirma;
    @Basic(optional = false)
    @Column(name = "nombre")
    private String nombre;
    @Basic(optional = false)
    @Column(name = "doc_numero")
    private String docNumero;
    @Basic(optional = false)
    @Lob
    @Column(name = "firma")
    private byte[] firma;
    @Lob
    @Column(name = "huella")
    private byte[] huella;
    @Basic(optional = false)
    @Column(name = "popayan")
    private String popayan;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @OneToOne(optional = true, fetch = FetchType.LAZY)
    private Tratamiento tratamientoId;

    public ActaEntrega() {
    }

    public ActaEntrega(Integer id) {
        this.id = id;
    }

    public ActaEntrega(Integer id, String yo, String identificadoCon, String numero, String registros, String paciente, Date fechaFirma, String nombre, String docNumero, byte[] firma, String popayan) {
        this.id = id;
        this.yo = yo;
        this.identificadoCon = identificadoCon;
        this.numero = numero;
        this.registros = registros;
        this.paciente = paciente;
        this.fechaFirma = fechaFirma;
        this.nombre = nombre;
        this.docNumero = docNumero;
        this.firma = firma;
        this.popayan = popayan;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public String getYo() {
        return yo;
    }

    public void setYo(String yo) {
        String oldYo = this.yo;
        this.yo = yo;
        changeSupport.firePropertyChange("yo", oldYo, yo);
    }

    public String getIdentificadoCon() {
        return identificadoCon;
    }

    public void setIdentificadoCon(String identificadoCon) {
        String oldIdentificadoCon = this.identificadoCon;
        this.identificadoCon = identificadoCon;
        changeSupport.firePropertyChange("identificadoCon", oldIdentificadoCon, identificadoCon);
    }

    public String getNumero() {
        return numero;
    }

    public void setNumero(String numero) {
        String oldNumero = this.numero;
        this.numero = numero;
        changeSupport.firePropertyChange("numero", oldNumero, numero);
    }

    public String getRegistros() {
        return registros;
    }

    public void setRegistros(String registros) {
        String oldRegistros = this.registros;
        this.registros = registros;
        changeSupport.firePropertyChange("registros", oldRegistros, registros);
    }

    public String getPaciente() {
        return paciente;
    }

    public void setPaciente(String paciente) {
        String oldPaciente = this.paciente;
        this.paciente = paciente;
        changeSupport.firePropertyChange("paciente", oldPaciente, paciente);
    }

    public Date getFechaFirma() {
        return fechaFirma;
    }

    public void setFechaFirma(Date fechaFirma) {
        Date oldFechaFirma = this.fechaFirma;
        this.fechaFirma = fechaFirma;
        changeSupport.firePropertyChange("fechaFirma", oldFechaFirma, fechaFirma);
    }

    public String getNombre() {
        return nombre;
    }

    public void setNombre(String nombre) {
        String oldNombre = this.nombre;
        this.nombre = nombre;
        changeSupport.firePropertyChange("nombre", oldNombre, nombre);
    }

    public String getDocNumero() {
        return docNumero;
    }

    public void setDocNumero(String docNumero) {
        String oldDocNumero = this.docNumero;
        this.docNumero = docNumero;
        changeSupport.firePropertyChange("docNumero", oldDocNumero, docNumero);
    }

    public byte[] getFirma() {
        return firma;
    }

    public void setFirma(byte[] firma) {
        byte[] oldFirma = this.firma;
        this.firma = firma;
        changeSupport.firePropertyChange("firma", oldFirma, firma);
    }

    public String getPopayan() {
        return popayan;
    }

    public void setPopayan(String popayan) {
        String oldPopayan = this.popayan;
        this.popayan = popayan;
        changeSupport.firePropertyChange("popayan", oldPopayan, popayan);
    }

    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    public void setTratamientoId(Tratamiento tratamientoId) {
        Tratamiento oldTratamientoId = this.tratamientoId;
        this.tratamientoId = tratamientoId;
        changeSupport.firePropertyChange("tratamientoId", oldTratamientoId, tratamientoId);
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof ActaEntrega)) {
            return false;
        }
        ActaEntrega other = (ActaEntrega) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.ActaEntrega[ id=" + id + " ]";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    /**
     * @return the huella
     */
    public byte[] getHuella() {
        return huella;
    }

    /**
     * @param huella the huella to set
     */
    public void setHuella(byte[] huella) {
        byte[] oldHuella = this.huella;
        this.huella = huella;
        changeSupport.firePropertyChange(PROP_HUELLA, oldHuella, huella);
    }

}
