/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import entidades.Tratamiento;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Collection;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "analisis_cefalometrico_adulto")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findAll", query = "SELECT a FROM AnalisisCefalometricoAdulto a"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findById", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.id = :id"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByFecha", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.fecha = :fecha"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByClase", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.clase = :clase"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByPatronCrecimiento", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.patronCrecimiento = :patronCrecimiento"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByAlturaFacialAnterior", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.alturaFacialAnterior = :alturaFacialAnterior"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByNuevoAtributo", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.nuevoAtributo = :nuevoAtributo"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByProtusionDentoalvolar", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.protusionDentoalvolar = :protusionDentoalvolar"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByRetrusionDentoalvolar", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.retrusionDentoalvolar = :retrusionDentoalvolar"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByInclinacionDental", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.inclinacionDental = :inclinacionDental"),  
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByTipoPerfil", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.tipoPerfil = :tipoPerfil"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByLabios", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.labios = :labios"),
    @NamedQuery(name = "AnalisisCefalometricoAdulto.findByAnguloNl", query = "SELECT a FROM AnalisisCefalometricoAdulto a WHERE a.anguloNl = :anguloNl")})
public class AnalisisCefalometricoAdulto implements Serializable {
    private static final long serialVersionUID = 1L;
    public static final String PROP_RESULTADOADULTOCOLLECTION = "PROP_RESULTADOADULTOCOLLECTION";
    public static final String PROP_DPROTUSIONR = "PROP_DPROTUSIONR";
    public static final String PROP_DRETRUSION = "PROP_DRETRUSION";
    public static final String PROP_DINCLINACION = "PROP_DINCLINACION";
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Basic(optional = false)
    @Column(name = "clase")
    private String clase;
    @Basic(optional = false)
    @Column(name = "patron_crecimiento")
    private String patronCrecimiento;
    @Basic(optional = false)
    @Column(name = "altura_facial_anterior")
    private String alturaFacialAnterior;
    @Basic(optional = false)
    @Column(name = "descripcion")
    private String nuevoAtributo;
    @Basic(optional = false)
    @Column(name = "protusion_dentoalvolar")
    private String protusionDentoalvolar;
    @Basic(optional = false)
    @Column(name = "retrusion_dentoalvolar")
    private String retrusionDentoalvolar;
    @Basic(optional = false)
    @Column(name = "inclinacion_dental")
    private String inclinacionDental;   
    @Column(name = "d_protusion")
    private String dProtusionr;
    @Basic(optional = false)
    @Column(name = "d_retrusion")
    private String dRetrusion;
    @Basic(optional = false)
    @Column(name = "d_inclinacion")
    private String dInclinacion; 
    @Basic(optional = false)
    @Column(name = "tipo_perfil")
    private String tipoPerfil;
    @Basic(optional = false)
    @Column(name = "labios")
    private String labios;
    @Basic(optional = false)
    @Column(name = "angulo_nl")
    private String anguloNl;    
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @OneToOne(optional = false, fetch = FetchType.LAZY)
    private Tratamiento tratamientoId;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "analisisCefalometricoAdultoId")
    private Collection<ResultadoAdulto> resultadoAdultoCollection;
    @Transient
    private final transient PropertyChangeSupport propertyChangeSupport = new java.beans.PropertyChangeSupport(this);

    public AnalisisCefalometricoAdulto() {
    }

    public AnalisisCefalometricoAdulto(Integer id) {
        this.id = id;
    }

    public AnalisisCefalometricoAdulto(Integer id, Date fecha, String clase, String patronCrecimiento, String alturaFacialAnterior, String nuevoAtributo, String protusionDentoalvolar, String retrusionDentoalvolar, String inclinacionDental, String lineaDeRickettsPuntaNarizPog, String tipoPerfil, String labios, String anguloNl) {
        this.id = id;
        this.fecha = fecha;
        this.clase = clase;
        this.patronCrecimiento = patronCrecimiento;
        this.alturaFacialAnterior = alturaFacialAnterior;
        this.nuevoAtributo = nuevoAtributo;
        this.protusionDentoalvolar = protusionDentoalvolar;
        this.retrusionDentoalvolar = retrusionDentoalvolar;
        this.inclinacionDental = inclinacionDental;
     
        this.tipoPerfil = tipoPerfil;
        this.labios = labios;
        this.anguloNl = anguloNl;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        propertyChangeSupport.firePropertyChange("id", oldId, id);
    }

    public Date getFecha() {
        return fecha;
    }

    public void setFecha(Date fecha) {
        Date oldFecha = this.fecha;
        this.fecha = fecha;
        propertyChangeSupport.firePropertyChange("fecha", oldFecha, fecha);
    }

    public String getClase() {
        return clase;
    }

    public void setClase(String clase) {
        String oldClase = this.clase;
        this.clase = clase;
        propertyChangeSupport.firePropertyChange("clase", oldClase, clase);
    }

    public String getPatronCrecimiento() {
        return patronCrecimiento;
    }

    public void setPatronCrecimiento(String patronCrecimiento) {
        String oldPatronCrecimiento = this.patronCrecimiento;
        this.patronCrecimiento = patronCrecimiento;
        propertyChangeSupport.firePropertyChange("patronCrecimiento", oldPatronCrecimiento, patronCrecimiento);
    }

    public String getAlturaFacialAnterior() {
        return alturaFacialAnterior;
    }

    public void setAlturaFacialAnterior(String alturaFacialAnterior) {
        String oldAlturaFacialAnterior = this.alturaFacialAnterior;
        this.alturaFacialAnterior = alturaFacialAnterior;
        propertyChangeSupport.firePropertyChange("alturaFacialAnterior", oldAlturaFacialAnterior, alturaFacialAnterior);
    }

    public String getNuevoAtributo() {
        return nuevoAtributo;
    }

    public void setNuevoAtributo(String nuevoAtributo) {
        String oldNuevoAtributo = this.nuevoAtributo;
        this.nuevoAtributo = nuevoAtributo;
        propertyChangeSupport.firePropertyChange("nuevoAtributo", oldNuevoAtributo, nuevoAtributo);
    }

    public String getProtusionDentoalvolar() {
        return protusionDentoalvolar;
    }

    public void setProtusionDentoalvolar(String protusionDentoalvolar) {
        String oldProtusionDentoalvolar = this.protusionDentoalvolar;
        this.protusionDentoalvolar = protusionDentoalvolar;
        propertyChangeSupport.firePropertyChange("protusionDentoalvolar", oldProtusionDentoalvolar, protusionDentoalvolar);
    }

    public String getRetrusionDentoalvolar() {
        return retrusionDentoalvolar;
    }

    public void setRetrusionDentoalvolar(String retrusionDentoalvolar) {
        String oldRetrusionDentoalvolar = this.retrusionDentoalvolar;
        this.retrusionDentoalvolar = retrusionDentoalvolar;
        propertyChangeSupport.firePropertyChange("retrusionDentoalvolar", oldRetrusionDentoalvolar, retrusionDentoalvolar);
    }

    public String getInclinacionDental() {
        return inclinacionDental;
    }

    public void setInclinacionDental(String inclinacionDental) {
        String oldInclinacionDental = this.inclinacionDental;
        this.inclinacionDental = inclinacionDental;
        propertyChangeSupport.firePropertyChange("inclinacionDental", oldInclinacionDental, inclinacionDental);
    }
    public String getTipoPerfil() {
        return tipoPerfil;
    }

    public void setTipoPerfil(String tipoPerfil) {
        String oldTipoPerfil = this.tipoPerfil;
        this.tipoPerfil = tipoPerfil;
        propertyChangeSupport.firePropertyChange("tipoPerfil", oldTipoPerfil, tipoPerfil);
    }

    public String getLabios() {
        return labios;
    }

    public void setLabios(String labios) {
        String oldLabios = this.labios;
        this.labios = labios;
        propertyChangeSupport.firePropertyChange("labios", oldLabios, labios);
    }

    public String getAnguloNl() {
        return anguloNl;
    }

    public void setAnguloNl(String anguloNl) {
        String oldAnguloNl = this.anguloNl;
        this.anguloNl = anguloNl;
        propertyChangeSupport.firePropertyChange("anguloNl", oldAnguloNl, anguloNl);
    }

    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    public void setTratamientoId(Tratamiento tratamientoId) {
        this.tratamientoId = tratamientoId;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof AnalisisCefalometricoAdulto)) {
            return false;
        }
        AnalisisCefalometricoAdulto other = (AnalisisCefalometricoAdulto) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.AnalisisCefalometricoAdulto[ id=" + id + " ]";
    }
     @XmlTransient
    /**
     * @return the resultadoAdultoCollection
     */
    public Collection<ResultadoAdulto> getResultadoAdultoCollection() {
        return resultadoAdultoCollection;
    }

    /**
     * @param resultadoAdultoCollection the resultadoAdultoCollection to set
     */
    public void setResultadoAdultoCollection(Collection<ResultadoAdulto> resultadoAdultoCollection) {
        java.util.Collection<entidades.ResultadoAdulto> oldResultadoAdultoCollection = this.resultadoAdultoCollection;
        this.resultadoAdultoCollection = resultadoAdultoCollection;
        propertyChangeSupport.firePropertyChange(PROP_RESULTADOADULTOCOLLECTION, oldResultadoAdultoCollection, resultadoAdultoCollection);
    }

    /**
     * @return the dProtusionr
     */
    public String getdProtusionr() {
        return dProtusionr;
    }

    /**
     * @param dProtusionr the dProtusionr to set
     */
    public void setdProtusionr(String dProtusionr) {
        java.lang.String olddProtusionr = this.dProtusionr;
        this.dProtusionr = dProtusionr;
        propertyChangeSupport.firePropertyChange(PROP_DPROTUSIONR, olddProtusionr, dProtusionr);
    }

    /**
     * @return the dRetrusion
     */
    public String getdRetrusion() {
        return dRetrusion;
    }

    /**
     * @param dRetrusion the dRetrusion to set
     */
    public void setdRetrusion(String dRetrusion) {
        java.lang.String olddRetrusion = this.dRetrusion;
        this.dRetrusion = dRetrusion;
        propertyChangeSupport.firePropertyChange(PROP_DRETRUSION, olddRetrusion, dRetrusion);
    }

    /**
     * @return the dInclinacion
     */
    public String getdInclinacion() {
        return dInclinacion;
    }

    /**
     * @param dInclinacion the dInclinacion to set
     */
    public void setdInclinacion(String dInclinacion) {
        java.lang.String olddInclinacion = this.dInclinacion;
        this.dInclinacion = dInclinacion;
        propertyChangeSupport.firePropertyChange(PROP_DINCLINACION, olddInclinacion, dInclinacion);
    }

}
