/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import entidades.PlanTratamiento;
import entidades.Tratamiento;
import java.io.Serializable;
import java.util.Collection;
import java.util.Collections;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "analisis_de espacio")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "AnalisisDeEspacio.findAll", query = "SELECT a FROM AnalisisDeEspacio a"),
    @NamedQuery(name = "AnalisisDeEspacio.findById", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.id = :id"),
    @NamedQuery(name = "AnalisisDeEspacio.findByLineaMediaDerecha", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.lineaMediaDerecha = :lineaMediaDerecha"),
    @NamedQuery(name = "AnalisisDeEspacio.findByLineaMediaIzquierda", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.lineaMediaIzquierda = :lineaMediaIzquierda"),
    @NamedQuery(name = "AnalisisDeEspacio.findByApi\u00f1amiento", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.api\u00f1amiento = :api\u00f1amiento"),
    @NamedQuery(name = "AnalisisDeEspacio.findByApinamientoIzquierda", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.apinamientoIzquierda = :apinamientoIzquierda"),
    @NamedQuery(name = "AnalisisDeEspacio.findByCurvaSpeeDerecha", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.curvaSpeeDerecha = :curvaSpeeDerecha"),
    @NamedQuery(name = "AnalisisDeEspacio.findByCurvaSpeeIzquierda", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.curvaSpeeIzquierda = :curvaSpeeIzquierda"),
    @NamedQuery(name = "AnalisisDeEspacio.findByPerfilDerecha", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.perfilDerecha = :perfilDerecha"),
    @NamedQuery(name = "AnalisisDeEspacio.findByPerfilIsquierda", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.perfilIsquierda = :perfilIsquierda"),
    @NamedQuery(name = "AnalisisDeEspacio.findByExodonciasDerecha", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.exodonciasDerecha = :exodonciasDerecha"),
    @NamedQuery(name = "AnalisisDeEspacio.findByExodonciasIzquierda", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.exodonciasIzquierda = :exodonciasIzquierda"),
    @NamedQuery(name = "AnalisisDeEspacio.findByMovMolarInfDerecha", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.movMolarInfDerecha = :movMolarInfDerecha"),
    @NamedQuery(name = "AnalisisDeEspacio.findByMovMolarInfIzquierda", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.movMolarInfIzquierda = :movMolarInfIzquierda"),
    @NamedQuery(name = "AnalisisDeEspacio.findByRelacionMolarDerecha", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.relacionMolarDerecha = :relacionMolarDerecha"),
    @NamedQuery(name = "AnalisisDeEspacio.findByRelacionMolarIzquierda", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.relacionMolarIzquierda = :relacionMolarIzquierda"),
    @NamedQuery(name = "AnalisisDeEspacio.findByMovMolarInfDerecha2", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.movMolarInfDerecha2 = :movMolarInfDerecha2"),
    @NamedQuery(name = "AnalisisDeEspacio.findByMovMolarInfIzquierda2", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.movMolarInfIzquierda2 = :movMolarInfIzquierda2"),
    @NamedQuery(name = "AnalisisDeEspacio.findByFacial", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.facial = :facial"),
    @NamedQuery(name = "AnalisisDeEspacio.findByPeriodontal", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.periodontal = :periodontal"),
    @NamedQuery(name = "AnalisisDeEspacio.findByEsqueletico", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.esqueletico = :esqueletico"),
    @NamedQuery(name = "AnalisisDeEspacio.findByDetalOclusal", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.detalOclusal = :detalOclusal"),
    @NamedQuery(name = "AnalisisDeEspacio.findByFuncional", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.funcional = :funcional"),
    @NamedQuery(name = "AnalisisDeEspacio.findByInterconsulta", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.interconsulta = :interconsulta"),
    @NamedQuery(name = "AnalisisDeEspacio.findByAnclaje", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.anclaje = :anclaje"),
    @NamedQuery(name = "AnalisisDeEspacio.findByLimitacionesRiesgos", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.limitacionesRiesgos = :limitacionesRiesgos"),
    @NamedQuery(name = "AnalisisDeEspacio.findByCosto", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.costo = :costo"),
    @NamedQuery(name = "AnalisisDeEspacio.findByCuotaInicial", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.cuotaInicial = :cuotaInicial"),
    @NamedQuery(name = "AnalisisDeEspacio.findByNumControles", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.numControles = :numControles"),
    @NamedQuery(name = "AnalisisDeEspacio.findByValorControles", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.valorControles = :valorControles"),
    @NamedQuery(name = "AnalisisDeEspacio.findByRetenedores", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.retenedores = :retenedores"),
    @NamedQuery(name = "AnalisisDeEspacio.findByReparaciones", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.reparaciones = :reparaciones"),
    @NamedQuery(name = "AnalisisDeEspacio.findByAnclajes", query = "SELECT a FROM AnalisisDeEspacio a WHERE a.anclajes = :anclajes")})
public class AnalisisDeEspacio implements Serializable {
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "linea_media_derecha")
    private String lineaMediaDerecha;
    @Basic(optional = false)
    @Column(name = "linea_media_izquierda")
    private String lineaMediaIzquierda;
    @Basic(optional = false)
    @Column(name = "apinamiento")
    private String apiñamiento;
    @Basic(optional = false)
    @Column(name = "apinamiento_izquierda")
    private String apinamientoIzquierda;
    @Basic(optional = false)
    @Column(name = "curva_spee_derecha")
    private String curvaSpeeDerecha;
    @Basic(optional = false)
    @Column(name = "curva_spee_izquierda")
    private String curvaSpeeIzquierda;
    @Basic(optional = false)
    @Column(name = "perfil_derecha")
    private String perfilDerecha;
    @Basic(optional = false)
    @Column(name = "perfil_isquierda")
    private String perfilIsquierda;
    @Basic(optional = false)
    @Column(name = "exodoncias_derecha")
    private String exodonciasDerecha;
    @Basic(optional = false)
    @Column(name = "exodoncias_izquierda")
    private String exodonciasIzquierda;
    @Basic(optional = false)
    @Column(name = "mov_molar_inf_derecha")
    private String movMolarInfDerecha;
    @Basic(optional = false)
    @Column(name = "mov_molar_inf_izquierda")
    private String movMolarInfIzquierda;
    @Basic(optional = false)
    @Column(name = "relacion_molar_derecha")
    private String relacionMolarDerecha;
    @Basic(optional = false)
    @Column(name = "relacion_molar_izquierda")
    private String relacionMolarIzquierda;
    @Basic(optional = false)
    @Column(name = "mov_molar_inf_derecha2")
    private String movMolarInfDerecha2;
    @Basic(optional = false)
    @Column(name = "mov_molar_inf_izquierda2")
    private String movMolarInfIzquierda2;
    @Basic(optional = false)
    @Column(name = "facial")
    private String facial;
    @Basic(optional = false)
    @Column(name = "periodontal")
    private String periodontal;
    @Basic(optional = false)
    @Column(name = "esqueletico")
    private String esqueletico;
    @Basic(optional = false)
    @Column(name = "detal_oclusal")
    private String detalOclusal;
    @Basic(optional = false)
    @Column(name = "funcional")
    private String funcional;
    @Basic(optional = false)
    @Column(name = "interconsulta")
    private String interconsulta;
    @Basic(optional = false)
    @Column(name = "anclaje")
    private String anclaje;
    @Basic(optional = false)
    @Column(name = "limitaciones_riesgos")
    private String limitacionesRiesgos;
    @Basic(optional = false)
    @Column(name = "costo")
    private long costo;
    @Basic(optional = false)
    @Column(name = "cuota_inicial")
    private long cuotaInicial;
    @Basic(optional = false)
    @Column(name = "num_controles")
    private int numControles;
    @Basic(optional = false)
    @Column(name = "valor_controles")
    private long valorControles;
    @Basic(optional = false)
    @Column(name = "retenedores")
    private boolean retenedores;
    @Basic(optional = false)
    @Column(name = "reparaciones")
    private boolean reparaciones;
    @Basic(optional = false)
    @Column(name = "anclajes")
    private long anclajes;
    @Basic(optional = false)
    @Lob
    @Column(name = "firma")
    private byte[] firma;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "analisisDeEspacioId", fetch = FetchType.LAZY)
    private Collection<PlanTratamiento> planTratamientoCollection;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)    
    private Tratamiento tratamientoId;

    public AnalisisDeEspacio() {
    }

    public AnalisisDeEspacio(Integer id) {
        this.id = id;
    }

    public AnalisisDeEspacio(Integer id, String lineaMediaDerecha, String lineaMediaIzquierda, String apiñamiento, String apinamientoIzquierda, String curvaSpeeDerecha, String curvaSpeeIzquierda, String perfilDerecha, String perfilIsquierda, String exodonciasDerecha, String exodonciasIzquierda, String movMolarInfDerecha, String movMolarInfIzquierda, String relacionMolarDerecha, String relacionMolarIzquierda, String movMolarInfDerecha2, String movMolarInfIzquierda2, String facial, String periodontal, String esqueletico, String detalOclusal, String funcional, String interconsulta, String anclaje, String limitacionesRiesgos, long costo, long cuotaInicial, int numControles, long valorControles, boolean retenedores, boolean reparaciones, long anclajes, byte[] firma) {
        this.id = id;
        this.lineaMediaDerecha = lineaMediaDerecha;
        this.lineaMediaIzquierda = lineaMediaIzquierda;
        this.apiñamiento = apiñamiento;
        this.apinamientoIzquierda = apinamientoIzquierda;
        this.curvaSpeeDerecha = curvaSpeeDerecha;
        this.curvaSpeeIzquierda = curvaSpeeIzquierda;
        this.perfilDerecha = perfilDerecha;
        this.perfilIsquierda = perfilIsquierda;
        this.exodonciasDerecha = exodonciasDerecha;
        this.exodonciasIzquierda = exodonciasIzquierda;
        this.movMolarInfDerecha = movMolarInfDerecha;
        this.movMolarInfIzquierda = movMolarInfIzquierda;
        this.relacionMolarDerecha = relacionMolarDerecha;
        this.relacionMolarIzquierda = relacionMolarIzquierda;
        this.movMolarInfDerecha2 = movMolarInfDerecha2;
        this.movMolarInfIzquierda2 = movMolarInfIzquierda2;
        this.facial = facial;
        this.periodontal = periodontal;
        this.esqueletico = esqueletico;
        this.detalOclusal = detalOclusal;
        this.funcional = funcional;
        this.interconsulta = interconsulta;
        this.anclaje = anclaje;
        this.limitacionesRiesgos = limitacionesRiesgos;
        this.costo = costo;
        this.cuotaInicial = cuotaInicial;
        this.numControles = numControles;
        this.valorControles = valorControles;
        this.retenedores = retenedores;
        this.reparaciones = reparaciones;
        this.anclajes = anclajes;
        this.firma = firma;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getLineaMediaDerecha() {
        return lineaMediaDerecha;
    }

    public void setLineaMediaDerecha(String lineaMediaDerecha) {
        this.lineaMediaDerecha = lineaMediaDerecha;
    }

    public String getLineaMediaIzquierda() {
        return lineaMediaIzquierda;
    }

    public void setLineaMediaIzquierda(String lineaMediaIzquierda) {
        this.lineaMediaIzquierda = lineaMediaIzquierda;
    }

    public String getApiñamiento() {
        return apiñamiento;
    }

    public void setApiñamiento(String apiñamiento) {
        this.apiñamiento = apiñamiento;
    }

    public String getApinamientoIzquierda() {
        return apinamientoIzquierda;
    }

    public void setApinamientoIzquierda(String apinamientoIzquierda) {
        this.apinamientoIzquierda = apinamientoIzquierda;
    }

    public String getCurvaSpeeDerecha() {
        return curvaSpeeDerecha;
    }

    public void setCurvaSpeeDerecha(String curvaSpeeDerecha) {
        this.curvaSpeeDerecha = curvaSpeeDerecha;
    }

    public String getCurvaSpeeIzquierda() {
        return curvaSpeeIzquierda;
    }

    public void setCurvaSpeeIzquierda(String curvaSpeeIzquierda) {
        this.curvaSpeeIzquierda = curvaSpeeIzquierda;
    }

    public String getPerfilDerecha() {
        return perfilDerecha;
    }

    public void setPerfilDerecha(String perfilDerecha) {
        this.perfilDerecha = perfilDerecha;
    }

    public String getPerfilIsquierda() {
        return perfilIsquierda;
    }

    public void setPerfilIsquierda(String perfilIsquierda) {
        this.perfilIsquierda = perfilIsquierda;
    }

    public String getExodonciasDerecha() {
        return exodonciasDerecha;
    }

    public void setExodonciasDerecha(String exodonciasDerecha) {
        this.exodonciasDerecha = exodonciasDerecha;
    }

    public String getExodonciasIzquierda() {
        return exodonciasIzquierda;
    }

    public void setExodonciasIzquierda(String exodonciasIzquierda) {
        this.exodonciasIzquierda = exodonciasIzquierda;
    }

    public String getMovMolarInfDerecha() {
        return movMolarInfDerecha;
    }

    public void setMovMolarInfDerecha(String movMolarInfDerecha) {
        this.movMolarInfDerecha = movMolarInfDerecha;
    }

    public String getMovMolarInfIzquierda() {
        return movMolarInfIzquierda;
    }

    public void setMovMolarInfIzquierda(String movMolarInfIzquierda) {
        this.movMolarInfIzquierda = movMolarInfIzquierda;
    }

    public String getRelacionMolarDerecha() {
        return relacionMolarDerecha;
    }

    public void setRelacionMolarDerecha(String relacionMolarDerecha) {
        this.relacionMolarDerecha = relacionMolarDerecha;
    }

    public String getRelacionMolarIzquierda() {
        return relacionMolarIzquierda;
    }

    public void setRelacionMolarIzquierda(String relacionMolarIzquierda) {
        this.relacionMolarIzquierda = relacionMolarIzquierda;
    }

    public String getMovMolarInfDerecha2() {
        return movMolarInfDerecha2;
    }

    public void setMovMolarInfDerecha2(String movMolarInfDerecha2) {
        this.movMolarInfDerecha2 = movMolarInfDerecha2;
    }

    public String getMovMolarInfIzquierda2() {
        return movMolarInfIzquierda2;
    }

    public void setMovMolarInfIzquierda2(String movMolarInfIzquierda2) {
        this.movMolarInfIzquierda2 = movMolarInfIzquierda2;
    }

    public String getFacial() {
        return facial;
    }

    public void setFacial(String facial) {
        this.facial = facial;
    }

    public String getPeriodontal() {
        return periodontal;
    }

    public void setPeriodontal(String periodontal) {
        this.periodontal = periodontal;
    }

    public String getEsqueletico() {
        return esqueletico;
    }

    public void setEsqueletico(String esqueletico) {
        this.esqueletico = esqueletico;
    }

    public String getDetalOclusal() {
        return detalOclusal;
    }

    public void setDetalOclusal(String detalOclusal) {
        this.detalOclusal = detalOclusal;
    }

    public String getFuncional() {
        return funcional;
    }

    public void setFuncional(String funcional) {
        this.funcional = funcional;
    }

    public String getInterconsulta() {
        return interconsulta;
    }

    public void setInterconsulta(String interconsulta) {
        this.interconsulta = interconsulta;
    }

    public String getAnclaje() {
        return anclaje;
    }

    public void setAnclaje(String anclaje) {
        this.anclaje = anclaje;
    }

    public String getLimitacionesRiesgos() {
        return limitacionesRiesgos;
    }

    public void setLimitacionesRiesgos(String limitacionesRiesgos) {
        this.limitacionesRiesgos = limitacionesRiesgos;
    }

    public long getCosto() {
        return costo;
    }

    public void setCosto(long costo) {
        this.costo = costo;
    }

    public long getCuotaInicial() {
        return cuotaInicial;
    }

    public void setCuotaInicial(long cuotaInicial) {
        this.cuotaInicial = cuotaInicial;
    }

    public int getNumControles() {
        return numControles;
    }

    public void setNumControles(int numControles) {
        this.numControles = numControles;
    }

    public long getValorControles() {
        return valorControles;
    }

    public void setValorControles(long valorControles) {
        this.valorControles = valorControles;
    }

    public boolean getRetenedores() {
        return retenedores;
    }

    public void setRetenedores(boolean retenedores) {
        this.retenedores = retenedores;
    }

    public boolean getReparaciones() {
        return reparaciones;
    }

    public void setReparaciones(boolean reparaciones) {
        this.reparaciones = reparaciones;
    }

    public long getAnclajes() {
        return anclajes;
    }

    public void setAnclajes(long anclajes) {
        this.anclajes = anclajes;
    }

    public byte[] getFirma() {
        return firma;
    }

    public void setFirma(byte[] firma) {
        this.firma = firma;
    }

    @XmlTransient
    public Collection<PlanTratamiento> getPlanTratamientoCollection() {
        return planTratamientoCollection;
    }

    public void setPlanTratamientoCollection(Collection<PlanTratamiento> planTratamientoCollection) {
        this.planTratamientoCollection = planTratamientoCollection;
    }

    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    public void setTratamientoId(Tratamiento tratamientoId) {
        this.tratamientoId = tratamientoId;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof AnalisisDeEspacio)) {
            return false;
        }
        AnalisisDeEspacio other = (AnalisisDeEspacio) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.AnalisisDeEspacio[ id=" + id + " ]";
    }

}
