/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.math.BigDecimal;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "autorizacion")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Autorizacion.findAll", query = "SELECT a FROM Autorizacion a"),
    @NamedQuery(name = "Autorizacion.findById", query = "SELECT a FROM Autorizacion a WHERE a.id = :id"),
    @NamedQuery(name = "Autorizacion.findByYo", query = "SELECT a FROM Autorizacion a WHERE a.yo = :yo"),
    @NamedQuery(name = "Autorizacion.findByCc", query = "SELECT a FROM Autorizacion a WHERE a.cc = :cc"),
    @NamedQuery(name = "Autorizacion.findByComo", query = "SELECT a FROM Autorizacion a WHERE a.como = :como"),
    @NamedQuery(name = "Autorizacion.findByTratamiento", query = "SELECT a FROM Autorizacion a WHERE a.tratamiento = :tratamiento"),
    @NamedQuery(name = "Autorizacion.findByPara", query = "SELECT a FROM Autorizacion a WHERE a.para = :para"),
    @NamedQuery(name = "Autorizacion.findByUno", query = "SELECT a FROM Autorizacion a WHERE a.uno = :uno"),
    @NamedQuery(name = "Autorizacion.findByDos", query = "SELECT a FROM Autorizacion a WHERE a.dos = :dos"),
    @NamedQuery(name = "Autorizacion.findByTres", query = "SELECT a FROM Autorizacion a WHERE a.tres = :tres"),
    @NamedQuery(name = "Autorizacion.findByCuatro", query = "SELECT a FROM Autorizacion a WHERE a.cuatro = :cuatro"),
    @NamedQuery(name = "Autorizacion.findByValorTratamiento", query = "SELECT a FROM Autorizacion a WHERE a.valorTratamiento = :valorTratamiento"),
    @NamedQuery(name = "Autorizacion.findByCancelarloAsi", query = "SELECT a FROM Autorizacion a WHERE a.cancelarloAsi = :cancelarloAsi"),
    @NamedQuery(name = "Autorizacion.findByTiempoEstimado", query = "SELECT a FROM Autorizacion a WHERE a.tiempoEstimado = :tiempoEstimado")})
public class Autorizacion implements Serializable {
    public static final String PROP_TIEMPOESTIMADO = "PROP_TIEMPOESTIMADO";
    public static final String PROP_ORTODONCIA = "PROP_ORTODONCIA";
   
    @Basic(optional = false)
    @Lob
    @Column(name = "firma")
    private byte[] firmaPaciente;
    @Basic(optional = false)
    @Lob
    @Column(name = "huella")
    private byte[] huella;
   
    @Transient
    private final PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "yo")
    private String yo;
    @Basic(optional = false)
    @Column(name = "cc")
    private String cc;
    @Basic(optional = false)
    @Column(name = "como")
    private String como;
    @Basic(optional = false)
    @Column(name = "tratamiento")
    private String tratamiento;
    @Basic(optional = false)
    @Column(name = "para")
    private String para;
    @Basic(optional = false)
    @Column(name = "uno")
    private String uno;
    @Basic(optional = false)
    @Column(name = "dos")
    private String dos;
    @Basic(optional = false)
    @Column(name = "tres")
    private String tres;
    @Basic(optional = false)
    @Column(name = "cuatro")
    private String cuatro;
    @Basic(optional = false)
    @Column(name = "valor_tratamiento")
    private long valorTratamiento;
    @Basic(optional = false)
    @Column(name = "cancelarlo_asi")
    private String cancelarloAsi;
    @Basic(optional = false)
    @Column(name = "tiempo_estimado")
    private int tiempoEstimado;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @OneToOne(optional = false, fetch = FetchType.LAZY)
    private Tratamiento tratamientoId;

    public Autorizacion() {
    }

    public Autorizacion(Integer id) {
        this.id = id;
    }

    public Autorizacion(Integer id, String yo, String cc, String como, String tratamiento, String para, String uno, String dos, String tres, String cuatro, long valorTratamiento, String cancelarloAsi, int tiempoEstimado, byte[] firmaPaciente) {
        this.id = id;
        this.yo = yo;
        this.cc = cc;
        this.como = como;
        this.tratamiento = tratamiento;
        this.para = para;
        this.uno = uno;
        this.dos = dos;
        this.tres = tres;
        this.cuatro = cuatro;
        this.valorTratamiento = valorTratamiento;
        this.cancelarloAsi = cancelarloAsi;
        this.tiempoEstimado = tiempoEstimado;
        this.firmaPaciente = firmaPaciente;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public String getYo() {
        return yo;
    }

    public void setYo(String yo) {
        String oldYo = this.yo;
        this.yo = yo;
        changeSupport.firePropertyChange("yo", oldYo, yo);
    }

    public String getCc() {
        return cc;
    }

    public void setCc(String cc) {
        String oldCc = this.cc;
        this.cc = cc;
        changeSupport.firePropertyChange("cc", oldCc, cc);
    }

    public String getComo() {
        return como;
    }

    public void setComo(String como) {
        String oldComo = this.como;
        this.como = como;
        changeSupport.firePropertyChange("como", oldComo, como);
    }

    public String getTratamiento() {
        return tratamiento;
    }

    public void setTratamiento(String tratamiento) {
        String oldTratamiento = this.tratamiento;
        this.tratamiento = tratamiento;
        changeSupport.firePropertyChange("tratamiento", oldTratamiento, tratamiento);
    }

    public String getPara() {
        return para;
    }

    public void setPara(String para) {
        String oldPara = this.para;
        this.para = para;
        changeSupport.firePropertyChange("para", oldPara, para);
    }

    public String getUno() {
        return uno;
    }

    public void setUno(String uno) {
        String oldUno = this.uno;
        this.uno = uno;
        changeSupport.firePropertyChange("uno", oldUno, uno);
    }

    public String getDos() {
        return dos;
    }

    public void setDos(String dos) {
        String oldDos = this.dos;
        this.dos = dos;
        changeSupport.firePropertyChange("dos", oldDos, dos);
    }

    public String getTres() {
        return tres;
    }

    public void setTres(String tres) {
        String oldTres = this.tres;
        this.tres = tres;
        changeSupport.firePropertyChange("tres", oldTres, tres);
    }

    public String getCuatro() {
        return cuatro;
    }

    public void setCuatro(String cuatro) {
        String oldCuatro = this.cuatro;
        this.cuatro = cuatro;
        changeSupport.firePropertyChange("cuatro", oldCuatro, cuatro);
    }

    public long getValorTratamiento() {
        return valorTratamiento;
    }

    public void setValorTratamiento(long valorTratamiento) {
        long oldValorTratamiento = this.valorTratamiento;
        this.valorTratamiento = valorTratamiento;
        changeSupport.firePropertyChange("valorTratamiento", oldValorTratamiento, valorTratamiento);
    }

    public String getCancelarloAsi() {
        return cancelarloAsi;
    }

    public void setCancelarloAsi(String cancelarloAsi) {
        String oldCancelarloAsi = this.cancelarloAsi;
        this.cancelarloAsi = cancelarloAsi;
        changeSupport.firePropertyChange("cancelarloAsi", oldCancelarloAsi, cancelarloAsi);
    }

    public int getTiempoEstimado() {
        return tiempoEstimado;
    }

    public void setTiempoEstimado(int tiempoEstimado) {
        int oldTiempoEstimado = this.tiempoEstimado;
        this.tiempoEstimado = tiempoEstimado;
        changeSupport.firePropertyChange("tiempoEstimado", oldTiempoEstimado, tiempoEstimado);
    }

    public byte[] getFirmaPaciente() {
        return firmaPaciente;
    }

    public void setFirmaPaciente(byte[] firmaPaciente) {
        byte[] oldFirmaPaciente = this.firmaPaciente;
        this.firmaPaciente = firmaPaciente;
        changeSupport.firePropertyChange("firmaPaciente", oldFirmaPaciente, firmaPaciente);
    }

    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    public void setTratamientoId(Tratamiento tratamientoId) {
        Tratamiento oldTratamientoId = this.tratamientoId;
        this.tratamientoId = tratamientoId;
        changeSupport.firePropertyChange("tratamientoId", oldTratamientoId, tratamientoId);
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Autorizacion)) {
            return false;
        }
        Autorizacion other = (Autorizacion) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return id+"";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    

    public byte[] getHuella() {
        return huella;
    }

    public void setHuella(byte[] huella) {
        byte[] oldHuella = this.huella;
        this.huella = huella;
        changeSupport.firePropertyChange("huella", oldHuella, huella);
    }


  

}
