/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "citas")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Citas.findAll", query = "SELECT c FROM Citas c"),
    @NamedQuery(name = "Citas.findById", query = "SELECT c FROM Citas c WHERE c.id = :id"),
    @NamedQuery(name = "Citas.orderByFecha", query = "SELECT c FROM Citas c GROUP BY c.fecha "),
    @NamedQuery(name = "Citas.findByFecha", query = "SELECT c FROM Citas c WHERE c.fecha = :fecha")})
public class Citas implements Serializable {

    public static final String PROP_PACEINTETXT = "PROP_PACEINTETXT";
    public static final String PROP_ME = "PROP_ME";
    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @JoinColumn(name = "estado_cita_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private EstadoCita estadoCitaId;
    @JoinColumn(name = "paciente_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Paciente pacienteId;
    @Column(name = "paciente")
    private String paceinteTxt;
    @Transient
    private Citas me;

    public Citas() {
    }

    public Citas(Integer id) {
        this.id = id;
    }

    public Citas(Integer id, Date fecha) {
        this.id = id;
        this.fecha = fecha;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public Date getFecha() {
        return fecha;
    }

    public void setFecha(Date fecha) {
        Date oldFecha = this.fecha;
        this.fecha = fecha;
        changeSupport.firePropertyChange("fecha", oldFecha, fecha);
    }

    public EstadoCita getEstadoCitaId() {
        return estadoCitaId;
    }

    public void setEstadoCitaId(EstadoCita estadoCitaId) {
        EstadoCita oldEstadoCitaId = this.estadoCitaId;
        this.estadoCitaId = estadoCitaId;
        changeSupport.firePropertyChange("estadoCitaId", oldEstadoCitaId, estadoCitaId);
    }

    public Paciente getPacienteId() {
        return pacienteId;
    }

    public void setPacienteId(Paciente pacienteId) {
        Paciente oldPacienteId = this.pacienteId;
        this.pacienteId = pacienteId;
        if (pacienteId != null) {
            setPaceinteTxt(pacienteId.getNombreApellido());
        }
        changeSupport.firePropertyChange("pacienteId", oldPacienteId, pacienteId);
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Citas)) {
            return false;
        }
        Citas other = (Citas) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    /**
     * @return the paceinteTxt
     */
    public String getPaceinteTxt() {
        return paceinteTxt;
    }

    /**
     * @param paceinteTxt the paceinteTxt to set
     */
    public void setPaceinteTxt(String paceinteTxt) {
        java.lang.String oldPaceinteTxt = this.paceinteTxt;
        this.paceinteTxt = paceinteTxt;
        changeSupport.firePropertyChange(PROP_PACEINTETXT, oldPaceinteTxt, paceinteTxt);
    }

    @Override
    public String toString() {
        return id+"";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    /**
     * @return the me
     */
    public Citas getMe() {
        return this;
    }

    /**
     * @param me the me to set
     */
    public void setMe(Citas me) {
        entidades.Citas oldMe = this.me;
        this.me = this;
        changeSupport.firePropertyChange(PROP_ME, oldMe, me);
    }

}
