/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import entidades.historia.HistoriaClinica;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "control_palaca")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "ControlPalaca.findAll", query = "SELECT c FROM ControlPalaca c"),
    @NamedQuery(name = "ControlPalaca.findById", query = "SELECT c FROM ControlPalaca c WHERE c.id = :id"),
    @NamedQuery(name = "ControlPalaca.findByNumDiente", query = "SELECT c FROM ControlPalaca c WHERE c.numDiente = :numDiente"),
    @NamedQuery(name = "ControlPalaca.findByTotal", query = "SELECT c FROM ControlPalaca c WHERE c.total = :total"),
    @NamedQuery(name = "ControlPalaca.findByV", query = "SELECT c FROM ControlPalaca c WHERE c.v = :v"),
    @NamedQuery(name = "ControlPalaca.findByM", query = "SELECT c FROM ControlPalaca c WHERE c.m = :m"),
    @NamedQuery(name = "ControlPalaca.findByD", query = "SELECT c FROM ControlPalaca c WHERE c.d = :d"),
    @NamedQuery(name = "ControlPalaca.findByL", query = "SELECT c FROM ControlPalaca c WHERE c.l = :l"),
    @NamedQuery(name = "ControlPalaca.findByO", query = "SELECT c FROM ControlPalaca c WHERE c.o = :o"),
    @NamedQuery(name = "ControlPalaca.findByF", query = "SELECT c FROM ControlPalaca c WHERE c.f = :f"),
    @NamedQuery(name = "ControlPalaca.findByT", query = "SELECT c FROM ControlPalaca c WHERE c.t = :t"),
    @NamedQuery(name = "ControlPalaca.findByFecha", query = "SELECT c FROM ControlPalaca c WHERE c.fecha = :fecha"),
    @NamedQuery(name = "ControlPalaca.findByNumSuperPlaca", query = "SELECT c FROM ControlPalaca c WHERE c.numSuperPlaca = :numSuperPlaca"),
    @NamedQuery(name = "ControlPalaca.findByIndice", query = "SELECT c FROM ControlPalaca c WHERE c.indice = :indice")})
public class ControlPalaca implements Serializable {
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "num_diente")
    private int numDiente;
    @Column(name = "total")
    private Integer total;
    @Column(name = "v")
    private Integer v;
    @Column(name = "m")
    private Integer m;
    @Column(name = "d")
    private Integer d;
    @Column(name = "l")
    private Integer l;
    @Column(name = "o")
    private Integer o;
    @Column(name = "f")
    private Integer f;
    @Column(name = "t")
    private Integer t;
    @Basic(optional = false)
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Basic(optional = false)
    @Column(name = "num_super_placa")
    private int numSuperPlaca;
    @Basic(optional = false)
    @Column(name = "indice")
    private long indice;
    @JoinColumn(name = "historia_clinica_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)
    private HistoriaClinica historiaClinicaId;

    public ControlPalaca() {
    }

    public ControlPalaca(Integer id) {
        this.id = id;
    }

    public ControlPalaca(Integer id, int numDiente, Date fecha, int numSuperPlaca, long indice) {
        this.id = id;
        this.numDiente = numDiente;
        this.fecha = fecha;
        this.numSuperPlaca = numSuperPlaca;
        this.indice = indice;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public int getNumDiente() {
        return numDiente;
    }

    public void setNumDiente(int numDiente) {
        this.numDiente = numDiente;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public Integer getV() {
        return v;
    }

    public void setV(Integer v) {
        this.v = v;
    }

    public Integer getM() {
        return m;
    }

    public void setM(Integer m) {
        this.m = m;
    }

    public Integer getD() {
        return d;
    }

    public void setD(Integer d) {
        this.d = d;
    }

    public Integer getL() {
        return l;
    }

    public void setL(Integer l) {
        this.l = l;
    }

    public Integer getO() {
        return o;
    }

    public void setO(Integer o) {
        this.o = o;
    }

    public Integer getF() {
        return f;
    }

    public void setF(Integer f) {
        this.f = f;
    }

    public Integer getT() {
        return t;
    }

    public void setT(Integer t) {
        this.t = t;
    }

    public Date getFecha() {
        return fecha;
    }

    public void setFecha(Date fecha) {
        this.fecha = fecha;
    }

    public int getNumSuperPlaca() {
        return numSuperPlaca;
    }

    public void setNumSuperPlaca(int numSuperPlaca) {
        this.numSuperPlaca = numSuperPlaca;
    }

    public long getIndice() {
        return indice;
    }

    public void setIndice(long indice) {
        this.indice = indice;
    }

    public HistoriaClinica getHistoriaClinicaId() {
        return historiaClinicaId;
    }

    public void setHistoriaClinicaId(HistoriaClinica historiaClinicaId) {
        this.historiaClinicaId = historiaClinicaId;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof ControlPalaca)) {
            return false;
        }
        ControlPalaca other = (ControlPalaca) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.ControlPalaca[ id=" + id + " ]";
    }

}
