/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "evolucion")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Evolucion.findAll", query = "SELECT e FROM Evolucion e"),
    @NamedQuery(name = "Evolucion.findById", query = "SELECT e FROM Evolucion e WHERE e.id = :id"),
    @NamedQuery(name = "Evolucion.findByFecha", query = "SELECT e FROM Evolucion e WHERE e.fecha = :fecha"),
    @NamedQuery(name = "Evolucion.findByProcedimiento", query = "SELECT e FROM Evolucion e WHERE e.procedimiento = :procedimiento"),
    @NamedQuery(name = "Evolucion.findByValor", query = "SELECT e FROM Evolucion e WHERE e.valor = :valor")})
public class Evolucion implements Serializable {
    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Basic(optional = false)
    @Column(name = "procedimiento")
    private String procedimiento;
    @Basic(optional = false)
    @Column(name = "valor")
    private long valor;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)
    private Tratamiento tratamientoId;
    @JoinColumn(name = "personal_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)
    private Personal personalId;
    

    public Evolucion() {
    }

    public Evolucion(Integer id) {
        this.id = id;
    }

    public Evolucion(Integer id, Date fecha, String procedimiento, long valor) {
        this.id = id;
        this.fecha = fecha;
        this.procedimiento = procedimiento;
        this.valor = valor;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public Date getFecha() {
        return fecha;
    }

    public void setFecha(Date fecha) {
        Date oldFecha = this.fecha;
        this.fecha = fecha;
        changeSupport.firePropertyChange("fecha", oldFecha, fecha);
    }

    public String getProcedimiento() {
        return procedimiento;
    }

    public void setProcedimiento(String procedimiento) {
        String oldProcedimiento = this.procedimiento;
        this.procedimiento = procedimiento;
        changeSupport.firePropertyChange("procedimiento", oldProcedimiento, procedimiento);
    }

    public long getValor() {
        return valor;
    }

    public void setValor(long valor) {
        long oldValor = this.valor;
        this.valor = valor;
        changeSupport.firePropertyChange("valor", oldValor, valor);
    }

    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    public void setTratamientoId(Tratamiento tratamientoId) {
        Tratamiento oldTratamientoId = this.tratamientoId;
        this.tratamientoId = tratamientoId;
        changeSupport.firePropertyChange("tratamientoId", oldTratamientoId, tratamientoId);
    }

    public Personal getPersonalId() {
        return personalId;
    }

    public void setPersonalId(Personal personalId) {
        Personal oldPersonalId = this.personalId;
        this.personalId = personalId;
        changeSupport.firePropertyChange("personalId", oldPersonalId, personalId);
    }

    

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Evolucion)) {
            return false;
        }
        Evolucion other = (Evolucion) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.Evolucion[ id=" + id + " ]";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

}
