/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "paciente")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Paciente.findAll", query = "SELECT p FROM Paciente p"),
    @NamedQuery(name = "Paciente.findById", query = "SELECT p FROM Paciente p WHERE p.id = :id"),
    @NamedQuery(name = "Paciente.findByIdTen", query = "SELECT p FROM Paciente p WHERE p.idTen = :idTen"),
    @NamedQuery(name = "Paciente.findByTipoId", query = "SELECT p FROM Paciente p WHERE p.tipoId = :tipoId"),
    @NamedQuery(name = "Paciente.findByNombreApellido", query = "SELECT p FROM Paciente p WHERE p.nombreApellido = :nombreApellido"),
    @NamedQuery(name = "Paciente.findByEstadoCivil", query = "SELECT p FROM Paciente p WHERE p.estadoCivil = :estadoCivil"),
    @NamedQuery(name = "Paciente.findBySexo", query = "SELECT p FROM Paciente p WHERE p.sexo = :sexo"),
    @NamedQuery(name = "Paciente.findByFechaNacimiento", query = "SELECT p FROM Paciente p WHERE p.fechaNacimiento = :fechaNacimiento"),
    @NamedQuery(name = "Paciente.findByEdad", query = "SELECT p FROM Paciente p WHERE p.edad = :edad"),
    @NamedQuery(name = "Paciente.findByOcupacion", query = "SELECT p FROM Paciente p WHERE p.ocupacion = :ocupacion"),
    @NamedQuery(name = "Paciente.findByDireccion", query = "SELECT p FROM Paciente p WHERE p.direccion = :direccion"),
    @NamedQuery(name = "Paciente.findByTelefono", query = "SELECT p FROM Paciente p WHERE p.telefono = :telefono"),
    @NamedQuery(name = "Paciente.findByNombreAcompanante", query = "SELECT p FROM Paciente p WHERE p.nombreAcompanante = :nombreAcompanante"),
    @NamedQuery(name = "Paciente.findByOcupacionAcomanante", query = "SELECT p FROM Paciente p WHERE p.ocupacionAcomanante = :ocupacionAcomanante"),
    @NamedQuery(name = "Paciente.findByParentescoAcompanante", query = "SELECT p FROM Paciente p WHERE p.parentescoAcompanante = :parentescoAcompanante"),
    @NamedQuery(name = "Paciente.findByTelAcompanante", query = "SELECT p FROM Paciente p WHERE p.telAcompanante = :telAcompanante"),
    @NamedQuery(name = "Paciente.findByDireccionAcompanante", query = "SELECT p FROM Paciente p WHERE p.direccionAcompanante = :direccionAcompanante"),
    @NamedQuery(name = "Paciente.findByAcudiente", query = "SELECT p FROM Paciente p WHERE p.acudiente = :acudiente"),
    @NamedQuery(name = "Paciente.findByOcupacionAcudiente", query = "SELECT p FROM Paciente p WHERE p.ocupacionAcudiente = :ocupacionAcudiente"),
    @NamedQuery(name = "Paciente.findByParentescoAcudiente", query = "SELECT p FROM Paciente p WHERE p.parentescoAcudiente = :parentescoAcudiente"),
    @NamedQuery(name = "Paciente.findByTelAcudiente", query = "SELECT p FROM Paciente p WHERE p.telAcudiente = :telAcudiente"),
    @NamedQuery(name = "Paciente.findByDireccionAcudiente", query = "SELECT p FROM Paciente p WHERE p.direccionAcudiente = :direccionAcudiente")})
public class Paciente implements Serializable {
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "pacienteId")
    private Collection<Citas> citasCollection;

    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "id_ten")
    private String idTen;
    @Basic(optional = false)
    @Column(name = "tipo_id")
    private String tipoId;
    @Basic(optional = false)
    @Column(name = "nombre_apellido")
    private String nombreApellido;
    @Basic(optional = false)
    @Column(name = "estado_civil")
    private String estadoCivil;
    @Basic(optional = false)
    @Column(name = "sexo")
    private String sexo;
    @Basic(optional = false)
    @Column(name = "fecha_nacimiento")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fechaNacimiento;
    @Basic(optional = false)
    @Column(name = "edad")
    private int edad;
    @Basic(optional = false)
    @Column(name = "ocupacion")
    private String ocupacion;
    @Basic(optional = false)
    @Column(name = "direccion")
    private String direccion;
    @Basic(optional = false)
    @Column(name = "telefono")
    private String telefono;
    @Basic(optional = false)
    @Column(name = "nombre_acompanante")
    private String nombreAcompanante;
    @Basic(optional = false)
    @Column(name = "ocupacion_acomanante")
    private String ocupacionAcomanante;
    @Basic(optional = false)
    @Column(name = "parentesco_acompanante")
    private String parentescoAcompanante;
    @Basic(optional = false)
    @Column(name = "tel_acompanante")
    private String telAcompanante;
    @Basic(optional = false)
    @Column(name = "direccion_acompanante")
    private String direccionAcompanante;
    @Basic(optional = false)
    @Column(name = "acudiente")
    private String acudiente;
    @Basic(optional = false)
    @Column(name = "ocupacion_acudiente")
    private String ocupacionAcudiente;
    @Basic(optional = false)
    @Column(name = "parentesco_acudiente")
    private String parentescoAcudiente;
    @Basic(optional = false)
    @Column(name = "tel_acudiente")
    private String telAcudiente;
    @Basic(optional = false)
    @Column(name = "direccion_acudiente")
    private String direccionAcudiente;
    @JoinColumn(name = "muni_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)
    private Muni muniId;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "pacienteId", fetch = FetchType.LAZY)
    private Collection<Tratamiento> tratamientoCollection;
    @Basic(optional = false)
    @Column(name = "adulto")
    private boolean adulto;

    public boolean isAdulto() {
        return adulto;
    }

    public void setAdulto(boolean adulto) {
        boolean oldAdulto = this.adulto;
        this.adulto = adulto;
        changeSupport.firePropertyChange("adulto", oldAdulto, adulto);

    }

    public Paciente() {
    }

    public Paciente(Integer id) {
        this.id = id;
    }

    public Paciente(Integer id, String idTen, String tipoId, String nombreApellido, String estadoCivil, String sexo, Date fechaNacimiento, int edad, String ocupacion, String direccion, String telefono, String nombreAcompanante, String ocupacionAcomanante, String parentescoAcompanante, String telAcompanante, String direccionAcompanante, String acudiente, String ocupacionAcudiente, String parentescoAcudiente, String telAcudiente, String direccionAcudiente) {
        this.id = id;
        this.idTen = idTen;
        this.tipoId = tipoId;
        this.nombreApellido = nombreApellido;
        this.estadoCivil = estadoCivil;
        this.sexo = sexo;
        this.fechaNacimiento = fechaNacimiento;
        this.edad = edad;
        this.ocupacion = ocupacion;
        this.direccion = direccion;
        this.telefono = telefono;
        this.nombreAcompanante = nombreAcompanante;
        this.ocupacionAcomanante = ocupacionAcomanante;
        this.parentescoAcompanante = parentescoAcompanante;
        this.telAcompanante = telAcompanante;
        this.direccionAcompanante = direccionAcompanante;
        this.acudiente = acudiente;
        this.ocupacionAcudiente = ocupacionAcudiente;
        this.parentescoAcudiente = parentescoAcudiente;
        this.telAcudiente = telAcudiente;
        this.direccionAcudiente = direccionAcudiente;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public String getIdTen() {
        return idTen;
    }

    public void setIdTen(String idTen) {
        String oldIdTen = this.idTen;
        this.idTen = idTen;
        changeSupport.firePropertyChange("idTen", oldIdTen, idTen);
    }

    public String getTipoId() {
        return tipoId;
    }

    public void setTipoId(String tipoId) {
        String oldTipoId = this.tipoId;
        this.tipoId = tipoId;
        changeSupport.firePropertyChange("tipoId", oldTipoId, tipoId);
    }

    public String getNombreApellido() {
        return nombreApellido;
    }

    public void setNombreApellido(String nombreApellido) {
        String oldNombreApellido = this.nombreApellido;
        this.nombreApellido = nombreApellido;
        changeSupport.firePropertyChange("nombreApellido", oldNombreApellido, nombreApellido);
    }

    public String getEstadoCivil() {
        return estadoCivil;
    }

    public void setEstadoCivil(String estadoCivil) {
        String oldEstadoCivil = this.estadoCivil;
        this.estadoCivil = estadoCivil;
        changeSupport.firePropertyChange("estadoCivil", oldEstadoCivil, estadoCivil);
    }

    public String getSexo() {
        return sexo;
    }

    public void setSexo(String sexo) {
        String oldSexo = this.sexo;
        this.sexo = sexo;
        changeSupport.firePropertyChange("sexo", oldSexo, sexo);
    }

    public Date getFechaNacimiento() {
        return fechaNacimiento;
    }

    public void setFechaNacimiento(Date fechaNacimiento) {
        Date oldFechaNacimiento = this.fechaNacimiento;
        this.fechaNacimiento = fechaNacimiento;
        changeSupport.firePropertyChange("fechaNacimiento", oldFechaNacimiento, fechaNacimiento);
    }

    public int getEdad() {
        return edad;
    }

    public void setEdad(int edad) {
        int oldEdad = this.edad;
        this.edad = edad;
        changeSupport.firePropertyChange("edad", oldEdad, edad);
    }

    public String getOcupacion() {
        return ocupacion;
    }

    public void setOcupacion(String ocupacion) {
        String oldOcupacion = this.ocupacion;
        this.ocupacion = ocupacion;
        changeSupport.firePropertyChange("ocupacion", oldOcupacion, ocupacion);
    }

    public String getDireccion() {
        return direccion;
    }

    public void setDireccion(String direccion) {
        String oldDireccion = this.direccion;
        this.direccion = direccion;
        changeSupport.firePropertyChange("direccion", oldDireccion, direccion);
    }

    public String getTelefono() {
        return telefono;
    }

    public void setTelefono(String telefono) {
        String oldTelefono = this.telefono;
        this.telefono = telefono;
        changeSupport.firePropertyChange("telefono", oldTelefono, telefono);
    }

    public String getNombreAcompanante() {
        return nombreAcompanante;
    }

    public void setNombreAcompanante(String nombreAcompanante) {
        String oldNombreAcompanante = this.nombreAcompanante;
        this.nombreAcompanante = nombreAcompanante;
        changeSupport.firePropertyChange("nombreAcompanante", oldNombreAcompanante, nombreAcompanante);
    }

    public String getOcupacionAcomanante() {
        return ocupacionAcomanante;
    }

    public void setOcupacionAcomanante(String ocupacionAcomanante) {
        String oldOcupacionAcomanante = this.ocupacionAcomanante;
        this.ocupacionAcomanante = ocupacionAcomanante;
        changeSupport.firePropertyChange("ocupacionAcomanante", oldOcupacionAcomanante, ocupacionAcomanante);
    }

    public String getParentescoAcompanante() {
        return parentescoAcompanante;
    }

    public void setParentescoAcompanante(String parentescoAcompanante) {
        String oldParentescoAcompanante = this.parentescoAcompanante;
        this.parentescoAcompanante = parentescoAcompanante;
        changeSupport.firePropertyChange("parentescoAcompanante", oldParentescoAcompanante, parentescoAcompanante);
    }

    public String getTelAcompanante() {
        return telAcompanante;
    }

    public void setTelAcompanante(String telAcompanante) {
        String oldTelAcompanante = this.telAcompanante;
        this.telAcompanante = telAcompanante;
        changeSupport.firePropertyChange("telAcompanante", oldTelAcompanante, telAcompanante);
    }

    public String getDireccionAcompanante() {
        return direccionAcompanante;
    }

    public void setDireccionAcompanante(String direccionAcompanante) {
        String oldDireccionAcompanante = this.direccionAcompanante;
        this.direccionAcompanante = direccionAcompanante;
        changeSupport.firePropertyChange("direccionAcompanante", oldDireccionAcompanante, direccionAcompanante);
    }

    public String getAcudiente() {
        return acudiente;
    }

    public void setAcudiente(String acudiente) {
        String oldAcudiente = this.acudiente;
        this.acudiente = acudiente;
        changeSupport.firePropertyChange("acudiente", oldAcudiente, acudiente);
    }

    public String getOcupacionAcudiente() {
        return ocupacionAcudiente;
    }

    public void setOcupacionAcudiente(String ocupacionAcudiente) {
        String oldOcupacionAcudiente = this.ocupacionAcudiente;
        this.ocupacionAcudiente = ocupacionAcudiente;
        changeSupport.firePropertyChange("ocupacionAcudiente", oldOcupacionAcudiente, ocupacionAcudiente);
    }

    public String getParentescoAcudiente() {
        return parentescoAcudiente;
    }

    public void setParentescoAcudiente(String parentescoAcudiente) {
        String oldParentescoAcudiente = this.parentescoAcudiente;
        this.parentescoAcudiente = parentescoAcudiente;
        changeSupport.firePropertyChange("parentescoAcudiente", oldParentescoAcudiente, parentescoAcudiente);
    }

    public String getTelAcudiente() {
        return telAcudiente;
    }

    public void setTelAcudiente(String telAcudiente) {
        String oldTelAcudiente = this.telAcudiente;
        this.telAcudiente = telAcudiente;
        changeSupport.firePropertyChange("telAcudiente", oldTelAcudiente, telAcudiente);
    }

    public String getDireccionAcudiente() {
        return direccionAcudiente;
    }

    public void setDireccionAcudiente(String direccionAcudiente) {
        String oldDireccionAcudiente = this.direccionAcudiente;
        this.direccionAcudiente = direccionAcudiente;
        changeSupport.firePropertyChange("direccionAcudiente", oldDireccionAcudiente, direccionAcudiente);
    }

    public Muni getMuniId() {
        return muniId;
    }

    public void setMuniId(Muni muniId) {
        Muni oldMuniId = this.muniId;
        this.muniId = muniId;
        changeSupport.firePropertyChange("muniId", oldMuniId, muniId);
    }

    @XmlTransient
    public Collection<Tratamiento> getTratamientoCollection() {
        return tratamientoCollection;
    }

    public void setTratamientoCollection(Collection<Tratamiento> tratamientoCollection) {
        this.tratamientoCollection = tratamientoCollection;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Paciente)) {
            return false;
        }
        Paciente other = (Paciente) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.Paciente[ id=" + id + " ]";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    @XmlTransient
    public Collection<Citas> getCitasCollection() {
        return citasCollection;
    }

    public void setCitasCollection(Collection<Citas> citasCollection) {
        this.citasCollection = citasCollection;
    }

}
