/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Collection;
import java.util.Collections;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "Personal")
@XmlRootElement
public class Personal implements Serializable {

    public static final String PROP_ESPECIALISTA = "PROP_ESPECIALISTA";
    public static final String PROP_PERMISO = "PROP_PERMISO";

    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "nombre_completo")
    private String nombreCompleto;
    @Basic(optional = false)
    @Column(name = "tel")
    private String tel;
    @Basic(optional = false)
    @Column(name = "direccion")
    private String direccion;
    @Basic(optional = false)
    @Column(name = "email")
    private String email;
    @Basic(optional = false)
    @Column(name = "titulo")
    private String titulo;
    @Basic(optional = false)
    @Column(name = "registro")
    private String registro;
    @Basic(optional = false)
    @Lob
    @Column(name = "firma")
    private byte[] firma;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "personalId")
    private Collection<Tratamiento> tratamientoCollection;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "personalId")
    private Collection<Evolucion> evolucionCollection;
    @JoinColumn(name = "area_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Area areaId;
    @OneToOne(cascade = CascadeType.ALL, mappedBy = "personalId")
    private Permiso permiso;
    @Column(name = "especialista")
    private boolean especialista;

    public Personal() {
    }

    public Personal(Integer id) {
        this.id = id;
    }

    public Personal(Integer id, String titulo, String registro, byte[] firma) {
        this.id = id;
        this.titulo = titulo;
        this.registro = registro;
        this.firma = firma;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public String getNombreCompleto() {
        return nombreCompleto;
    }

    public void setNombreCompleto(String nombreCompleto) {
        String oldNombreCompleto = this.nombreCompleto;
        this.nombreCompleto = nombreCompleto;
        changeSupport.firePropertyChange("nombreCompleto", oldNombreCompleto, nombreCompleto);
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        String oldTel = this.tel;
        this.tel = tel;
        changeSupport.firePropertyChange("tel", oldTel, tel);
    }

    public String getDireccion() {
        return direccion;
    }

    public void setDireccion(String direccion) {
        String oldDireccion = this.direccion;
        this.direccion = direccion;
        changeSupport.firePropertyChange("direccion", oldDireccion, direccion);
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        String oldEmail = this.email;
        this.email = email;
        changeSupport.firePropertyChange("email", oldEmail, email);
    }

    public String getTitulo() {
        return titulo;
    }

    public void setTitulo(String titulo) {
        String oldTitulo = this.titulo;
        this.titulo = titulo;
        changeSupport.firePropertyChange("titulo", oldTitulo, titulo);
    }

    public String getRegistro() {
        return registro;
    }

    public void setRegistro(String registro) {
        String oldRegistro = this.registro;
        this.registro = registro;
        changeSupport.firePropertyChange("registro", oldRegistro, registro);
    }

    public byte[] getFirma() {
        return firma;
    }

    public void setFirma(byte[] firma) {
        byte[] oldFirma = this.firma;
        this.firma = firma;
        changeSupport.firePropertyChange("firma", oldFirma, firma);
    }

    @XmlTransient
    public Collection<Tratamiento> getTratamientoCollection() {
        return tratamientoCollection;
    }

    public void setTratamientoCollection(Collection<Tratamiento> tratamientoCollection) {
        this.tratamientoCollection = tratamientoCollection;
    }

    @XmlTransient
    public Collection<Evolucion> getEvolucionCollection() {
        return evolucionCollection;
    }

    public void setEvolucionCollection(Collection<Evolucion> evolucionCollection) {
        this.evolucionCollection = evolucionCollection;
    }

    public Area getAreaId() {
        return areaId;
    }

    public void setAreaId(Area areaId) {
        Area oldAreaId = this.areaId;
        this.areaId = areaId;
        changeSupport.firePropertyChange("areaId", oldAreaId, areaId);
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Personal)) {
            return false;
        }
        Personal other = (Personal) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return nombreCompleto;
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    /**
     * @return the especialista
     */
    public boolean isEspecialista() {
        return especialista;
    }

    /**
     * @param especialista the especialista to set
     */
    public void setEspecialista(boolean especialista) {
        boolean oldEspecialista = this.especialista;
        this.especialista = especialista;
        changeSupport.firePropertyChange(PROP_ESPECIALISTA, oldEspecialista, especialista);
    }

    /**
     * @return the permiso
     */
    public Permiso getPermiso() {
        return permiso;
    }

    /**
     * @param permiso the permiso to set
     */
    public void setPermiso(Permiso permiso) {
        entidades.Permiso oldPermiso = this.permiso;
        this.permiso = permiso;
        changeSupport.firePropertyChange(PROP_PERMISO, oldPermiso, permiso);
    }

}
