/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author ander
 */
@Entity
@Table(name = "recetario")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Recetario.findAll", query = "SELECT r FROM Recetario r"),
    @NamedQuery(name = "Recetario.findById", query = "SELECT r FROM Recetario r WHERE r.id = :id"),
    @NamedQuery(name = "Recetario.findByFecha", query = "SELECT r FROM Recetario r WHERE r.fecha = :fecha"),
    @NamedQuery(name = "Recetario.findByReceta", query = "SELECT r FROM Recetario r WHERE r.receta = :receta")})
public class Recetario implements Serializable {
    @Transient
    private static final long serialVersionUID = 1L;
    @Transient
    public static final String PROP_ID = "PROP_ID";
    @Transient
    public static final String PROP_FECHA = "PROP_FECHA";
    @Transient
    public static final String PROP_RECETA = "PROP_RECETA";
    public static final String PROP_PACIENTEID = "PROP_PACIENTEID";
    public static final String PROP_TRATAMIENTOID = "PROP_TRATAMIENTOID";
    public static final String PROP_PROPERTYCHANGESUPPORT = "PROP_PROPERTYCHANGESUPPORT";
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Column(name = "receta")
    private String receta;
    @JoinColumn(name = "paciente_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Paciente pacienteId;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Tratamiento tratamientoId;
    @Transient
    private transient PropertyChangeSupport propertyChangeSupport = new java.beans.PropertyChangeSupport(this);


    @Override
    public int hashCode() {
        int hash = 0;
        hash += (getId() != null ? getId().hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Recetario)) {
            return false;
        }
        Recetario other = (Recetario) object;
        if ((this.getId() == null && other.getId() != null) || (this.getId() != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.Recetario[ id=" + getId() + " ]";
    }

    /**
     * @return the id
     */
    public Integer getId() {
        return id;
    }

    /**
     * @param id the id to set
     */
    public void setId(Integer id) {
        java.lang.Integer oldId = this.id;
        this.id = id;
        getPropertyChangeSupport().firePropertyChange(PROP_ID, oldId, id);
    }

    /**
     * @return the fecha
     */
    public Date getFecha() {
        return fecha;
    }

    /**
     * @param fecha the fecha to set
     */
    public void setFecha(Date fecha) {
        java.util.Date oldFecha = this.fecha;
        this.fecha = fecha;
        getPropertyChangeSupport().firePropertyChange(PROP_FECHA, oldFecha, fecha);
    }

    /**
     * @return the receta
     */
    public String getReceta() {
        return receta;
    }

    /**
     * @param receta the receta to set
     */
    public void setReceta(String receta) {
        java.lang.String oldReceta = this.receta;
        this.receta = receta;
        getPropertyChangeSupport().firePropertyChange(PROP_RECETA, oldReceta, receta);
    }

    /**
     * @return the pacienteId
     */
    public Paciente getPacienteId() {
        return pacienteId;
    }

    /**
     * @param pacienteId the pacienteId to set
     */
    public void setPacienteId(Paciente pacienteId) {
        entidades.Paciente oldPacienteId = this.pacienteId;
        this.pacienteId = pacienteId;
        propertyChangeSupport.firePropertyChange(PROP_PACIENTEID, oldPacienteId, pacienteId);
    }

    /**
     * @return the tratamientoId
     */
    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    /**
     * @param tratamientoId the tratamientoId to set
     */
    public void setTratamientoId(Tratamiento tratamientoId) {
        entidades.Tratamiento oldTratamientoId = this.tratamientoId;
        this.tratamientoId = tratamientoId;
        propertyChangeSupport.firePropertyChange(PROP_TRATAMIENTOID, oldTratamientoId, tratamientoId);
    }

    /**
     * @return the propertyChangeSupport
     */
    public PropertyChangeSupport getPropertyChangeSupport() {
        return propertyChangeSupport;
    }

    /**
     * @param propertyChangeSupport the propertyChangeSupport to set
     */
    public void setPropertyChangeSupport(PropertyChangeSupport propertyChangeSupport) {
        java.beans.PropertyChangeSupport oldPropertyChangeSupport = this.propertyChangeSupport;
        this.propertyChangeSupport = propertyChangeSupport;
        propertyChangeSupport.firePropertyChange(PROP_PROPERTYCHANGESUPPORT, oldPropertyChangeSupport, propertyChangeSupport);
    }
    
}
