/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;


import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import utilidades.NumberToLetterConverter;

/**
 *
 * @author ander
 */
@Entity
@Table(name = "recibo_caja")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "ReciboCaja.findAll", query = "SELECT r FROM ReciboCaja r"),
    @NamedQuery(name = "ReciboCaja.findById", query = "SELECT r FROM ReciboCaja r WHERE r.id = :id"),
    @NamedQuery(name = "ReciboCaja.findByFecha", query = "SELECT r FROM ReciboCaja r WHERE r.fecha = :fecha"),
    @NamedQuery(name = "ReciboCaja.findByCiudad", query = "SELECT r FROM ReciboCaja r WHERE r.ciudad = :ciudad"),
    @NamedQuery(name = "ReciboCaja.findByPor", query = "SELECT r FROM ReciboCaja r WHERE r.por = :por"),
    @NamedQuery(name = "ReciboCaja.findByEfectivo", query = "SELECT r FROM ReciboCaja r WHERE r.efectivo = :efectivo"),
    @NamedQuery(name = "ReciboCaja.findByAbono", query = "SELECT r FROM ReciboCaja r WHERE r.abono = :abono"),
    @NamedQuery(name = "ReciboCaja.findBySaldo", query = "SELECT r FROM ReciboCaja r WHERE r.saldo = :saldo"),
    @NamedQuery(name = "ReciboCaja.findBySuma", query = "SELECT r FROM ReciboCaja r WHERE r.suma = :suma"),
    @NamedQuery(name = "ReciboCaja.findByConcepto", query = "SELECT r FROM ReciboCaja r WHERE r.concepto = :concepto")})
public class ReciboCaja implements Serializable {

    @Transient
    public static final String PROP_TRATAMIENTOID = "PROP_TRATAMIENTOID";
    public static final String PROP_PERSONALID = "PROP_PERSONALID";
    public static final String PROP_PACEINTEID = "PROP_PACEINTEID";
    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Column(name = "ciudad")
    private String ciudad;
    @Column(name = "por")
    private String por;
    @Column(name = "efectivo")
    private boolean efectivo;
    // @Max(value=?)  @Min(value=?)//if you know range of your decimal fields consider using these annotations to enforce field validation
    @Column(name = "abono")
    private BigDecimal abono;
    @Column(name = "saldo")
    private BigDecimal saldo;
    @Column(name = "suma")
    private String suma;
    @Column(name = "concepto")
    private String concepto;
    @Lob
    @Column(name = "firma")
    private byte[] firma;
    @JoinColumn(name = "paciente_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Paciente paceinteId;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Tratamiento tratamientoId;

    public ReciboCaja() {
    }

    public ReciboCaja(Integer id) {
        this.id = id;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public Date getFecha() {
        return fecha;
    }

    public void setFecha(Date fecha) {
        Date oldFecha = this.fecha;
        this.fecha = fecha;
        changeSupport.firePropertyChange("fecha", oldFecha, fecha);
    }

    public String getCiudad() {
        return ciudad;
    }

    public void setCiudad(String ciudad) {
        String oldCiudad = this.ciudad;
        this.ciudad = ciudad;
        changeSupport.firePropertyChange("ciudad", oldCiudad, ciudad);
    }

    public String getPor() {
        return por;
    }

    public void setPor(String por) {
        String oldPor = this.por;
        this.por = por;
        setSuma( NumberToLetterConverter.convertNumberToLetter(por));
        changeSupport.firePropertyChange("por", oldPor, por);
    }

    public boolean getEfectivo() {
        return efectivo;
    }

    public void setEfectivo(boolean efectivo) {
        boolean oldEfectivo = this.efectivo;
        this.efectivo = efectivo;
        changeSupport.firePropertyChange("efectivo", oldEfectivo, efectivo);
    }

    public BigDecimal getAbono() {
        return abono;
    }

    public void setAbono(BigDecimal abono) {
        BigDecimal oldAbono = this.abono;
        this.abono = abono;
        changeSupport.firePropertyChange("abono", oldAbono, abono);
    }

    public BigDecimal getSaldo() {
        return saldo;
    }

    public void setSaldo(BigDecimal saldo) {
        BigDecimal oldSaldo = this.saldo;
        this.saldo = saldo;
        changeSupport.firePropertyChange("saldo", oldSaldo, saldo);
    }

    public String getSuma() {
        return suma;
    }

    public void setSuma(String suma) {
        String oldSuma = this.suma;
        this.suma = suma;
        changeSupport.firePropertyChange("suma", oldSuma, suma);
    }

    public String getConcepto() {
        return concepto;
    }

    public void setConcepto(String concepto) {
        String oldConcepto = this.concepto;
        this.concepto = concepto;
        changeSupport.firePropertyChange("concepto", oldConcepto, concepto);
    }

    public byte[] getFirma() {
        return firma;
    }

    public void setFirma(byte[] firma) {
        byte[] oldFirma = this.firma;
        this.firma = firma;
        changeSupport.firePropertyChange("firma", oldFirma, firma);
    }

   

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof ReciboCaja)) {
            return false;
        }
        ReciboCaja other = (ReciboCaja) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.ReciboCaja[ id=" + id + " ]";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    /**
     * @return the tratamientoId
     */
    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    /**
     * @param tratamientoId the tratamientoId to set
     */
    public void setTratamientoId(Tratamiento tratamientoId) {
        entidades.Tratamiento oldTratamientoId = this.tratamientoId;
        this.tratamientoId = tratamientoId;
        changeSupport.firePropertyChange(PROP_TRATAMIENTOID, oldTratamientoId, tratamientoId);
    }

 

    /**
     * @return the paceinteId
     */
    public Paciente getPaceinteId() {
        return paceinteId;
    }

    /**
     * @param paceinteId the paceinteId to set
     */
    public void setPaceinteId(Paciente paceinteId) {
        entidades.Paciente oldPaceinteId = this.paceinteId;
        this.paceinteId = paceinteId;
        changeSupport.firePropertyChange(PROP_PACEINTEID, oldPaceinteId, paceinteId);
    }

}
