/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "remision")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Remision.findAll", query = "SELECT r FROM Remision r"),
    @NamedQuery(name = "Remision.findById", query = "SELECT r FROM Remision r WHERE r.id = :id"),
    @NamedQuery(name = "Remision.findByFecha", query = "SELECT r FROM Remision r WHERE r.fecha = :fecha"),
    @NamedQuery(name = "Remision.findByDirigidoA", query = "SELECT r FROM Remision r WHERE r.dirigidoA = :dirigidoA"),
    @NamedQuery(name = "Remision.findByArea", query = "SELECT r FROM Remision r WHERE r.area = :area"),
    @NamedQuery(name = "Remision.findByMotivo", query = "SELECT r FROM Remision r WHERE r.motivo = :motivo"),
    @NamedQuery(name = "Remision.findByRespuesta", query = "SELECT r FROM Remision r WHERE r.respuesta = :respuesta")})
public class Remision implements Serializable {

    private static final long serialVersionUID = 1L;
    public static final String PROP_ID = "PROP_ID";
    public static final String PROP_FECHA = "PROP_FECHA";
    public static final String PROP_DIRIGIDOA = "PROP_DIRIGIDOA";
    public static final String PROP_AREA = "PROP_AREA";
    public static final String PROP_MOTIVO = "PROP_MOTIVO";
    public static final String PROP_RESPUESTA = "PROP_RESPUESTA";
    public static final String PROP_TRATAMIENTOID = "PROP_TRATAMIENTOID";
    public static final String PROP_MEDICOID = "PROP_MEDICOID";
    public static final String PROP_PACIENTEID = "PROP_PACIENTEID";
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Basic(optional = false)
    @Column(name = "dirigido_a")
    private String dirigidoA;
    @Basic(optional = false)
    @Column(name = "area")
    private String area;
    @Basic(optional = false)
    @Column(name = "motivo")
    private String motivo;
    @Basic(optional = false)
    @Column(name = "respuesta")
    private String respuesta;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Tratamiento tratamientoId;
   
    @JoinColumn(name = "paciente_id", referencedColumnName = "id")
    @ManyToOne(optional = false)
    private Paciente pacienteId;
    @Transient
    private final transient PropertyChangeSupport propertyChangeSupport = new java.beans.PropertyChangeSupport(this);

    public Remision() {
    }

    public Remision(Integer id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (getId() != null ? getId().hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Remision)) {
            return false;
        }
        Remision other = (Remision) object;
        if ((this.getId() == null && other.getId() != null) || (this.getId() != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.Remision[ id=" + getId() + " ]";
    }

    /**
     * @return the id
     */
    public Integer getId() {
        return id;
    }

    /**
     * @param id the id to set
     */
    public void setId(Integer id) {
        java.lang.Integer oldId = this.id;
        this.id = id;
        propertyChangeSupport.firePropertyChange(PROP_ID, oldId, id);
    }

    /**
     * @return the fecha
     */
    public Date getFecha() {
        return fecha;
    }

    /**
     * @param fecha the fecha to set
     */
    public void setFecha(Date fecha) {
        java.util.Date oldFecha = this.fecha;
        this.fecha = fecha;
        propertyChangeSupport.firePropertyChange(PROP_FECHA, oldFecha, fecha);
    }

    /**
     * @return the dirigidoA
     */
    public String getDirigidoA() {
        return dirigidoA;
    }

    /**
     * @param dirigidoA the dirigidoA to set
     */
    public void setDirigidoA(String dirigidoA) {
        java.lang.String oldDirigidoA = this.dirigidoA;
        this.dirigidoA = dirigidoA;
        propertyChangeSupport.firePropertyChange(PROP_DIRIGIDOA, oldDirigidoA, dirigidoA);
    }

    /**
     * @return the area
     */
    public String getArea() {
        return area;
    }

    /**
     * @param area the area to set
     */
    public void setArea(String area) {
        java.lang.String oldArea = this.area;
        this.area = area;
        propertyChangeSupport.firePropertyChange(PROP_AREA, oldArea, area);
    }

    /**
     * @return the motivo
     */
    public String getMotivo() {
        return motivo;
    }

    /**
     * @param motivo the motivo to set
     */
    public void setMotivo(String motivo) {
        java.lang.String oldMotivo = this.motivo;
        this.motivo = motivo;
        propertyChangeSupport.firePropertyChange(PROP_MOTIVO, oldMotivo, motivo);
    }

    /**
     * @return the respuesta
     */
    public String getRespuesta() {
        return respuesta;
    }

    /**
     * @param respuesta the respuesta to set
     */
    public void setRespuesta(String respuesta) {
        java.lang.String oldRespuesta = this.respuesta;
        this.respuesta = respuesta;
        propertyChangeSupport.firePropertyChange(PROP_RESPUESTA, oldRespuesta, respuesta);
    }

    /**
     * @return the tratamientoId
     */
    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    /**
     * @param tratamientoId the tratamientoId to set
     */
    public void setTratamientoId(Tratamiento tratamientoId) {
        entidades.Tratamiento oldTratamientoId = this.tratamientoId;
        this.tratamientoId = tratamientoId;
        propertyChangeSupport.firePropertyChange(PROP_TRATAMIENTOID, oldTratamientoId, tratamientoId);
    }

  
    /**
     * @return the pacienteId
     */
    public Paciente getPacienteId() {
        return pacienteId;
    }

    /**
     * @param pacienteId the pacienteId to set
     */
    public void setPacienteId(Paciente pacienteId) {
        entidades.Paciente oldPacienteId = this.pacienteId;
        this.pacienteId = pacienteId;
        propertyChangeSupport.firePropertyChange(PROP_PACIENTEID, oldPacienteId, pacienteId);
    }

}
