/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades;

import entidades.historia.HistoriaClinica;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Collection;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "tratamiento")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Tratamiento.findAll", query = "SELECT t FROM Tratamiento t"),
    @NamedQuery(name = "Tratamiento.findById", query = "SELECT t FROM Tratamiento t WHERE t.id = :id"),
    @NamedQuery(name = "Tratamiento.findByFecha", query = "SELECT t FROM Tratamiento t WHERE t.fecha = :fecha"),
    @NamedQuery(name = "Tratamiento.findByDescripcion", query = "SELECT t FROM Tratamiento t WHERE t.descripcion = :descripcion"),
    @NamedQuery(name = "Tratamiento.findByFinTratamiento", query = "SELECT t FROM Tratamiento t WHERE t.finTratamiento = :finTratamiento"),
    @NamedQuery(name = "Tratamiento.findByFechaFin", query = "SELECT t FROM Tratamiento t WHERE t.fechaFin = :fechaFin"),
    @NamedQuery(name = "Tratamiento.findByInactivo", query = "SELECT t FROM Tratamiento t WHERE t.inactivo = :inactivo"),
    @NamedQuery(name = "Tratamiento.findByDeAlta", query = "SELECT t FROM Tratamiento t WHERE t.deAlta = :deAlta")})
public class Tratamiento implements Serializable {

    public static final String PROP_AUTORIZACIONADULTO = "PROP_AUTORIZACIONADULTO";
    public static final String PROP_ANALISISCEFALOMETRICOADULTO = "PROP_ANALISISCEFALOMETRICOADULTO";
    public static final String PROP_ANALISISDEESPACIO = "PROP_ANALISISDEESPACIO";
    public static final String PROP_EVOLUCION = "PROP_EVOLUCION";
    public static final String PROP_ANALISISCEFALOMETRICONINOS = "PROP_ANALISISCEFALOMETRICONINOS";
    public static final String PROP_AUTORIZACION = "PROP_AUTORIZACION";
    public static final String PROP_ORTOPEDIA = "PROP_ORTOPEDIA";
    public static final String PROP_HISTORIACLINICACOLLECTION = "PROP_HISTORIACLINICACOLLECTION";
    public static final String PROP_ACTAENTREGA = "PROP_ACTAENTREGA";
    public static final String PROP_ORTOPEDIA2 = "PROP_ORTOPEDIA2";
    public static final String PROP_RECIBOCAJA = "PROP_RECIBOCAJA";
    public static final String PROP_RECIBOCAJA_1 = "PROP_RECIBOCAJA_1";
    public static final String PROP_RECIBOCAJACOLLECTION = "PROP_RECIBOCAJACOLLECTION";
    public static final String PROP_ORTOPEDIA3 = "PROP_ORTOPEDIA3";
    public static final String PROP_ANALISISPRESUPUESTO = "PROP_ANALISISPRESUPUESTO";
    public static final String PROP_ANALISISPRESUPUESTO2 = "PROP_ANALISISPRESUPUESTO2";
    public static final String PROP_ANALISISPRESUPUESTO3 = "PROP_ANALISISPRESUPUESTO3";
    public static final String PROP_CONSENTIMIENTO = "PROP_CONSENTIMIENTO";
    public static final String PROP_CONSENTIMIENTO2 = "PROP_CONSENTIMIENTO2";
    public static final String PROP_ANALISISCEFALOMETRICO = "PROP_ANALISISCEFALOMETRICO";
    public static final String PROP_ANALISISCEFALOMETRICO2 = "PROP_ANALISISCEFALOMETRICO2";

    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Column(name = "descripcion")
    private String descripcion;
    @Column(name = "fin_tratamiento")
    private boolean finTratamiento;
    @Column(name = "fecha_fin")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fechaFin;
    @Column(name = "inactivo")
    private boolean inactivo;
    @Column(name = "de_alta")
    private boolean deAlta;
    @Column(name = "analisis_presupuesto")
    private boolean analisisPresupuesto;
    @Column(name = "analisis_presupuesto2")
    private boolean analisisPresupuesto2;
    @Column(name = "analisis_presupuesto3")
    private boolean analisisPresupuesto3;
    @Column(name = "consentimiento")
    private boolean consentimiento;
    @Column(name = "consentimiento2")
    private boolean consentimiento2;
    @Column(name = "analisis_cefalometrico")
    private boolean analisisCefalometrico;
    @Column(name = "analisis_cefalometrico2")
    private boolean analisisCefalometrico2;
    
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Collection<Remision> remisionCollection;
    @OneToOne(fetch = FetchType.LAZY, mappedBy = "tratamientoId",cascade = {CascadeType.PERSIST, CascadeType.REMOVE}, orphanRemoval = true, optional = false) 
    private ActaEntrega actaEntrega;
    @JoinColumn(name = "paciente_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)
    private Paciente pacienteId;
    @JoinColumn(name = "medico_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)
    private Personal personalId;

    @OneToOne(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private AutorizacionAdulto autorizacionAdulto;
    @OneToOne(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private AnalisisCefalometricoAdulto analisisCefalometricoAdulto;
    @OneToOne(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private AnalisisDeEspacio analisisDeEspacio;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Collection<Evolucion> evolucion;
    @OneToOne(fetch = FetchType.LAZY, cascade = {CascadeType.PERSIST, CascadeType.REMOVE},
            orphanRemoval = true, optional = false, mappedBy = "tratamientoId")
    private AnalisisCefalometricoNinos analisisCefalometricoNinos;
    @OneToOne(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Autorizacion autorizacion;
    @OneToOne(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Ortopedia ortopedia;
    @OneToOne(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Ortopedia2 ortopedia2;
    @OneToOne(cascade = CascadeType.ALL, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Ortopedia3 ortopedia3;
    @OneToMany(cascade = {CascadeType.REFRESH, CascadeType.MERGE, CascadeType.DETACH}, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Collection<HistoriaClinica> historiaClinicaCollection;
    @OneToMany(cascade = {CascadeType.REFRESH, CascadeType.MERGE, CascadeType.DETACH}, mappedBy = "tratamientoId", fetch = FetchType.LAZY)
    private Collection<ReciboCaja> reciboCajaCollection;

    public Tratamiento() {
    }

    public Tratamiento(Integer id) {
        this.id = id;
    }

    public Tratamiento(Integer id, Date fecha) {
        this.id = id;
        this.fecha = fecha;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public Date getFecha() {
        return fecha;
    }

    public void setFecha(Date fecha) {
        Date oldFecha = this.fecha;
        this.fecha = fecha;
        changeSupport.firePropertyChange("fecha", oldFecha, fecha);
    }

    public String getDescripcion() {
        return descripcion;
    }

    public void setDescripcion(String descripcion) {
        String oldDescripcion = this.descripcion;
        this.descripcion = descripcion;
        changeSupport.firePropertyChange("descripcion", oldDescripcion, descripcion);
    }

    public boolean getFinTratamiento() {
        return finTratamiento;
    }

    public void setFinTratamiento(boolean finTratamiento) {
        boolean oldFinTratamiento = this.finTratamiento;
        this.finTratamiento = finTratamiento;
        changeSupport.firePropertyChange("finTratamiento", oldFinTratamiento, finTratamiento);
    }

    public Date getFechaFin() {
        return fechaFin;
    }

    public void setFechaFin(Date fechaFin) {
        Date oldFechaFin = this.fechaFin;
        this.fechaFin = fechaFin;
        changeSupport.firePropertyChange("fechaFin", oldFechaFin, fechaFin);
    }

    public boolean getInactivo() {
        return inactivo;
    }

    public void setInactivo(boolean inactivo) {
        boolean oldInactivo = this.inactivo;
        this.inactivo = inactivo;
        changeSupport.firePropertyChange("inactivo", oldInactivo, inactivo);
    }

    public boolean getDeAlta() {
        return deAlta;
    }

    public void setDeAlta(boolean deAlta) {
        boolean oldDeAlta = this.deAlta;
        this.deAlta = deAlta;
        changeSupport.firePropertyChange("deAlta", oldDeAlta, deAlta);
    }

    public Paciente getPacienteId() {
        return pacienteId;
    }

    public void setPacienteId(Paciente pacienteId) {
        Paciente oldPacienteId = this.pacienteId;
        this.pacienteId = pacienteId;
        /*if (pacienteId!=null) {
         if (pacienteId.isAdulto()) {
         TratamientoAdulto ta = new TratamientoAdulto();
         ta.setTratamientoId(this);
         setTratamientoAdulto(ta);
         }else{
         TratamientoNios tn = new TratamientoNios();
         tn.setTratamientoId(this);
         setTratamientoNios(tn);
         }
         }*/
        changeSupport.firePropertyChange("pacienteId", oldPacienteId, pacienteId);
    }

    public Personal getPersonalId() {
        return personalId;
    }

    public void setPersonalId(Personal personalId) {
        Personal oldPersonalId = this.personalId;
        this.personalId = personalId;
        changeSupport.firePropertyChange("personalId", oldPersonalId, personalId);
    }

    @XmlTransient
    public Collection<Remision> getRemisionCollection() {
        return remisionCollection;
    }

    public void setRemisionCollection(Collection<Remision> remisionCollection) {
        this.remisionCollection = remisionCollection;
    }

    @XmlTransient
    public Collection<HistoriaClinica> getHistoriaClinicaCollection() {
        return historiaClinicaCollection;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Tratamiento)) {
            return false;
        }
        Tratamiento other = (Tratamiento) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.Tratamiento[ id=" + id + " ]";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    /**
     * @return the autorizacionAdulto
     */
    public AutorizacionAdulto getAutorizacionAdulto() {
        return autorizacionAdulto;
    }

    /**
     * @param autorizacionAdulto the autorizacionAdulto to set
     */
    public void setAutorizacionAdulto(AutorizacionAdulto autorizacionAdulto) {
        entidades.AutorizacionAdulto oldAutorizacionAdulto = this.autorizacionAdulto;
        this.autorizacionAdulto = autorizacionAdulto;
        changeSupport.firePropertyChange(PROP_AUTORIZACIONADULTO, oldAutorizacionAdulto, autorizacionAdulto);
    }

    /**
     * @return the analisisCefalometricoAdulto
     */
    public AnalisisCefalometricoAdulto getAnalisisCefalometricoAdulto() {
        return analisisCefalometricoAdulto;
    }

    /**
     * @param analisisCefalometricoAdulto the analisisCefalometricoAdulto to set
     */
    public void setAnalisisCefalometricoAdulto(AnalisisCefalometricoAdulto analisisCefalometricoAdulto) {
        entidades.AnalisisCefalometricoAdulto oldAnalisisCefalometricoAdulto = this.analisisCefalometricoAdulto;
        this.analisisCefalometricoAdulto = analisisCefalometricoAdulto;
        changeSupport.firePropertyChange(PROP_ANALISISCEFALOMETRICOADULTO, oldAnalisisCefalometricoAdulto, analisisCefalometricoAdulto);
    }

    /**
     * @return the analisisDeEspacio
     */
    public AnalisisDeEspacio getAnalisisDeEspacio() {
        return analisisDeEspacio;
    }

    /**
     * @param analisisDeEspacio the analisisDeEspacio to set
     */
    public void setAnalisisDeEspacio(AnalisisDeEspacio analisisDeEspacio) {
        entidades.AnalisisDeEspacio oldAnalisisDeEspacio = this.analisisDeEspacio;
        this.analisisDeEspacio = analisisDeEspacio;
        changeSupport.firePropertyChange(PROP_ANALISISDEESPACIO, oldAnalisisDeEspacio, analisisDeEspacio);
    }

    /**
     * @return the evolucion
     */
    public Collection<Evolucion> getEvolucion() {
        return evolucion;
    }

    /**
     * @param evolucion the evolucion to set
     */
    @XmlTransient
    public void setEvolucion(Collection<Evolucion> evolucion) {
        java.util.Collection<entidades.Evolucion> oldEvolucion = this.evolucion;
        this.evolucion = evolucion;
        changeSupport.firePropertyChange(PROP_EVOLUCION, oldEvolucion, evolucion);
    }

    /**
     * @return the analisisCefalometricoNinos
     */
    public AnalisisCefalometricoNinos getAnalisisCefalometricoNinos() {
        return analisisCefalometricoNinos;
    }

    /**
     * @param analisisCefalometricoNinos the analisisCefalometricoNinos to set
     */
    public void setAnalisisCefalometricoNinos(AnalisisCefalometricoNinos analisisCefalometricoNinos) {
        entidades.AnalisisCefalometricoNinos oldAnalisisCefalometricoNinos = this.analisisCefalometricoNinos;
        this.analisisCefalometricoNinos = analisisCefalometricoNinos;
        changeSupport.firePropertyChange(PROP_ANALISISCEFALOMETRICONINOS, oldAnalisisCefalometricoNinos, analisisCefalometricoNinos);
    }

    /**
     * @return the autorizacion
     */
    public Autorizacion getAutorizacion() {
        return autorizacion;
    }

    /**
     * @param autorizacion the autorizacion to set
     */
    public void setAutorizacion(Autorizacion autorizacion) {
        entidades.Autorizacion oldAutorizacion = this.autorizacion;
        this.autorizacion = autorizacion;
        changeSupport.firePropertyChange(PROP_AUTORIZACION, oldAutorizacion, autorizacion);
    }

    /**
     * @return the ortopedia
     */
    public Ortopedia getOrtopedia() {
        return ortopedia;
    }

    /**
     * @param ortopedia the ortopedia to set
     */
    public void setOrtopedia(Ortopedia ortopedia) {
        entidades.Ortopedia oldOrtopedia = this.ortopedia;
        this.ortopedia = ortopedia;
        changeSupport.firePropertyChange(PROP_ORTOPEDIA, oldOrtopedia, ortopedia);
    }

    /**
     * @param historiaClinicaCollection the historiaClinicaCollection to set
     */
    public void setHistoriaClinicaCollection(Collection<HistoriaClinica> historiaClinicaCollection) {
        java.util.Collection<entidades.historia.HistoriaClinica> oldHistoriaClinicaCollection = this.historiaClinicaCollection;
        this.historiaClinicaCollection = historiaClinicaCollection;
        changeSupport.firePropertyChange(PROP_HISTORIACLINICACOLLECTION, oldHistoriaClinicaCollection, historiaClinicaCollection);
    }

    /**
     * @return the actaEntrega
     */
    public ActaEntrega getActaEntrega() {
        return actaEntrega;
    }

    /**
     * @param actaEntrega the actaEntrega to set
     */
    public void setActaEntrega(ActaEntrega actaEntrega) {
        entidades.ActaEntrega oldActaEntrega = this.actaEntrega;
        this.actaEntrega = actaEntrega;
        System.out.println("" + actaEntrega);
        changeSupport.firePropertyChange(PROP_ACTAENTREGA, oldActaEntrega, actaEntrega);
    }

    /**
     * @return the ortopedia2
     */
    public Ortopedia2 getOrtopedia2() {
        return ortopedia2;
    }

    /**
     * @param ortopedia2 the ortopedia2 to set
     */
    public void setOrtopedia2(Ortopedia2 ortopedia2) {
        entidades.Ortopedia2 oldOrtopedia2 = this.ortopedia2;
        this.ortopedia2 = ortopedia2;
        changeSupport.firePropertyChange(PROP_ORTOPEDIA2, oldOrtopedia2, ortopedia2);
    }

    /**
     * @return the reciboCajaCollection
     */
    public Collection<ReciboCaja> getReciboCajaCollection() {
        return reciboCajaCollection;
    }

    /**
     * @param reciboCajaCollection the reciboCajaCollection to set
     */
    @XmlTransient
    public void setReciboCajaCollection(Collection<ReciboCaja> reciboCajaCollection) {
        java.util.Collection<entidades.ReciboCaja> oldReciboCajaCollection = this.reciboCajaCollection;
        this.reciboCajaCollection = reciboCajaCollection;
        changeSupport.firePropertyChange(PROP_RECIBOCAJACOLLECTION, oldReciboCajaCollection, reciboCajaCollection);
    }

    /**
     * @return the ortopedia3
     */
    public Ortopedia3 getOrtopedia3() {
        return ortopedia3;
    }

    /**
     * @param ortopedia3 the ortopedia3 to set
     */
    public void setOrtopedia3(Ortopedia3 ortopedia3) {
        entidades.Ortopedia3 oldOrtopedia3 = this.ortopedia3;
        this.ortopedia3 = ortopedia3;
        changeSupport.firePropertyChange(PROP_ORTOPEDIA3, oldOrtopedia3, ortopedia3);
    }

    /**
     * @return the analisisPresupuesto
     */
    public boolean isAnalisisPresupuesto() {
        return analisisPresupuesto;
    }

    /**
     * @param analisisPresupuesto the analisisPresupuesto to set
     */
    public void setAnalisisPresupuesto(boolean analisisPresupuesto) {
        boolean oldAnalisisPresupuesto = this.analisisPresupuesto;
        this.analisisPresupuesto = analisisPresupuesto;
        changeSupport.firePropertyChange(PROP_ANALISISPRESUPUESTO, oldAnalisisPresupuesto, analisisPresupuesto);
    }

    /**
     * @return the analisisPresupuesto2
     */
    public boolean isAnalisisPresupuesto2() {
        return analisisPresupuesto2;
    }

    /**
     * @param analisisPresupuesto2 the analisisPresupuesto2 to set
     */
    public void setAnalisisPresupuesto2(boolean analisisPresupuesto2) {
        boolean oldAnalisisPresupuesto2 = this.analisisPresupuesto2;
        this.analisisPresupuesto2 = analisisPresupuesto2;
        changeSupport.firePropertyChange(PROP_ANALISISPRESUPUESTO2, oldAnalisisPresupuesto2, analisisPresupuesto2);
    }

    /**
     * @return the analisisPresupuesto3
     */
    public boolean isAnalisisPresupuesto3() {
        return analisisPresupuesto3;
    }

    /**
     * @param analisisPresupuesto3 the analisisPresupuesto3 to set
     */
    public void setAnalisisPresupuesto3(boolean analisisPresupuesto3) {
        boolean oldAnalisisPresupuesto3 = this.analisisPresupuesto3;
        this.analisisPresupuesto3 = analisisPresupuesto3;
        changeSupport.firePropertyChange(PROP_ANALISISPRESUPUESTO3, oldAnalisisPresupuesto3, analisisPresupuesto3);
    }

    /**
     * @return the consentimiento
     */
    public boolean isConsentimiento() {
        return consentimiento;
    }

    /**
     * @param consentimiento the consentimiento to set
     */
    public void setConsentimiento(boolean consentimiento) {
        boolean oldConsentimiento = this.consentimiento;
        this.consentimiento = consentimiento;
        changeSupport.firePropertyChange(PROP_CONSENTIMIENTO, oldConsentimiento, consentimiento);
    }

    /**
     * @return the consentimiento2
     */
    public boolean isConsentimiento2() {
        return consentimiento2;
    }

    /**
     * @param consentimiento2 the consentimiento2 to set
     */
    public void setConsentimiento2(boolean consentimiento2) {
        boolean oldConsentimiento2 = this.consentimiento2;
        this.consentimiento2 = consentimiento2;
        changeSupport.firePropertyChange(PROP_CONSENTIMIENTO2, oldConsentimiento2, consentimiento2);
    }

    /**
     * @return the analisisCefalometrico
     */
    public boolean isAnalisisCefalometrico() {
        return analisisCefalometrico;
    }

    /**
     * @param analisisCefalometrico the analisisCefalometrico to set
     */
    public void setAnalisisCefalometrico(boolean analisisCefalometrico) {
        boolean oldAnalisisCefalometrico = this.analisisCefalometrico;
        this.analisisCefalometrico = analisisCefalometrico;
        changeSupport.firePropertyChange(PROP_ANALISISCEFALOMETRICO, oldAnalisisCefalometrico, analisisCefalometrico);
    }

    /**
     * @return the analisisCefalometrico2
     */
    public boolean isAnalisisCefalometrico2() {
        return analisisCefalometrico2;
    }

    /**
     * @param analisisCefalometrico2 the analisisCefalometrico2 to set
     */
    public void setAnalisisCefalometrico2(boolean analisisCefalometrico2) {
        boolean oldAnalisisCefalometrico2 = this.analisisCefalometrico2;
        this.analisisCefalometrico2 = analisisCefalometrico2;
        changeSupport.firePropertyChange(PROP_ANALISISCEFALOMETRICO2, oldAnalisisCefalometrico2, analisisCefalometrico2);
    }

}
