/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades.historia;

import entidades.Tratamiento;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "anexos_radiografia")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "AnexosRadiografia.findAll", query = "SELECT a FROM AnexosRadiografia a"),
    @NamedQuery(name = "AnexosRadiografia.findById", query = "SELECT a FROM AnexosRadiografia a WHERE a.id = :id"),
    @NamedQuery(name = "AnexosRadiografia.findByDescripcion", query = "SELECT a FROM AnexosRadiografia a WHERE a.descripcion = :descripcion"),
    @NamedQuery(name = "AnexosRadiografia.findByRuta", query = "SELECT a FROM AnexosRadiografia a WHERE a.ruta = :ruta")})
public class AnexosRadiografia implements Serializable {

    private static final long serialVersionUID = 1L;
    public static final String PROP_ID = "PROP_ID";
    public static final String PROP_DESCRIPCION = "PROP_DESCRIPCION";
    public static final String PROP_RUTA = "PROP_RUTA";
    public static final String PROP_HISTORIAID = "PROP_HISTORIAID";
    public static final String PROP_NOMBRE = "PROP_NOMBRE";
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "descripcion")
    private String descripcion;
    @Basic(optional = false)
    @Column(name = "ruta")
    private String ruta;
    @Basic(optional = false)
    @Column(name = "nombre")
    private String nombre;
    @JoinColumn(name = "historia_clinica_id", referencedColumnName = "id")
    @ManyToOne(cascade = {
        CascadeType.PERSIST, CascadeType.MERGE,
        CascadeType.REFRESH, CascadeType.DETACH
    }, optional = false)
    private HistoriaClinica historiaId;
    @Transient
    private final transient PropertyChangeSupport propertyChangeSupport = new java.beans.PropertyChangeSupport(this);

    public AnexosRadiografia() {
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (getId() != null ? getId().hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof AnexosRadiografia)) {
            return false;
        }
        AnexosRadiografia other = (AnexosRadiografia) object;
        if ((this.getId() == null && other.getId() != null) || (this.getId() != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return descripcion;
    }

    /**
     * @return the id
     */
    public Integer getId() {
        return id;
    }

    /**
     * @param id the id to set
     */
    public void setId(Integer id) {
        java.lang.Integer oldId = this.id;
        this.id = id;
        propertyChangeSupport.firePropertyChange(PROP_ID, oldId, id);
    }

    /**
     * @return the descripcion
     */
    public String getDescripcion() {
        return descripcion;
    }

    /**
     * @param descripcion the descripcion to set
     */
    public void setDescripcion(String descripcion) {
        java.lang.String oldDescripcion = this.descripcion;
        this.descripcion = descripcion;
        propertyChangeSupport.firePropertyChange(PROP_DESCRIPCION, oldDescripcion, descripcion);
    }

    /**
     * @return the ruta
     */
    public String getRuta() {
        return ruta;
    }

    /**
     * @param ruta the ruta to set
     */
    public void setRuta(String ruta) {
        java.lang.String oldRuta = this.ruta;
        this.ruta = ruta;
        propertyChangeSupport.firePropertyChange(PROP_RUTA, oldRuta, ruta);
    }

    /**
     * @return the tratamientoId
     */
    public HistoriaClinica getHistoriaId() {
        return historiaId;
    }

    /**
     * @param tratamientoId the tratamientoId to set
     */
    public void setHistoriaId(HistoriaClinica tratamientoId) {
        HistoriaClinica oldTratamientoId = this.historiaId;
        this.historiaId = tratamientoId;
        propertyChangeSupport.firePropertyChange(PROP_HISTORIAID, oldTratamientoId, historiaId);
    }

    /**
     * @return the nombre
     */
    public String getNombre() {
        return nombre;
    }

    /**
     * @param nombre the nombre to set
     */
    public void setNombre(String nombre) {
        java.lang.String oldNombre = this.nombre;
        this.nombre = nombre;
        propertyChangeSupport.firePropertyChange(PROP_NOMBRE, oldNombre, nombre);
    }

}
