/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package entidades.historia;

import entidades.Evolucion;
import entidades.Tratamiento;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.Serializable;
import java.util.Collection;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Embedded;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

/**
 *
 * @author Andersson Paz Narvaez
 */
@Entity
@Table(name = "historia_clinica")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "HistoriaClinica.findAll", query = "SELECT h FROM HistoriaClinica h"),
    @NamedQuery(name = "HistoriaClinica.findById", query = "SELECT h FROM HistoriaClinica h WHERE h.id = :id"),
    @NamedQuery(name = "HistoriaClinica.findByFecha", query = "SELECT h FROM HistoriaClinica h WHERE h.fecha = :fecha")})
public class HistoriaClinica implements Serializable {

    public static final String PROP_ANEXOSRADIOGRAFIA = "PROP_ANEXOSRADIOGRAFIA";

    @Transient
    private PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);
    private static final long serialVersionUID = 1L;
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "id")
    private Integer id;
    @Basic(optional = false)
    @Column(name = "fecha")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fecha;
    @Basic(optional = false)
    @Column(name = "motivo_consulta")
    private String motivoConsulta;
    @Embedded
    private Antecedentes antecedentes;
    @Embedded
    private Habitos habitos_;
    @Embedded
    private ExamenClinico examenClinico;
    @Embedded
    private ExamenIntraOral examenIntraoral;
    @Embedded
    private OtrosHabitos otrosHabitos;
    @Embedded
    private AnalisisRadiografico analisisRadiografico;
    @Embedded
    private AnalisisFotografico analisisFotografico;
    @Embedded
    private AnArcDentales anArcDentales;
    @Basic(optional = false)
    @Lob
    @Column(name = "odontograma")
    private byte[] odontograma;
    @Basic(optional = false)
    @Column(name = "sano")
    private boolean sano;
    @JoinColumn(name = "tratamiento_id", referencedColumnName = "id")
    @ManyToOne(optional = false, fetch = FetchType.LAZY)
    private Tratamiento tratamientoId;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "historiaId")
    private Collection<AnexosRadiografia> anexosRadiografia;

    /**
     * Get the value of odontograma
     *
     * @return the value of odontograma
     */
    public byte[] getOdontograma() {
        return odontograma;
    }

    /**
     * Set the value of odontograma
     *
     * @param odontograma new value of odontograma
     */
    public void setOdontograma(byte[] odontograma) {
        byte[] oldOdontograma = this.odontograma;
        this.odontograma = odontograma;
        changeSupport.firePropertyChange("odontograma", oldOdontograma, odontograma);
    }

    /**
     * Get the value of sano
     *
     * @return the value of sano
     */
    public boolean isSano() {
        return sano;
    }

    /**
     * Set the value of sano
     *
     * @param sano new value of sano
     */
    public void setSano(boolean sano) {
        boolean oldSano = this.sano;
        this.sano = sano;
        changeSupport.firePropertyChange("sano", oldSano, sano);
    }

    public HistoriaClinica() {
    }

    public HistoriaClinica(Integer id) {
        this.id = id;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        Integer oldId = this.id;
        this.id = id;
        changeSupport.firePropertyChange("id", oldId, id);
    }

    public Date getFecha() {
        return fecha;
    }

    public void setFecha(Date fecha) {
        Date oldFecha = this.fecha;
        this.fecha = fecha;
        changeSupport.firePropertyChange("fecha", oldFecha, fecha);
    }

    public String getMotivoConsulta() {
        return motivoConsulta;
    }

    public void setMotivoConsulta(String motivoConsulta) {
        String oldMotivoConsulta = this.motivoConsulta;
        this.motivoConsulta = motivoConsulta;
        changeSupport.firePropertyChange("motivoConsulta", oldMotivoConsulta, motivoConsulta);
    }

    public Antecedentes getAntecedentes() {
        return antecedentes;
    }

    public void setAntecedentes(Antecedentes antecedentes) {
        Antecedentes oldantecedentes = this.antecedentes;
        this.antecedentes = antecedentes;
        changeSupport.firePropertyChange("antecedentes", oldantecedentes, antecedentes);
    }

    public Habitos getHabitos_() {
        return habitos_;
    }

    public void setHabitos_(Habitos habitos_) {
        Habitos oldhabitos_ = this.habitos_;
        this.habitos_ = habitos_;
        changeSupport.firePropertyChange("habitos_", oldhabitos_, habitos_);
    }

    public ExamenClinico getExamenClinico() {
        return examenClinico;
    }

    public void setExamenClinico(ExamenClinico examenClinico) {
        ExamenClinico oldexamenClinico = this.examenClinico;
        this.examenClinico = examenClinico;
        changeSupport.firePropertyChange("examenClinico", oldexamenClinico, examenClinico);
    }

    public ExamenIntraOral getExamenIntraoral() {
        return examenIntraoral;
    }

    public void setExamenIntraoral(ExamenIntraOral examenIntraoral) {
        ExamenIntraOral oldexamenIntraoral = this.examenIntraoral;
        this.examenIntraoral = examenIntraoral;
        changeSupport.firePropertyChange("examenIntraoral", oldexamenIntraoral, examenIntraoral);
    }

    public OtrosHabitos getOtrosHabitos() {
        return otrosHabitos;
    }

    public void setOtrosHabitos(OtrosHabitos otrosHabitos) {
        OtrosHabitos oldotrosHabitos = this.otrosHabitos;
        this.otrosHabitos = otrosHabitos;
        changeSupport.firePropertyChange("otrosHabitos", oldotrosHabitos, otrosHabitos);
    }

    public AnalisisRadiografico getAnalisisRadiografico() {
        return analisisRadiografico;
    }

    public void setAnalisisRadiografico(AnalisisRadiografico analisisRadiografico) {
        AnalisisRadiografico oldanalisisRadiografico = this.analisisRadiografico;
        this.analisisRadiografico = analisisRadiografico;
        changeSupport.firePropertyChange("analisisRadiografico", oldanalisisRadiografico, analisisRadiografico);
    }

    public AnalisisFotografico getAnalisisFotografico() {
        return analisisFotografico;
    }

    public void setAnalisisFotografico(AnalisisFotografico analisisFotografico) {
        AnalisisFotografico oldanalisisFotografico = this.analisisFotografico;
        this.analisisFotografico = analisisFotografico;
        changeSupport.firePropertyChange("analisisFotografico", oldanalisisFotografico, analisisFotografico);
    }

    public AnArcDentales getAnArcDentales() {
        return anArcDentales;
    }

    public void setAnArcDentales(AnArcDentales anArcDentales) {
        AnArcDentales oldanArcDentales = this.anArcDentales;
        this.anArcDentales = anArcDentales;
        changeSupport.firePropertyChange("anArcDentales", oldanArcDentales, anArcDentales);
    }

    public Tratamiento getTratamientoId() {
        return tratamientoId;
    }

    public void setTratamientoId(Tratamiento tratamientoId) {
        Tratamiento oldTratamientoId = this.tratamientoId;
        this.tratamientoId = tratamientoId;
        changeSupport.firePropertyChange("tratamientoId", oldTratamientoId, tratamientoId);
    }

    /**
     * @return the anexosRadiografia
     */
    public Collection<AnexosRadiografia> getAnexosRadiografia() {
        return anexosRadiografia;
    }

    /**
     * @param anexosRadiografia the anexosRadiografia to set
     */
    @XmlTransient
    public void setAnexosRadiografia(Collection<AnexosRadiografia> anexosRadiografia) {
        java.util.Collection<entidades.historia.AnexosRadiografia> oldAnexosRadiografia = this.anexosRadiografia;
        this.anexosRadiografia = anexosRadiografia;
        changeSupport.firePropertyChange(PROP_ANEXOSRADIOGRAFIA, oldAnexosRadiografia, anexosRadiografia);
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof HistoriaClinica)) {
            return false;
        }
        HistoriaClinica other = (HistoriaClinica) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "entidades.HistoriaClinica[ id=" + id + " ]";
    }

    public void addPropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.addPropertyChangeListener(listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener) {
        changeSupport.removePropertyChangeListener(listener);
    }

    public void add(HistoriaClinica historiaClinica) {
        throw new UnsupportedOperationException("Not supported yet."); //To change body of generated methods, choose Tools | Templates.
    }

    public void remove(HistoriaClinica historiaClinica) {
        throw new UnsupportedOperationException("Not supported yet."); //To change body of generated methods, choose Tools | Templates.
    }

}
