/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package utilidades;

import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.RenderingHints;
import java.awt.geom.AffineTransform;
import java.awt.image.AffineTransformOp;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.sql.Connection;
import java.text.Format;
import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import javax.imageio.ImageIO;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.swing.JOptionPane;
import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JasperCompileManager;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperReport;
import net.sf.jasperreports.view.JasperViewer;

/**
 *
 * @author Usuario
 */
public class Utilidades {

    private static TimeRenderer timeRender;
    private static Properties conf;

    public static TimeRenderer getTimeRender() {
        if (timeRender == null) {
            timeRender = new TimeRenderer();
        }
        return timeRender;
    }

    public static byte[] getBytesFromImg(Image image) throws IOException, Exception {
        BufferedImage bufferedImage = (BufferedImage) image;
        //escalar
        BufferedImage resized = new BufferedImage(90, 110, bufferedImage.getType());
        Graphics2D g = resized.createGraphics();
        g.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BILINEAR);
        g.drawImage(bufferedImage, 0, 0, 90, 110, 0, 0, bufferedImage.getWidth(), bufferedImage.getHeight(), null);
        g.dispose();
        //generar imagen
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        ImageIO.write(resized, "jpeg", baos);
        baos.flush();
        baos.close();
        return baos.toByteArray();
    }
    private static String fileConf;

    public static class TimeRenderer extends DefaultTableCellRenderer {

        private final Format formatter = new SimpleDateFormat("h:mm a");

        @Override
        public void setValue(Object value) {
            //  Format the Object before setting its value in the renderer

            try {
                if (value != null) {
                    value = formatter.format(value);
                }
            } catch (IllegalArgumentException e) {
            }

            super.setValue(value);
        }
    }

    public static Image rotar(Image image) {
        BufferedImage bufferedImage = (BufferedImage) image;
        AffineTransform tx = new AffineTransform();
        tx.rotate(Math.PI, bufferedImage.getWidth() / 2, bufferedImage.getHeight() / 2);

        AffineTransformOp op = new AffineTransformOp(tx,
                AffineTransformOp.TYPE_BILINEAR);
        bufferedImage = op.filter(bufferedImage, null);
        return bufferedImage;
    }

    /**
     *
     * @return mapa con los datos de conexxion de la base de datos
     */
    public static Map<String, String> cargarConf() {
        Map<String, String> properties = new HashMap<String, String>();
        properties.put("javax.persistence.jdbc.user", conf.getProperty("usuario").toString());
        properties.put("javax.persistence.jdbc.password", conf.getProperty("contrasena").toString());
        properties.put("javax.persistence.jdbc.url", String.format("jdbc:mysql://%s/%s",
                conf.getProperty("url").toString(),
                conf.getProperty("nombre_bd").toString()));
        return properties;
    }

    public static Properties getConfigFile(String archivo) {
        Properties propiedades = null;
        try {
            fileConf = archivo;
            try (FileInputStream f = new FileInputStream(archivo)) {
                propiedades = new Properties();
                propiedades.load(f);
            }
            conf = propiedades;
            System.out.println("conf ok!");
            return conf;

        } catch (IOException iOException) {
            JOptionPane.showMessageDialog(null, "Hubo un error tratando de leer "
                    + "el archivo de configuracíon:\n\n" + iOException.getLocalizedMessage());
            return null;
        }

    }

    public static void guardarConf(String usuario, String contrasena, String url, String nombre_bd) {
        try {
            conf.setProperty("usuario", usuario);
            conf.setProperty("contrasena", contrasena);
            conf.setProperty("url", url);
            conf.setProperty("nombre_bd", nombre_bd);
            try (FileOutputStream fileOut = new FileOutputStream(fileConf)) {
                conf.store(fileOut, "Configuración Base datos");
            }
        } catch (FileNotFoundException e) {
            JOptionPane.showMessageDialog(null, "Hubo un error tratando de guardar "
                    + "el archivo de configuracíon:\n\n" + e.getLocalizedMessage());
        } catch (IOException e) {
            JOptionPane.showMessageDialog(null, "Hubo un error tratando de guardar "
                    + "el archivo de configuracíon:\n\n" + e.getLocalizedMessage());
        }
    }

    public static EntityManagerFactory cargarUP(String unidad_persistencia, String jdbc) {
        Map<String, String> properties = new HashMap<>();
        properties.put("javax.persistence.jdbc.user", conf.getProperty("usuario").toString());
        properties.put("javax.persistence.jdbc.password", conf.getProperty("contrasena").toString());
        properties.put("javax.persistence.jdbc.url", String.format("jdbc:mysql://%s/%s",
                conf.getProperty("url").toString(),
                conf.getProperty("nombre_bd").toString()));
        EntityManagerFactory emf = Persistence.createEntityManagerFactory(
                unidad_persistencia, properties);
        return emf;
    }

    public static void restTable(JTable masterTable) {
        int row = masterTable.getSelectedRow();
        masterTable.clearSelection();
        masterTable.setRowSelectionInterval(row, row);
        masterTable.scrollRectToVisible(masterTable.getCellRect(row, 0, true));
    }

    public static java.sql.Connection getCoenction(EntityManager em) {     
        java.sql.Connection connection = em.unwrap(java.sql.Connection.class);
        return connection;
    }

    public static void abrirReporte(String archivo, Connection coneccion, Map<String, Object> parametros) {

        try {

            JasperReport report = JasperCompileManager.compileReport(archivo);

            JasperPrint print = JasperFillManager.fillReport(report,parametros, coneccion);

            JasperViewer.viewReport(print, false);

        } catch (JRException jRException) {

            JOptionPane.showMessageDialog(null,jRException.getMessage());

        }

    }
}
