/* 
 * Copyright (C) 2014 Andersson Paz Narvaez
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package utilidades;

import java.awt.Component;
import javax.swing.JComboBox;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;

/**
 *
 * @author Andersson Paz Narvaez
 */
public abstract class ValidarPanel extends JPanel implements ValidarComponentes {

    /**
     * busca componentes vacios o nulos en un jpanel, en caso de que no exista
     * este en el jtabedPane buscara lo buscara dentro de un jscrollPane
     *
     * @param tab tabulador
     * @return verdadero si algun componente esta vacio o no seleccionado
     */
    public boolean checkNull(JTabbedPane tab) {
        Component[] components = this.getComponents();
        for (Component component : components) {
            if (component instanceof JPanel) {

                JPanel panel = (JPanel) component;
                Component[] componentsp = panel.getComponents();
                if (panel.isEnabled()) {
                    for (Component componentp : componentsp) {

                        if (tipoComponente(componentp, tab)) {
                            return true;
                        }
                    }
                }
            } else {
                if (tipoComponente(component, tab)) {
                    return true;
                }
            }
        }
        return false;
    }

    public boolean checkNull(JTabbedPane tab, int indexPanel) {
        Component contenedor = tab.getComponentAt(indexPanel);
        JPanel componentAt;
        if (contenedor instanceof JScrollPane) {
            JScrollPane sp = (JScrollPane) contenedor;
            componentAt = (JPanel) sp.getViewport().getView();
        } else {
            componentAt = (JPanel) contenedor;
        }
        Component[] components = componentAt.getComponents();
        if (componentAt.isEnabled()) {
            for (Component component : components) {
                if (component instanceof JPanel) {
                    JPanel panel = (JPanel) component;
                    Component[] componentsp = panel.getComponents();
                    for (Component componentp : componentsp) {
                        if (panel.isEnabled()) {
                            if (tipoComponente(componentp, tab, indexPanel)) {
                                return true;
                            }
                        }
                    }
                } else {
                    if (tipoComponente(component, tab, indexPanel)) {
                        return true;
                    }
                }
            }
        }
        return false;
    }

    private void focusTab(JTabbedPane tab) {
        try {
            tab.setSelectedComponent(this);

        } catch (Exception e) {
            try {
                JScrollPane ancestorOfClass = (JScrollPane) SwingUtilities.getAncestorOfClass(JScrollPane.class, this);
                tab.setSelectedComponent(ancestorOfClass);
            } catch (Exception e2) {
            }

        }
        String titleAt = tab.getTitleAt(tab.getSelectedIndex());
        mensaje("Existe un campo vacio en " + titleAt + ".");
    }

    private void focusTab(JTabbedPane tab, int index) {
        try {
            tab.setSelectedIndex(index);

        } catch (Exception e) {

        }
        String titleAt = tab.getTitleAt(tab.getSelectedIndex());
        mensaje("Existe un campo vacio en " + titleAt + ".");
    }

    private void mensaje(Object msg) {
        JOptionPane.showMessageDialog(null, msg);
    }

    private boolean tipoComponente(Component component, JTabbedPane tab) {
        if (component instanceof JTextField) {
            JTextField caja = (JTextField) component;
            if (valuidarJtext(caja)) {
                focusTab(tab);
                caja.requestFocusInWindow();
                return true;
            }
        } else if (component instanceof JTextArea) {
            JTextArea area = (JTextArea) component;

            if (valuidarJArea(area)) {
                focusTab(tab);
                area.requestFocusInWindow();
                return true;
            }
        } else if (component instanceof JComboBox) {
            JComboBox combo = (JComboBox) component;
            if (valuidarJCombo(combo)) {
                focusTab(tab);
                combo.requestFocusInWindow();
                return true;
            }
        }
        return false;

    }

    private boolean tipoComponente(Component component, JTabbedPane tab, int index) {
        if (component instanceof JTextField) {
            JTextField caja = (JTextField) component;
            if (valuidarJtext(caja)) {
                focusTab(tab, index);
                caja.requestFocusInWindow();
                return true;
            }
        } else if (component instanceof JTextArea) {
            JTextArea area = (JTextArea) component;

            if (valuidarJArea(area)) {
                focusTab(tab, index);
                area.requestFocusInWindow();
                return true;
            }
        } else if (component instanceof JComboBox) {
            JComboBox combo = (JComboBox) component;
            if (valuidarJCombo(combo)) {
                focusTab(tab, index);
                combo.requestFocusInWindow();
                return true;
            }
        }
        return false;

    }
}
